@@ -49,7 +49,7 @@ static void vala_ccode_case_statement_dispose (GObject * obj);
 
 ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeCaseStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_CASE_STATEMENT, 0, NULL);
 	vala_ccode_case_statement_set_expression (self, expression);
 	return self;
@@ -63,7 +63,7 @@ ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expr
  */
 void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, ValaCCodeStatement* stmt) {
 	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->statements), stmt);
 }
 
@@ -71,7 +71,7 @@ void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, Vala
 static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCaseStatement * self;
 	self = VALA_CCODE_CASE_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "case ");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
