@@ -23,6 +23,9 @@
 #include <ccode/valaccodecastexpression.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeCastExpressionPrivate {
 	ValaCCodeExpression* _inner;
 	char* _type_name;
@@ -38,11 +41,13 @@ static gpointer vala_ccode_cast_expression_parent_class = NULL;
 static void vala_ccode_cast_expression_dispose (GObject * obj);
 
 
+
 ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* expr, const char* type) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeCastExpression * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (type != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -66,11 +71,11 @@ ValaCCodeCastExpression* vala_ccode_cast_expression_new (ValaCCodeExpression* ex
 static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCastExpression * self;
 	self = VALA_CCODE_CAST_EXPRESSION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "((");
-	vala_ccode_writer_write_string (writer, vala_ccode_cast_expression_get_type_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, ") ");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_cast_expression_get_inner (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
