@@ -1,11 +1,11 @@
 /* valaccodecommaexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,15 +20,17 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodecommaexpression.h"
+#include <ccode/valaccodecommaexpression.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
-#include <gee/collection.h>
+#include <gee/readonlycollection.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ccode/valaccodecommaexpression.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeCommaExpressionPrivate {
 	GeeList* inner;
 };
@@ -41,24 +43,29 @@ static gpointer vala_ccode_comma_expression_parent_class = NULL;
 static void vala_ccode_comma_expression_dispose (GObject * obj);
 
 
+
 /**
  * Appends the specified expression to the expression list.
  *
  * @param expr a C code expression
  */
-void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr)
-{
+void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->inner), expr);
 }
 
 
-static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
-{
+GeeCollection* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self) {
+	g_return_val_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->inner)));
+}
+
+
+static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCommaExpression * self;
 	gboolean first;
-	self = ((ValaCCodeCommaExpression*) base);
+	self = VALA_CCODE_COMMA_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
@@ -69,7 +76,7 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
 		while (gee_iterator_next (expr_it)) {
 			ValaCCodeExpression* expr;
-			expr = gee_iterator_get (expr_it);
+			expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -86,8 +93,17 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 }
 
 
-static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClass * klass)
-{
+/**
+ * Represents a comma separated expression list in the C code.
+ */
+ValaCCodeCommaExpression* vala_ccode_comma_expression_new (void) {
+	ValaCCodeCommaExpression * self;
+	self = g_object_newv (VALA_TYPE_CCODE_COMMA_EXPRESSION, 0, NULL);
+	return self;
+}
+
+
+static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClass * klass) {
 	vala_ccode_comma_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCCodeCommaExpressionPrivate));
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_comma_expression_dispose;
@@ -95,28 +111,21 @@ static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClas
 }
 
 
-static void vala_ccode_comma_expression_init (ValaCCodeCommaExpression * self)
-{
+static void vala_ccode_comma_expression_init (ValaCCodeCommaExpression * self) {
 	self->priv = VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE (self);
-	self->priv->inner = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->inner = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_ccode_comma_expression_dispose (GObject * obj)
-{
+static void vala_ccode_comma_expression_dispose (GObject * obj) {
 	ValaCCodeCommaExpression * self;
-	ValaCCodeCommaExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CCODE_COMMA_EXPRESSION (obj);
 	(self->priv->inner == NULL ? NULL : (self->priv->inner = (g_object_unref (self->priv->inner), NULL)));
-	klass = VALA_CCODE_COMMA_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CCODE_COMMA_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_ccode_comma_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_ccode_comma_expression_get_type (void)
-{
+GType vala_ccode_comma_expression_get_type (void) {
 	static GType vala_ccode_comma_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_comma_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comma_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCommaExpression), 0, (GInstanceInitFunc) vala_ccode_comma_expression_init };
