@@ -43,6 +43,7 @@ ValaCCodeComment* vala_ccode_comment_new (const char* _text) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeComment * self;
+	g_return_val_if_fail (_text != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "text";
@@ -62,7 +63,7 @@ ValaCCodeComment* vala_ccode_comment_new (const char* _text) {
 static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeComment * self;
 	self = VALA_CCODE_COMMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_comment (writer, self->priv->_text);
 }
 
