@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODECONDITIONALEXPRESSION_H__
-#define __VALACCODECONDITIONALEXPRESSION_H__
+#ifndef __CCODE_VALACCODECONDITIONALEXPRESSION_H__
+#define __CCODE_VALACCODECONDITIONALEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,11 +46,11 @@ typedef struct _ValaCCodeConditionalExpressionPrivate ValaCCodeConditionalExpres
  * Represents a conditional expression in C code.
  */
 struct _ValaCCodeConditionalExpression {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeConditionalExpressionPrivate * priv;
 };
 struct _ValaCCodeConditionalExpressionClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCodeExpression* cond, ValaCCodeExpression* true_expr, ValaCCodeExpression* false_expr);
@@ -60,7 +60,8 @@ ValaCCodeExpression* vala_ccode_conditional_expression_get_true_expression (Vala
 void vala_ccode_conditional_expression_set_true_expression (ValaCCodeConditionalExpression* self, ValaCCodeExpression* value);
 ValaCCodeExpression* vala_ccode_conditional_expression_get_false_expression (ValaCCodeConditionalExpression* self);
 void vala_ccode_conditional_expression_set_false_expression (ValaCCodeConditionalExpression* self, ValaCCodeExpression* value);
-GType vala_ccode_conditional_expression_get_type ();
+GType vala_ccode_conditional_expression_get_type (void);
+
 
 G_END_DECLS
 
