@@ -46,16 +46,17 @@ typedef struct _ValaCCodeContinueStatementPrivate ValaCCodeContinueStatementPriv
  * Represents a continue statement in the C code.
  */
 struct _ValaCCodeContinueStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeContinueStatementPrivate * priv;
 };
 struct _ValaCCodeContinueStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeContinueStatement* vala_ccode_continue_statement_new (void);
 GType vala_ccode_continue_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
