@@ -52,6 +52,7 @@ static void vala_ccode_declaration_dispose (GObject * obj);
 
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name) {
 	ValaCCodeDeclaration * self;
+	g_return_val_if_fail (type_name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_DECLARATION, 0, NULL);
 	vala_ccode_declaration_set_type_name (self, type_name);
 	return self;
@@ -65,7 +66,7 @@ ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name) {
  */
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl) {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATION (self));
-	g_return_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATOR (decl));
+	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (decl));
 	gee_collection_add (GEE_COLLECTION (self->priv->declarators), decl);
 }
 
@@ -73,7 +74,7 @@ void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCod
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeDeclaration * self;
 	self = VALA_CCODE_DECLARATION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
 		gboolean first;
 		/* combined declaration and initialization for static and extern variables*/
@@ -164,11 +165,11 @@ static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base,
 	ValaCCodeDeclaration * self;
 	gboolean first;
 	self = VALA_CCODE_DECLARATION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
+		/* no separate declaration for static variables*/
 		return;
 	}
-	/* no separate declaration for static variables*/
 	vala_ccode_writer_write_indent (writer, NULL);
 	if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_REGISTER) == VALA_CCODE_MODIFIERS_REGISTER) {
 		vala_ccode_writer_write_string (writer, "register ");
