@@ -27,6 +27,9 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeElementAccessPrivate {
 	ValaCCodeExpression* _container;
 	ValaCCodeExpression* _index;
@@ -42,12 +45,13 @@ static gpointer vala_ccode_element_access_parent_class = NULL;
 static void vala_ccode_element_access_dispose (GObject * obj);
 
 
+
 ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont, ValaCCodeExpression* i) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeElementAccess * self;
-	g_return_val_if_fail (cont == NULL || VALA_IS_CCODE_EXPRESSION (cont), NULL);
-	g_return_val_if_fail (i == NULL || VALA_IS_CCODE_EXPRESSION (i), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cont), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (i), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "container";
@@ -71,10 +75,10 @@ ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont
 static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeElementAccess * self;
 	self = VALA_CCODE_ELEMENT_ACCESS (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_element_access_get_container (self)), writer);
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_container), writer);
 	vala_ccode_writer_write_string (writer, "[");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_element_access_get_index (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_index), writer);
 	vala_ccode_writer_write_string (writer, "]");
 }
 
