@@ -46,16 +46,17 @@ typedef struct _ValaCCodeEmptyStatementPrivate ValaCCodeEmptyStatementPrivate;
  * Represents an empty statement in the C code.
  */
 struct _ValaCCodeEmptyStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeEmptyStatementPrivate * priv;
 };
 struct _ValaCCodeEmptyStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeEmptyStatement* vala_ccode_empty_statement_new (void);
 GType vala_ccode_empty_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
