@@ -1,6 +1,6 @@
 /* valaccodeenum.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <gee/collection.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeEnumPrivate {
 	char* _name;
 	GeeList* values;
@@ -40,6 +43,7 @@ static gpointer vala_ccode_enum_parent_class = NULL;
 static void vala_ccode_enum_dispose (GObject * obj);
 
 
+
 ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
 	ValaCCodeEnum * self;
 	self = g_object_newv (VALA_TYPE_CCODE_ENUM, 0, NULL);
@@ -56,7 +60,7 @@ ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
  */
 void vala_ccode_enum_add_value (ValaCCodeEnum* self, ValaCCodeEnumValue* value) {
 	g_return_if_fail (VALA_IS_CCODE_ENUM (self));
-	g_return_if_fail (value == NULL || VALA_IS_CCODE_ENUM_VALUE (value));
+	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (value));
 	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
 }
 
@@ -65,8 +69,8 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	ValaCCodeEnum * self;
 	gboolean first;
 	self = VALA_CCODE_ENUM (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if (vala_ccode_enum_get_name (self) != NULL) {
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	if (self->priv->_name != NULL) {
 		vala_ccode_writer_write_string (writer, "typedef ");
 	}
 	vala_ccode_writer_write_string (writer, "enum ");
@@ -97,9 +101,9 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 		vala_ccode_writer_write_newline (writer);
 	}
 	vala_ccode_writer_write_end_block (writer);
-	if (vala_ccode_enum_get_name (self) != NULL) {
+	if (self->priv->_name != NULL) {
 		vala_ccode_writer_write_string (writer, " ");
-		vala_ccode_writer_write_string (writer, vala_ccode_enum_get_name (self));
+		vala_ccode_writer_write_string (writer, self->priv->_name);
 	}
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
