@@ -45,15 +45,17 @@ typedef struct _ValaCCodeExpressionPrivate ValaCCodeExpressionPrivate;
  * Represents an expression node in the C code tree.
  */
 struct _ValaCCodeExpression {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeExpressionPrivate * priv;
 };
 struct _ValaCCodeExpressionClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
+ValaCCodeExpression* vala_ccode_expression_new (void);
 GType vala_ccode_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
