@@ -45,6 +45,8 @@ static void vala_ccode_formal_parameter_dispose (GObject * obj);
 
 ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const char* type) {
 	ValaCCodeFormalParameter * self;
+	g_return_val_if_fail (n != NULL, NULL);
+	g_return_val_if_fail (type != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FORMAL_PARAMETER, 0, NULL);
 	vala_ccode_formal_parameter_set_name (self, n);
 	vala_ccode_formal_parameter_set_type_name (self, type);
@@ -63,7 +65,7 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_new_with_ellipsis (void) {
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFormalParameter * self;
 	self = VALA_CCODE_FORMAL_PARAMETER (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (!self->priv->_ellipsis) {
 		vala_ccode_writer_write_string (writer, self->priv->_type_name);
 		vala_ccode_writer_write_string (writer, " ");
