@@ -1,6 +1,6 @@
 /* valaccodeforstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeForStatementPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeStatement* _body;
@@ -46,13 +49,14 @@ static gpointer vala_ccode_for_statement_parent_class = NULL;
 static void vala_ccode_for_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
 	ValaCCodeForStatement * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (body == NULL || VALA_IS_CCODE_STATEMENT (body), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FOR_STATEMENT, 0, NULL);
-	vala_ccode_for_statement_set_condition (self, condition);
 	vala_ccode_for_statement_set_body (self, body);
+	vala_ccode_for_statement_set_condition (self, condition);
 	return self;
 }
 
@@ -97,7 +101,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
 		while (gee_iterator_next (init_expr_it)) {
 			ValaCCodeExpression* init_expr;
-			init_expr = gee_iterator_get (init_expr_it);
+			init_expr = ((ValaCCodeExpression*) gee_iterator_get (init_expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -113,8 +117,8 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, "; ");
-	if (vala_ccode_for_statement_get_condition (self) != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_for_statement_get_condition (self)), writer);
+	if (self->priv->_condition != NULL) {
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	first = TRUE;
@@ -125,7 +129,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
 		while (gee_iterator_next (it_expr_it)) {
 			ValaCCodeExpression* it_expr;
-			it_expr = gee_iterator_get (it_expr_it);
+			it_expr = ((ValaCCodeExpression*) gee_iterator_get (it_expr_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -141,7 +145,7 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_for_statement_get_body (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
 }
 
 
@@ -152,10 +156,12 @@ ValaCCodeExpression* vala_ccode_for_statement_get_condition (ValaCCodeForStateme
 
 
 void vala_ccode_for_statement_set_condition (ValaCCodeForStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
