@@ -25,6 +25,9 @@
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 
+
+
+
 struct _ValaCCodeFragmentPrivate {
 	GeeList* children;
 };
@@ -39,6 +42,7 @@ static gpointer vala_ccode_fragment_parent_class = NULL;
 static void vala_ccode_fragment_dispose (GObject * obj);
 
 
+
 /**
  * Appends the specified code node to this code fragment.
  *
@@ -73,7 +77,7 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
 		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = gee_iterator_get (node_it);
+			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
 			{
 				vala_ccode_node_write (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
@@ -95,7 +99,7 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
 		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = gee_iterator_get (node_it);
+			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
 			{
 				vala_ccode_node_write_declaration (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
@@ -117,7 +121,7 @@ static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCC
 		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
 		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = gee_iterator_get (node_it);
+			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
 			{
 				vala_ccode_node_write_combined (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
