@@ -62,7 +62,7 @@ ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
  */
 void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->arguments), expr);
 }
 
@@ -82,7 +82,7 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 	ValaCCodeFunctionCall * self;
 	gboolean first;
 	self = VALA_CCODE_FUNCTION_CALL (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_call), writer);
 	vala_ccode_writer_write_string (writer, " (");
 	first = TRUE;
