@@ -25,6 +25,9 @@
 #include <gee/list.h>
 #include <gee/collection.h>
 
+
+
+
 struct _ValaCCodeFunctionDeclaratorPrivate {
 	char* _name;
 	GeeList* parameters;
@@ -40,6 +43,7 @@ static gpointer vala_ccode_function_declarator_parent_class = NULL;
 static void vala_ccode_function_declarator_dispose (GObject * obj);
 
 
+
 ValaCCodeFunctionDeclarator* vala_ccode_function_declarator_new (const char* name) {
 	ValaCCodeFunctionDeclarator * self;
 	g_return_val_if_fail (name != NULL, NULL);
@@ -75,7 +79,7 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 	self = VALA_CCODE_FUNCTION_DECLARATOR (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(*");
-	vala_ccode_writer_write_string (writer, vala_ccode_function_declarator_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ") (");
 	first = TRUE;
 	{
@@ -85,7 +89,7 @@ static void vala_ccode_function_declarator_real_write_declaration (ValaCCodeNode
 		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
 		while (gee_iterator_next (param_it)) {
 			ValaCCodeFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -109,10 +113,12 @@ char* vala_ccode_function_declarator_get_name (ValaCCodeFunctionDeclarator* self
 
 
 void vala_ccode_function_declarator_set_name (ValaCCodeFunctionDeclarator* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_DECLARATOR (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
+	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp2);
 }
 
 
@@ -165,7 +171,7 @@ static void vala_ccode_function_declarator_init (ValaCCodeFunctionDeclarator * s
 static void vala_ccode_function_declarator_dispose (GObject * obj) {
 	ValaCCodeFunctionDeclarator * self;
 	self = VALA_CCODE_FUNCTION_DECLARATOR (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
 	G_OBJECT_CLASS (vala_ccode_function_declarator_parent_class)->dispose (obj);
 }
