@@ -23,6 +23,9 @@
 #include <ccode/valaccodegotostatement.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeGotoStatementPrivate {
 	char* _name;
 };
@@ -36,10 +39,12 @@ static gpointer vala_ccode_goto_statement_parent_class = NULL;
 static void vala_ccode_goto_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeGotoStatement * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -59,10 +64,10 @@ ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
 static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeGotoStatement * self;
 	self = VALA_CCODE_GOTO_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "goto ");
-	vala_ccode_writer_write_string (writer, vala_ccode_goto_statement_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
 }
