@@ -1,6 +1,6 @@
 /* valaccodeifstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,9 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodeblock.h>
 
+
+
+
 struct _ValaCCodeIfStatementPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeStatement* _true_statement;
@@ -46,6 +49,7 @@ static gpointer vala_ccode_if_statement_parent_class = NULL;
 static void vala_ccode_if_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -55,9 +59,18 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 	g_return_val_if_fail (false_stmt == NULL || VALA_IS_CCODE_STATEMENT (false_stmt), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
-	(__params_it->name = "true-statement", g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT), g_value_set_object (&__params_it->value, true_stmt), __params_it++);
-	(__params_it->name = "false-statement", g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT), g_value_set_object (&__params_it->value, false_stmt), __params_it++);
+	__params_it->name = "condition";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, cond);
+	__params_it++;
+	__params_it->name = "true-statement";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT);
+	g_value_set_object (&__params_it->value, true_stmt);
+	__params_it++;
+	__params_it->name = "false-statement";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT);
+	g_value_set_object (&__params_it->value, false_stmt);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_IF_STATEMENT, __params_it - __params, __params);
 	while (__params_it > __params) {
 		--__params_it;
@@ -72,27 +85,27 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 	ValaCCodeIfStatement * self;
 	self = VALA_CCODE_IF_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
-	if (!vala_ccode_if_statement_get_else_if (self)) {
+	if (!self->priv->_else_if) {
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	} else {
 		vala_ccode_writer_write_string (writer, " ");
 	}
 	vala_ccode_writer_write_string (writer, "if (");
-	if (vala_ccode_if_statement_get_condition (self) != NULL) {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_if_statement_get_condition (self)), writer);
+	if (self->priv->_condition != NULL) {
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	}
 	vala_ccode_writer_write_string (writer, ")");
 	/* else shouldn't be on a separate line */
-	if (vala_ccode_if_statement_get_false_statement (self) != NULL && VALA_IS_CCODE_BLOCK (vala_ccode_if_statement_get_true_statement (self))) {
+	if (self->priv->_false_statement != NULL && VALA_IS_CCODE_BLOCK (self->priv->_true_statement)) {
 		ValaCCodeBlock* _tmp0;
 		ValaCCodeBlock* cblock;
 		_tmp0 = NULL;
-		cblock = (_tmp0 = VALA_CCODE_BLOCK (vala_ccode_if_statement_get_true_statement (self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		cblock = (_tmp0 = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		vala_ccode_block_set_suppress_newline (cblock, TRUE);
 		(cblock == NULL ? NULL : (cblock = (g_object_unref (cblock), NULL)));
 	}
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_if_statement_get_true_statement (self)), writer);
-	if (vala_ccode_if_statement_get_false_statement (self) != NULL) {
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_true_statement), writer);
+	if (self->priv->_false_statement != NULL) {
 		if (vala_ccode_writer_get_bol (writer)) {
 			vala_ccode_writer_write_indent (writer, NULL);
 			vala_ccode_writer_write_string (writer, "else");
@@ -100,15 +113,15 @@ static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWr
 			vala_ccode_writer_write_string (writer, " else");
 		}
 		/* else if should be on one line */
-		if (VALA_IS_CCODE_IF_STATEMENT (vala_ccode_if_statement_get_false_statement (self))) {
+		if (VALA_IS_CCODE_IF_STATEMENT (self->priv->_false_statement)) {
 			ValaCCodeIfStatement* _tmp1;
 			ValaCCodeIfStatement* cif;
 			_tmp1 = NULL;
-			cif = (_tmp1 = VALA_CCODE_IF_STATEMENT (vala_ccode_if_statement_get_false_statement (self)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			cif = (_tmp1 = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			vala_ccode_if_statement_set_else_if (cif, TRUE);
 			(cif == NULL ? NULL : (cif = (g_object_unref (cif), NULL)));
 		}
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_if_statement_get_false_statement (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_false_statement), writer);
 	}
 }
 
@@ -120,10 +133,12 @@ ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement
 
 
 void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
+	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp2);
 }
 
 
@@ -134,10 +149,12 @@ ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfState
 
 
 void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
+	ValaCCodeStatement* _tmp2;
 	ValaCCodeStatement* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_true_statement = (_tmp1 = g_object_ref (value), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), _tmp1);
+	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (g_object_unref (self->priv->_true_statement), NULL))), _tmp2);
 }
 
 
