@@ -1,6 +1,6 @@
 /* valaccodeifstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -47,11 +47,11 @@ typedef struct _ValaCCodeIfStatementPrivate ValaCCodeIfStatementPrivate;
  * Represents an if selection statement in the C code.
  */
 struct _ValaCCodeIfStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeIfStatementPrivate * priv;
 };
 struct _ValaCCodeIfStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt);
@@ -65,6 +65,7 @@ gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self);
 void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value);
 GType vala_ccode_if_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
