@@ -23,6 +23,9 @@
 #include <ccode/valaccodeincludedirective.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeIncludeDirectivePrivate {
 	char* _filename;
 	gboolean _local;
@@ -38,10 +41,12 @@ static gpointer vala_ccode_include_directive_parent_class = NULL;
 static void vala_ccode_include_directive_dispose (GObject * obj);
 
 
+
 ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filename, gboolean _local) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeIncludeDirective * self;
+	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "filename";
@@ -62,18 +67,16 @@ ValaCCodeIncludeDirective* vala_ccode_include_directive_new (const char* _filena
 static void vala_ccode_include_directive_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIncludeDirective * self;
 	self = VALA_CCODE_INCLUDE_DIRECTIVE (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#include ");
-	if (vala_ccode_include_directive_get_local (self)) {
+	if (self->priv->_local) {
+		vala_ccode_writer_write_string (writer, "\"");
+		vala_ccode_writer_write_string (writer, self->priv->_filename);
 		vala_ccode_writer_write_string (writer, "\"");
 	} else {
 		vala_ccode_writer_write_string (writer, "<");
-	}
-	vala_ccode_writer_write_string (writer, vala_ccode_include_directive_get_filename (self));
-	if (vala_ccode_include_directive_get_local (self)) {
-		vala_ccode_writer_write_string (writer, "\"");
-	} else {
+		vala_ccode_writer_write_string (writer, self->priv->_filename);
 		vala_ccode_writer_write_string (writer, ">");
 	}
 	vala_ccode_writer_write_newline (writer);
