@@ -28,6 +28,9 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeInitializerListPrivate {
 	GeeList* initializers;
 };
@@ -40,6 +43,7 @@ static gpointer vala_ccode_initializer_list_parent_class = NULL;
 static void vala_ccode_initializer_list_dispose (GObject * obj);
 
 
+
 /**
  * Appends the specified expression to this initializer list.
  *
@@ -47,7 +51,7 @@ static void vala_ccode_initializer_list_dispose (GObject * obj);
  */
 void vala_ccode_initializer_list_append (ValaCCodeInitializerList* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_INITIALIZER_LIST (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializers), expr);
 }
 
@@ -56,7 +60,7 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 	ValaCCodeInitializerList * self;
 	gboolean first;
 	self = VALA_CCODE_INITIALIZER_LIST (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "{");
 	first = TRUE;
 	{
