@@ -23,6 +23,9 @@
 #include <ccode/valaccodelabel.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeLabelPrivate {
 	char* _name;
 };
@@ -36,10 +39,12 @@ static gpointer vala_ccode_label_parent_class = NULL;
 static void vala_ccode_label_dispose (GObject * obj);
 
 
+
 ValaCCodeLabel* vala_ccode_label_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeLabel * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -59,9 +64,9 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name) {
 static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
-	vala_ccode_writer_write_string (writer, vala_ccode_label_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ":");
 	vala_ccode_writer_write_newline (writer);
 }
