@@ -23,6 +23,9 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodewriter.h>
 
+
+
+
 struct _ValaCCodeLineDirectivePrivate {
 	char* _filename;
 	gint _line;
@@ -38,6 +41,7 @@ static gpointer vala_ccode_line_directive_parent_class = NULL;
 static void vala_ccode_line_directive_dispose (GObject * obj);
 
 
+
 ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gint _line) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -45,7 +49,10 @@ ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gi
 	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
+	__params_it->name = "filename";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, _filename);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_LINE_DIRECTIVE, __params_it - __params, __params);
 	vala_ccode_line_directive_set_line (self, _line);
 	while (__params_it > __params) {
@@ -66,8 +73,8 @@ static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCode
 		vala_ccode_writer_write_newline (writer);
 	}
 	_tmp0 = NULL;
-	vala_ccode_writer_write_string (writer, (_tmp0 = g_strdup_printf ("#line %d \"%s\"", vala_ccode_line_directive_get_line (self), vala_ccode_line_directive_get_filename (self))));
-	(_tmp0 = (g_free (_tmp0), NULL));
+	vala_ccode_writer_write_string (writer, (_tmp0 = g_strdup_printf ("#line %d \"%s\"", self->priv->_line, self->priv->_filename)));
+	_tmp0 = (g_free (_tmp0), NULL);
 	vala_ccode_writer_write_newline (writer);
 }
 
@@ -79,10 +86,12 @@ char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self) {
 
 
 void vala_ccode_line_directive_set_filename (ValaCCodeLineDirective* self, const char* value) {
-	char* _tmp1;
+	char* _tmp2;
+	const char* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_LINE_DIRECTIVE (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_filename = (_tmp1 = g_strdup (value), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp1);
+	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_filename = (g_free (self->priv->_filename), NULL)), _tmp2);
 }
 
 
@@ -152,7 +161,7 @@ static void vala_ccode_line_directive_init (ValaCCodeLineDirective * self) {
 static void vala_ccode_line_directive_dispose (GObject * obj) {
 	ValaCCodeLineDirective * self;
 	self = VALA_CCODE_LINE_DIRECTIVE (obj);
-	(self->priv->_filename = (g_free (self->priv->_filename), NULL));
+	self->priv->_filename = (g_free (self->priv->_filename), NULL);
 	G_OBJECT_CLASS (vala_ccode_line_directive_parent_class)->dispose (obj);
 }
 
