@@ -23,6 +23,9 @@
 #include <ccode/valaccodemacroreplacement.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeMacroReplacementPrivate {
 	char* _name;
 	char* _replacement;
@@ -40,10 +43,13 @@ static gpointer vala_ccode_macro_replacement_parent_class = NULL;
 static void vala_ccode_macro_replacement_dispose (GObject * obj);
 
 
+
 ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, const char* replacement) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (replacement != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -65,7 +71,8 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (con
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
-	g_return_val_if_fail (replacement_expression == NULL || VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -86,15 +93,15 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (con
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#define ");
-	vala_ccode_writer_write_string (writer, vala_ccode_macro_replacement_get_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, " ");
-	if (vala_ccode_macro_replacement_get_replacement (self) != NULL) {
-		vala_ccode_writer_write_string (writer, vala_ccode_macro_replacement_get_replacement (self));
+	if (self->priv->_replacement != NULL) {
+		vala_ccode_writer_write_string (writer, self->priv->_replacement);
 	} else {
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_macro_replacement_get_replacement_expression (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_replacement_expression), writer);
 	}
 	vala_ccode_writer_write_newline (writer);
 }
