@@ -23,6 +23,9 @@
 #include <ccode/valaccodememberaccess.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeMemberAccessPrivate {
 	ValaCCodeExpression* _inner;
 	char* _member_name;
@@ -40,15 +43,23 @@ static gpointer vala_ccode_member_access_parent_class = NULL;
 static void vala_ccode_member_access_dispose (GObject * obj);
 
 
+
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMemberAccess * self;
-	g_return_val_if_fail (container == NULL || VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (member != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, container), __params_it++);
-	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, container);
+	__params_it++;
+	__params_it->name = "member-name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, member);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
 	vala_ccode_member_access_set_is_pointer (self, pointer);
 	while (__params_it > __params) {
@@ -64,11 +75,18 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMemberAccess * self;
-	g_return_val_if_fail (container == NULL || VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
+	g_return_val_if_fail (member != NULL, NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, container), __params_it++);
-	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION);
+	g_value_set_object (&__params_it->value, container);
+	__params_it++;
+	__params_it->name = "member-name";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, member);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
 	vala_ccode_member_access_set_is_pointer (self, TRUE);
 	while (__params_it > __params) {
@@ -83,14 +101,14 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_member_access_get_inner (self)), writer);
-	if (vala_ccode_member_access_get_is_pointer (self)) {
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
+	if (self->priv->_is_pointer) {
 		vala_ccode_writer_write_string (writer, "->");
 	} else {
 		vala_ccode_writer_write_string (writer, ".");
 	}
-	vala_ccode_writer_write_string (writer, vala_ccode_member_access_get_member_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_member_name);
 }
 
 
@@ -200,7 +218,7 @@ static void vala_ccode_member_access_dispose (GObject * obj) {
 	ValaCCodeMemberAccess * self;
 	self = VALA_CCODE_MEMBER_ACCESS (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	(self->priv->_member_name = (g_free (self->priv->_member_name), NULL));
+	self->priv->_member_name = (g_free (self->priv->_member_name), NULL);
 	G_OBJECT_CLASS (vala_ccode_member_access_parent_class)->dispose (obj);
 }
 
