@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEMEMBERACCESS_H__
-#define __VALACCODEMEMBERACCESS_H__
+#ifndef __CCODE_VALACCODEMEMBERACCESS_H__
+#define __CCODE_VALACCODEMEMBERACCESS_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -48,11 +48,11 @@ typedef struct _ValaCCodeMemberAccessPrivate ValaCCodeMemberAccessPrivate;
  * Represents an access to a struct member in the C code.
  */
 struct _ValaCCodeMemberAccess {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeMemberAccessPrivate * priv;
 };
 struct _ValaCCodeMemberAccessClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* container, const char* member, gboolean pointer);
@@ -65,6 +65,7 @@ gboolean vala_ccode_member_access_get_is_pointer (ValaCCodeMemberAccess* self);
 void vala_ccode_member_access_set_is_pointer (ValaCCodeMemberAccess* self, gboolean value);
 GType vala_ccode_member_access_get_type (void);
 
+
 G_END_DECLS
 
 #endif
