@@ -24,6 +24,9 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodewriter.h>
 
+
+
+
 struct _ValaCCodeNodePrivate {
 	ValaCCodeLineDirective* _line;
 };
@@ -38,6 +41,7 @@ static gpointer vala_ccode_node_parent_class = NULL;
 static void vala_ccode_node_dispose (GObject * obj);
 
 
+
 /**
  * Writes this code node and all children with the specified C code
  * writer.
@@ -85,6 +89,16 @@ void vala_ccode_node_write_combined (ValaCCodeNode* self, ValaCCodeWriter* write
 }
 
 
+/**
+ * Represents a node in the C code tree.
+ */
+ValaCCodeNode* vala_ccode_node_new (void) {
+	ValaCCodeNode * self;
+	self = g_object_newv (VALA_TYPE_CCODE_NODE, 0, NULL);
+	return self;
+}
+
+
 ValaCCodeLineDirective* vala_ccode_node_get_line (ValaCCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_NODE (self), NULL);
 	return self->priv->_line;
