@@ -25,6 +25,9 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeParenthesizedExpressionPrivate {
 	ValaCCodeExpression* _inner;
 };
@@ -38,11 +41,12 @@ static gpointer vala_ccode_parenthesized_expression_parent_class = NULL;
 static void vala_ccode_parenthesized_expression_dispose (GObject * obj);
 
 
+
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeParenthesizedExpression * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -62,9 +66,9 @@ ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaC
 static void vala_ccode_parenthesized_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeParenthesizedExpression * self;
 	self = VALA_CCODE_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_parenthesized_expression_get_inner (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
 	vala_ccode_writer_write_string (writer, ")");
 }
 
