@@ -46,11 +46,11 @@ typedef struct _ValaCCodeParenthesizedExpressionPrivate ValaCCodeParenthesizedEx
  * Represents a parenthesized expression in the C code.
  */
 struct _ValaCCodeParenthesizedExpression {
-	ValaCCodeExpression parent;
+	ValaCCodeExpression parent_instance;
 	ValaCCodeParenthesizedExpressionPrivate * priv;
 };
 struct _ValaCCodeParenthesizedExpressionClass {
-	ValaCCodeExpressionClass parent;
+	ValaCCodeExpressionClass parent_class;
 };
 
 ValaCCodeParenthesizedExpression* vala_ccode_parenthesized_expression_new (ValaCCodeExpression* expr);
@@ -58,6 +58,7 @@ ValaCCodeExpression* vala_ccode_parenthesized_expression_get_inner (ValaCCodePar
 void vala_ccode_parenthesized_expression_set_inner (ValaCCodeParenthesizedExpression* self, ValaCCodeExpression* value);
 GType vala_ccode_parenthesized_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
