@@ -1,6 +1,6 @@
 /* valaccodereturnstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeReturnStatementPrivate {
 	ValaCCodeExpression* _return_expression;
 };
@@ -39,6 +42,7 @@ static gpointer vala_ccode_return_statement_parent_class = NULL;
 static void vala_ccode_return_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression* expr) {
 	ValaCCodeReturnStatement * self;
 	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
@@ -54,9 +58,9 @@ static void vala_ccode_return_statement_real_write (ValaCCodeNode* base, ValaCCo
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "return");
-	if (vala_ccode_return_statement_get_return_expression (self) != NULL) {
+	if (self->priv->_return_expression != NULL) {
 		vala_ccode_writer_write_string (writer, " ");
-		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_return_statement_get_return_expression (self)), writer);
+		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_return_expression), writer);
 	}
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
