@@ -47,6 +47,7 @@ static void vala_ccode_struct_dispose (GObject * obj);
 
 ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
 	ValaCCodeStruct * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_STRUCT, 0, NULL);
 	vala_ccode_struct_set_name (self, name);
 	return self;
@@ -60,7 +61,7 @@ ValaCCodeStruct* vala_ccode_struct_new (const char* name) {
  */
 void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclaration* decl) {
 	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
-	g_return_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATION (decl));
+	g_return_if_fail (VALA_IS_CCODE_DECLARATION (decl));
 	gee_collection_add (GEE_COLLECTION (self->priv->declarations), decl);
 }
 
@@ -75,6 +76,8 @@ void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name,
 	ValaCCodeDeclaration* decl;
 	ValaCCodeVariableDeclarator* _tmp0;
 	g_return_if_fail (VALA_IS_CCODE_STRUCT (self));
+	g_return_if_fail (type_name != NULL);
+	g_return_if_fail (name != NULL);
 	decl = vala_ccode_declaration_new (type_name);
 	_tmp0 = NULL;
 	vala_ccode_declaration_add_declarator (decl, VALA_CCODE_DECLARATOR ((_tmp0 = vala_ccode_variable_declarator_new (name))));
@@ -87,7 +90,7 @@ void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name,
 static void vala_ccode_struct_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeStruct * self;
 	self = VALA_CCODE_STRUCT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "struct ");
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_begin_block (writer);
