@@ -29,6 +29,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeSwitchStatementPrivate {
 	ValaCCodeExpression* _expression;
 	GeeList* case_statements;
@@ -44,6 +47,7 @@ static gpointer vala_ccode_switch_statement_parent_class = NULL;
 static void vala_ccode_switch_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
@@ -83,7 +87,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "switch (");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_switch_statement_get_expression (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
 	vala_ccode_writer_write_string (writer, ")");
 	vala_ccode_writer_write_begin_block (writer);
 	{
@@ -93,7 +97,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 		case_stmt_it = gee_iterable_iterator (GEE_ITERABLE (case_stmt_collection));
 		while (gee_iterator_next (case_stmt_it)) {
 			ValaCCodeCaseStatement* case_stmt;
-			case_stmt = gee_iterator_get (case_stmt_it);
+			case_stmt = ((ValaCCodeCaseStatement*) gee_iterator_get (case_stmt_it));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (case_stmt), writer);
 				(case_stmt == NULL ? NULL : (case_stmt = (g_object_unref (case_stmt), NULL)));
@@ -112,7 +116,7 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 			stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
 			while (gee_iterator_next (stmt_it)) {
 				ValaCCodeStatement* stmt;
-				stmt = gee_iterator_get (stmt_it);
+				stmt = ((ValaCCodeStatement*) gee_iterator_get (stmt_it));
 				{
 					vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
 					(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
@@ -132,10 +136,12 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 
 
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value) {
+	ValaCCodeExpression* _tmp2;
 	ValaCCodeExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_expression = (_tmp1 = g_object_ref (value), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp1);
+	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_expression == NULL ? NULL : (self->priv->_expression = (g_object_unref (self->priv->_expression), NULL))), _tmp2);
 }
 
 
