@@ -48,11 +48,11 @@ typedef struct _ValaCCodeSwitchStatementPrivate ValaCCodeSwitchStatementPrivate;
  * Represents a switch selection statement in the C code.
  */
 struct _ValaCCodeSwitchStatement {
-	ValaCCodeStatement parent;
+	ValaCCodeStatement parent_instance;
 	ValaCCodeSwitchStatementPrivate * priv;
 };
 struct _ValaCCodeSwitchStatementClass {
-	ValaCCodeStatementClass parent;
+	ValaCCodeStatementClass parent_class;
 };
 
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
@@ -62,6 +62,7 @@ ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitch
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value);
 GType vala_ccode_switch_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
