@@ -23,6 +23,9 @@
 #include <ccode/valaccodetypedefinition.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeTypeDefinitionPrivate {
 	char* _type_name;
 	ValaCCodeDeclarator* _declarator;
@@ -39,9 +42,11 @@ static gpointer vala_ccode_type_definition_parent_class = NULL;
 static void vala_ccode_type_definition_dispose (GObject * obj);
 
 
+
 ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl) {
 	ValaCCodeTypeDefinition * self;
-	g_return_val_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATOR (decl), NULL);
+	g_return_val_if_fail (type != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_DECLARATOR (decl), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_TYPE_DEFINITION, 0, NULL);
 	vala_ccode_type_definition_set_type_name (self, type);
 	vala_ccode_type_definition_set_declarator (self, decl);
@@ -52,19 +57,19 @@ ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaC
 static void vala_ccode_type_definition_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
 static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "typedef ");
-	vala_ccode_writer_write_string (writer, vala_ccode_type_definition_get_type_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, " ");
-	vala_ccode_node_write_declaration (VALA_CCODE_NODE (vala_ccode_type_definition_get_declarator (self)), writer);
+	vala_ccode_node_write_declaration (VALA_CCODE_NODE (self->priv->_declarator), writer);
 	vala_ccode_writer_write_string (writer, ";");
 	vala_ccode_writer_write_newline (writer);
 }
