@@ -1,6 +1,6 @@
 /* valaccodewhilestatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,9 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeWhileStatementPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeStatement* _body;
@@ -41,11 +44,12 @@ static gpointer vala_ccode_while_statement_parent_class = NULL;
 static void vala_ccode_while_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* stmt) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWhileStatement * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -67,12 +71,12 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "while (");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_while_statement_get_condition (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	vala_ccode_writer_write_string (writer, ")");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_while_statement_get_body (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
 }
 
 
