@@ -1,6 +1,6 @@
 /* valaccodewriter.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,9 @@
 #include <glib/gstdio.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeWriterPrivate {
 	gboolean _line_directives;
 	char* _filename;
@@ -47,10 +50,12 @@ static void vala_ccode_writer_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
+
 ValaCCodeWriter* vala_ccode_writer_new (const char* _filename) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWriter * self;
+	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "filename";
@@ -104,7 +109,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			}
 			len = g_mapped_file_get_length (old_file);
 			if (len == g_mapped_file_get_length (new_file)) {
-				if (memcmp (((gpointer) g_mapped_file_get_contents (old_file)), ((gpointer) g_mapped_file_get_contents (new_file)), ((gsize) len)) == 0) {
+				if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), ((gsize) len)) == 0) {
 					changed = FALSE;
 				}
 			}
@@ -142,7 +147,7 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
 	g_return_if_fail (line == NULL || VALA_IS_CCODE_LINE_DIRECTIVE (line));
-	if (vala_ccode_writer_get_line_directives (self) && line != NULL) {
+	if (self->priv->_line_directives && line != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (line), self);
 	}
 	if (!vala_ccode_writer_get_bol (self)) {
@@ -151,7 +156,7 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < self->priv->indent; i++) {
+		for (; i < self->priv->indent; i++) {
 			fputc ('\t', self->priv->stream);
 		}
 	}
@@ -166,6 +171,7 @@ void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirecti
  */
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (s != NULL);
 	fprintf (self->priv->stream, "%s", s);
 	self->priv->_bol = FALSE;
 }
@@ -220,6 +226,7 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	gint lines_length1;
 	char** lines;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	g_return_if_fail (text != NULL);
 	vala_ccode_writer_write_indent (self, NULL);
 	fprintf (self->priv->stream, "/*");
 	first = TRUE;
