@@ -27,6 +27,9 @@
 #include <vala/valasourcefile.h>
 #include <glib/gstdio.h>
 
+
+
+
 enum  {
 	VALA_CCODE_COMPILER_DUMMY_PROPERTY
 };
@@ -35,6 +38,7 @@ static gpointer vala_ccode_compiler_parent_class = NULL;
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 ValaCCodeCompiler* vala_ccode_compiler_new (void) {
 	ValaCCodeCompiler * self;
 	self = g_object_newv (VALA_TYPE_CCODE_COMPILER, 0, NULL);
@@ -46,6 +50,7 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
 	GError * inner_error;
 	char* pc;
 	gint exit_status;
+	g_return_val_if_fail (package_name != NULL, FALSE);
 	inner_error = NULL;
 	pc = g_strconcat ("pkg-config --exists ", package_name, NULL);
 	exit_status = 0;
@@ -98,7 +103,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	GeeCollection* source_files;
 	GeeCollection* c_source_files;
 	g_return_if_fail (VALA_IS_CCODE_COMPILER (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	inner_error = NULL;
 	pc = g_strdup ("pkg-config --cflags");
 	if (!vala_code_context_get_compile_only (context)) {
@@ -220,27 +225,25 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	_tmp16 = NULL;
 	cmdline = (_tmp17 = g_strconcat (cmdline, (_tmp16 = (g_strconcat (" ", pkgflags, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp17);
 	_tmp16 = (g_free (_tmp16), NULL);
-	if (cc_options != NULL) {
-		{
-			char** cc_option_collection;
-			char** cc_option_it;
-			int cc_option_collection_length1;
-			cc_option_collection = cc_options;
-			cc_option_collection_length1 = -1;
-			for (cc_option_it = cc_option_collection; *cc_option_it != NULL; cc_option_it = cc_option_it + 1) {
-				const char* _tmp20;
-				char* cc_option;
-				_tmp20 = NULL;
-				cc_option = (_tmp20 = *cc_option_it, (_tmp20 == NULL ? NULL : g_strdup (_tmp20)));
-				{
-					char* _tmp19;
-					char* _tmp18;
-					_tmp19 = NULL;
-					_tmp18 = NULL;
-					cmdline = (_tmp19 = g_strconcat (cmdline, (_tmp18 = (g_strconcat (" ", cc_option, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp19);
-					_tmp18 = (g_free (_tmp18), NULL);
-					cc_option = (g_free (cc_option), NULL);
-				}
+	{
+		char** cc_option_collection;
+		char** cc_option_it;
+		int cc_option_collection_length1;
+		cc_option_collection = cc_options;
+		cc_option_collection_length1 = -1;
+		for (cc_option_it = cc_option_collection; *cc_option_it != NULL; cc_option_it = cc_option_it + 1) {
+			const char* _tmp20;
+			char* cc_option;
+			_tmp20 = NULL;
+			cc_option = (_tmp20 = *cc_option_it, (_tmp20 == NULL ? NULL : g_strdup (_tmp20)));
+			{
+				char* _tmp19;
+				char* _tmp18;
+				_tmp19 = NULL;
+				_tmp18 = NULL;
+				cmdline = (_tmp19 = g_strconcat (cmdline, (_tmp18 = (g_strconcat (" ", cc_option, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), _tmp19);
+				_tmp18 = (g_free (_tmp18), NULL);
+				cc_option = (g_free (cc_option), NULL);
 			}
 		}
 	}
@@ -267,7 +270,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			ValaSourceFile* file;
 			file = ((ValaSourceFile*) gee_iterator_get (file_it));
 			{
-				if (!vala_source_file_get_pkg (file)) {
+				if (!vala_source_file_get_external_package (file)) {
 					char* _tmp27;
 					char* _tmp26;
 					char* _tmp25;
@@ -338,6 +341,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	}
 	__finally2:
 	;
+	/* remove generated C source and header files */
 	{
 		GeeCollection* file_collection;
 		GeeIterator* file_it;
@@ -347,8 +351,7 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			ValaSourceFile* file;
 			file = ((ValaSourceFile*) gee_iterator_get (file_it));
 			{
-				/* remove generated C source and header files */
-				if (!vala_source_file_get_pkg (file)) {
+				if (!vala_source_file_get_external_package (file)) {
 					if (!vala_code_context_get_save_csources (context)) {
 						char* _tmp32;
 						_tmp32 = NULL;
