@@ -26,9 +26,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valacodegenerator.h>
 #include <vala/valaelementaccess.h>
 #include <gobject/valaccodeexpressionbinding.h>
+#include <gobject/valaccodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -40,8 +40,6 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_ELEMENT_ACCESS_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING))
 #define VALA_CCODE_ELEMENT_ACCESS_BINDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING, ValaCCodeElementAccessBindingClass))
 
-typedef struct _ValaCCodeElementAccessBinding ValaCCodeElementAccessBinding;
-typedef struct _ValaCCodeElementAccessBindingClass ValaCCodeElementAccessBindingClass;
 typedef struct _ValaCCodeElementAccessBindingPrivate ValaCCodeElementAccessBindingPrivate;
 
 /**
@@ -55,7 +53,7 @@ struct _ValaCCodeElementAccessBindingClass {
 	ValaCCodeExpressionBindingClass parent_class;
 };
 
-ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCodeGenerator* codegen, ValaElementAccess* element_access);
+ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCCodeGenerator* codegen, ValaElementAccess* element_access);
 ValaElementAccess* vala_ccode_element_access_binding_get_element_access (ValaCCodeElementAccessBinding* self);
 void vala_ccode_element_access_binding_set_element_access (ValaCCodeElementAccessBinding* self, ValaElementAccess* value);
 GType vala_ccode_element_access_binding_get_type (void);
