@@ -34,6 +34,9 @@
 #include <ccode/valaccodeidentifier.h>
 #include <ccode/valaccodeexpressionstatement.h>
 
+
+
+
 struct _ValaClassRegisterFunctionPrivate {
 	ValaClass* _class_reference;
 };
@@ -57,6 +60,7 @@ static gpointer vala_class_register_function_parent_class = NULL;
 static void vala_class_register_function_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new C function to register the specified class at runtime.
  *
@@ -65,7 +69,7 @@ static void vala_class_register_function_dispose (GObject * obj);
  */
 ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl) {
 	ValaClassRegisterFunction * self;
-	g_return_val_if_fail (cl == NULL || VALA_IS_CLASS (cl), NULL);
+	g_return_val_if_fail (VALA_IS_CLASS (cl), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS_REGISTER_FUNCTION, 0, NULL);
 	vala_class_register_function_set_class_reference (self, cl);
 	return self;
@@ -77,7 +81,7 @@ static ValaTypesymbol* vala_class_register_function_real_get_type_declaration (V
 	ValaClass* _tmp0;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
-	return VALA_TYPESYMBOL ((_tmp0 = vala_class_register_function_get_class_reference (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_class_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
 }
 
 
@@ -88,7 +92,7 @@ static char* vala_class_register_function_real_get_type_struct_name (ValaTypeReg
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%sClass", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_class_reference), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -106,7 +110,7 @@ static char* vala_class_register_function_real_get_class_init_func_name (ValaTyp
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_class_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_class_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -117,7 +121,7 @@ static char* vala_class_register_function_real_get_instance_struct_size (ValaTyp
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (vala_class_register_function_get_class_reference (self)), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("sizeof (%s)", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_class_reference), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -128,21 +132,21 @@ static char* vala_class_register_function_real_get_instance_init_func_name (Vala
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
 static char* vala_class_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (vala_class_get_base_class (vala_class_register_function_get_class_reference (self))), "TYPE_");
+	return vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (vala_class_get_base_class (self->priv->_class_reference)), "TYPE_");
 }
 
 
 static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	if (vala_class_get_is_abstract (vala_class_register_function_get_class_reference (self))) {
+	if (vala_class_get_is_abstract (self->priv->_class_reference)) {
 		return g_strdup ("G_TYPE_FLAG_ABSTRACT");
 	} else {
 		return g_strdup ("0");
@@ -153,7 +157,7 @@ static char* vala_class_register_function_real_get_type_flags (ValaTypeRegisterF
 static ValaSymbolAccessibility vala_class_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return vala_symbol_get_access (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)));
+	return vala_symbol_get_access (VALA_SYMBOL (self->priv->_class_reference));
 }
 
 
@@ -165,7 +169,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 	{
 		GeeCollection* base_type_collection;
 		GeeIterator* base_type_it;
-		base_type_collection = vala_class_get_base_types (vala_class_register_function_get_class_reference (self));
+		base_type_collection = vala_class_get_base_types (self->priv->_class_reference);
 		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
 		while (gee_iterator_next (base_type_it)) {
 			ValaDataType* base_type;
@@ -198,7 +202,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				_tmp5 = NULL;
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp7 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_constant_new ((_tmp5 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL)), (_tmp4 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL)))))))))));
+				vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp7 = vala_ccode_variable_declarator_new_with_initializer (iface_info_name, VALA_CCODE_EXPRESSION ((_tmp6 = vala_ccode_constant_new ((_tmp5 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL)), (_tmp4 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (iface), NULL)))))))))));
 				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
 				(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 				_tmp5 = (g_free (_tmp5), NULL);
@@ -226,7 +230,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 	{
 		GeeCollection* base_type_collection;
 		GeeIterator* base_type_it;
-		base_type_collection = vala_class_get_base_types (vala_class_register_function_get_class_reference (self));
+		base_type_collection = vala_class_get_base_types (self->priv->_class_reference);
 		base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
 		while (gee_iterator_next (base_type_it)) {
 			ValaDataType* base_type;
@@ -263,7 +267,7 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 				_tmp7 = NULL;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
-				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = g_strdup_printf ("%s_type_id", (_tmp5 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_class_register_function_get_class_reference (self)), NULL))))))));
+				vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = g_strdup_printf ("%s_type_id", (_tmp5 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))))))));
 				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
 				_tmp6 = (g_free (_tmp6), NULL);
 				_tmp5 = (g_free (_tmp5), NULL);
