@@ -41,29 +41,34 @@
 #include <ccode/valaccodeifstatement.h>
 #include <ccode/valaccodestatement.h>
 
+
+
+
 struct _ValaTypeRegisterFunctionPrivate {
 	ValaCCodeFragment* declaration_fragment;
 	ValaCCodeFragment* definition_fragment;
 };
-#define VALA_TYPE_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPE_REGISTER_FUNCTION, ValaTypeRegisterFunctionPrivate))
+#define VALA_TYPEREGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionPrivate))
 enum  {
-	VALA_TYPE_REGISTER_FUNCTION_DUMMY_PROPERTY
+	VALA_TYPEREGISTER_FUNCTION_DUMMY_PROPERTY
 };
-static char* vala_type_register_function_real_get_type_flags (ValaTypeRegisterFunction* self);
-static ValaCCodeFragment* vala_type_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self);
-static gpointer vala_type_register_function_parent_class = NULL;
-static void vala_type_register_function_dispose (GObject * obj);
+static char* vala_typeregister_function_real_get_type_flags (ValaTypeRegisterFunction* self);
+static ValaCCodeFragment* vala_typeregister_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self);
+static gpointer vala_typeregister_function_parent_class = NULL;
+static void vala_typeregister_function_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
  * Constructs the C function from the specified type.
  */
-void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self, gboolean plugin) {
+void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self, gboolean plugin) {
 	gboolean fundamental;
-	ValaDataType* _tmp0;
+	ValaTypesymbol* _tmp0;
 	ValaClass* cl;
 	char* _tmp2;
-	ValaDataType* _tmp1;
+	ValaTypesymbol* _tmp1;
 	char* _tmp3;
 	char* type_id_name;
 	ValaCCodeBlock* type_block;
@@ -86,7 +91,7 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	ValaCCodeConstant* _tmp48;
 	char* _tmp47;
 	char* _tmp46;
-	ValaDataType* _tmp45;
+	ValaTypesymbol* _tmp45;
 	ValaCCodeIdentifier* _tmp49;
 	ValaCCodeConstant* _tmp52;
 	char* _tmp51;
@@ -97,17 +102,17 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	ValaCCodeReturnStatement* _tmp65;
 	ValaCCodeIdentifier* _tmp64;
 	ValaCCodeFunction* _tmp66;
-	g_return_if_fail (VALA_IS_TYPE_REGISTER_FUNCTION (self));
+	g_return_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self));
 	fundamental = FALSE;
 	_tmp0 = NULL;
-	cl = (_tmp0 = vala_type_register_function_get_type_declaration (self), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL));
-	if (cl != NULL && vala_class_get_base_class (cl) != NULL && g_utf8_collate (vala_symbol_get_name (VALA_SYMBOL (vala_class_get_base_class (cl))), "TypeInstance") == 0 && g_utf8_collate (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_class_get_base_class (cl)))), "GLib") == 0) {
+	cl = (_tmp0 = vala_typeregister_function_get_type_declaration (self), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL));
+	if (cl != NULL && vala_class_get_base_class (cl) != NULL && _vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (vala_class_get_base_class (cl))), "TypeInstance") == 0 && _vala_strcmp0 (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_class_get_base_class (cl)))), "GLib") == 0) {
 		fundamental = TRUE;
 	}
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	_tmp3 = NULL;
-	type_id_name = (_tmp3 = g_strdup_printf ("%s_type_id", (_tmp2 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp1 = vala_type_register_function_get_type_declaration (self))), NULL))), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 = (g_object_unref (_tmp1), NULL)), _tmp3);
+	type_id_name = (_tmp3 = g_strdup_printf ("%s_type_id", (_tmp2 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp1 = vala_typeregister_function_get_type_declaration (self))), NULL))), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp3);
 	type_block = vala_ccode_block_new ();
 	cdecl_ = vala_ccode_declaration_new ("GType");
 	_tmp5 = NULL;
@@ -126,28 +131,28 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 		ValaCCodeFunction* _tmp9;
 		char* _tmp8;
 		char* _tmp7;
-		ValaDataType* _tmp6;
+		ValaTypesymbol* _tmp6;
 		_tmp9 = NULL;
 		_tmp8 = NULL;
 		_tmp7 = NULL;
 		_tmp6 = NULL;
-		fun = (_tmp9 = vala_ccode_function_new ((_tmp8 = g_strdup_printf ("%s_get_type", (_tmp7 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp6 = vala_type_register_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp9);
-		(_tmp8 = (g_free (_tmp8), NULL));
-		(_tmp7 = (g_free (_tmp7), NULL));
-		(_tmp6 = (g_object_unref (_tmp6), NULL));
+		fun = (_tmp9 = vala_ccode_function_new ((_tmp8 = g_strdup_printf ("%s_get_type", (_tmp7 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp6 = vala_typeregister_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp9);
+		_tmp8 = (g_free (_tmp8), NULL);
+		_tmp7 = (g_free (_tmp7), NULL);
+		(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 		/* Function will not be prototyped anyway */
-		if (vala_type_register_function_get_accessibility (self) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		if (vala_typeregister_function_get_accessibility (self) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 			vala_ccode_function_set_modifiers (fun, VALA_CCODE_MODIFIERS_STATIC);
 		}
 	} else {
 		ValaCCodeFunction* _tmp13;
 		char* _tmp12;
 		char* _tmp11;
-		ValaDataType* _tmp10;
+		ValaTypesymbol* _tmp10;
 		ValaCCodeFormalParameter* _tmp14;
 		char* _tmp17;
 		char* _tmp16;
-		ValaDataType* _tmp15;
+		ValaTypesymbol* _tmp15;
 		ValaCCodeFunction* _tmp18;
 		ValaCCodeFunction* get_fun;
 		ValaCCodeFunction* _tmp19;
@@ -158,10 +163,10 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp12 = NULL;
 		_tmp11 = NULL;
 		_tmp10 = NULL;
-		fun = (_tmp13 = vala_ccode_function_new ((_tmp12 = g_strdup_printf ("%s_register_type", (_tmp11 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp10 = vala_type_register_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp13);
-		(_tmp12 = (g_free (_tmp12), NULL));
-		(_tmp11 = (g_free (_tmp11), NULL));
-		(_tmp10 = (g_object_unref (_tmp10), NULL));
+		fun = (_tmp13 = vala_ccode_function_new ((_tmp12 = g_strdup_printf ("%s_register_type", (_tmp11 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp10 = vala_typeregister_function_get_type_declaration (self))), NULL)))), "GType"), (fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL))), _tmp13);
+		_tmp12 = (g_free (_tmp12), NULL);
+		_tmp11 = (g_free (_tmp11), NULL);
+		(_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL)));
 		_tmp14 = NULL;
 		vala_ccode_function_add_parameter (fun, (_tmp14 = vala_ccode_formal_parameter_new ("module", "GTypeModule *")));
 		(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
@@ -169,13 +174,13 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 		_tmp16 = NULL;
 		_tmp15 = NULL;
 		_tmp18 = NULL;
-		get_fun = (_tmp18 = vala_ccode_function_new ((_tmp17 = g_strdup_printf ("%s_get_type", (_tmp16 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp15 = vala_type_register_function_get_type_declaration (self))), NULL)))), "GType"), (_tmp17 = (g_free (_tmp17), NULL)), (_tmp16 = (g_free (_tmp16), NULL)), (_tmp15 = (g_object_unref (_tmp15), NULL)), _tmp18);
-		if (vala_type_register_function_get_accessibility (self) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
+		get_fun = (_tmp18 = vala_ccode_function_new ((_tmp17 = g_strdup_printf ("%s_get_type", (_tmp16 = vala_symbol_get_lower_case_cname (VALA_SYMBOL ((_tmp15 = vala_typeregister_function_get_type_declaration (self))), NULL)))), "GType"), (_tmp17 = (g_free (_tmp17), NULL)), (_tmp16 = (g_free (_tmp16), NULL)), (_tmp15 == NULL ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL))), _tmp18);
+		if (vala_typeregister_function_get_accessibility (self) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE) {
 			vala_ccode_function_set_modifiers (fun, VALA_CCODE_MODIFIERS_STATIC);
 		}
 		_tmp19 = NULL;
 		vala_ccode_fragment_append (self->priv->declaration_fragment, VALA_CCODE_NODE ((_tmp19 = vala_ccode_function_copy (get_fun))));
-		(_tmp19 = (g_object_unref (_tmp19), NULL));
+		(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
 		_tmp20 = NULL;
 		vala_ccode_function_set_block (get_fun, (_tmp20 = vala_ccode_block_new ()));
 		(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
@@ -198,15 +203,15 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	_tmp25 = NULL;
 	_tmp24 = NULL;
 	_tmp23 = NULL;
-	vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp30 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_info", VALA_CCODE_EXPRESSION ((_tmp29 = vala_ccode_constant_new ((_tmp28 = g_strdup_printf ("{ sizeof (%s), (GBaseInitFunc) %s, (GBaseFinalizeFunc) NULL, (GClassInitFunc) %s, (GClassFinalizeFunc) NULL, NULL, %s, 0, (GInstanceInitFunc) %s }", (_tmp23 = vala_type_register_function_get_type_struct_name (self)), (_tmp24 = vala_type_register_function_get_base_init_func_name (self)), (_tmp25 = vala_type_register_function_get_class_init_func_name (self)), (_tmp26 = vala_type_register_function_get_instance_struct_size (self)), (_tmp27 = vala_type_register_function_get_instance_init_func_name (self)))))))))));
+	vala_ccode_declaration_add_declarator (ctypedecl, VALA_CCODE_DECLARATOR ((_tmp30 = vala_ccode_variable_declarator_new_with_initializer ("g_define_type_info", VALA_CCODE_EXPRESSION ((_tmp29 = vala_ccode_constant_new ((_tmp28 = g_strdup_printf ("{ sizeof (%s), (GBaseInitFunc) %s, (GBaseFinalizeFunc) NULL, (GClassInitFunc) %s, (GClassFinalizeFunc) NULL, NULL, %s, 0, (GInstanceInitFunc) %s }", (_tmp23 = vala_typeregister_function_get_type_struct_name (self)), (_tmp24 = vala_typeregister_function_get_base_init_func_name (self)), (_tmp25 = vala_typeregister_function_get_class_init_func_name (self)), (_tmp26 = vala_typeregister_function_get_instance_struct_size (self)), (_tmp27 = vala_typeregister_function_get_instance_init_func_name (self)))))))))));
 	(_tmp30 == NULL ? NULL : (_tmp30 = (g_object_unref (_tmp30), NULL)));
 	(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
-	(_tmp28 = (g_free (_tmp28), NULL));
-	(_tmp27 = (g_free (_tmp27), NULL));
-	(_tmp26 = (g_free (_tmp26), NULL));
-	(_tmp25 = (g_free (_tmp25), NULL));
-	(_tmp24 = (g_free (_tmp24), NULL));
-	(_tmp23 = (g_free (_tmp23), NULL));
+	_tmp28 = (g_free (_tmp28), NULL);
+	_tmp27 = (g_free (_tmp27), NULL);
+	_tmp26 = (g_free (_tmp26), NULL);
+	_tmp25 = (g_free (_tmp25), NULL);
+	_tmp24 = (g_free (_tmp24), NULL);
+	_tmp23 = (g_free (_tmp23), NULL);
 	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE (ctypedecl));
 	if (fundamental) {
 		ValaCCodeDeclaration* ctypefundamentaldecl;
@@ -223,8 +228,8 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 		(ctypefundamentaldecl == NULL ? NULL : (ctypefundamentaldecl = (g_object_unref (ctypefundamentaldecl), NULL)));
 	}
 	_tmp33 = NULL;
-	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE ((_tmp33 = vala_type_register_function_get_type_interface_init_declaration (self))));
-	(_tmp33 = (g_object_unref (_tmp33), NULL));
+	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE ((_tmp33 = vala_typeregister_function_get_type_interface_init_declaration (self))));
+	(_tmp33 == NULL ? NULL : (_tmp33 = (g_object_unref (_tmp33), NULL)));
 	reg_call = NULL;
 	if (fundamental) {
 		ValaCCodeFunctionCall* _tmp35;
@@ -267,19 +272,19 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 		char* _tmp43;
 		_tmp44 = NULL;
 		_tmp43 = NULL;
-		vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp44 = vala_ccode_identifier_new ((_tmp43 = vala_type_register_function_get_parent_type_name (self))))));
+		vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp44 = vala_ccode_identifier_new ((_tmp43 = vala_typeregister_function_get_parent_type_name (self))))));
 		(_tmp44 == NULL ? NULL : (_tmp44 = (g_object_unref (_tmp44), NULL)));
-		(_tmp43 = (g_free (_tmp43), NULL));
+		_tmp43 = (g_free (_tmp43), NULL);
 	}
 	_tmp48 = NULL;
 	_tmp47 = NULL;
 	_tmp46 = NULL;
 	_tmp45 = NULL;
-	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_constant_new ((_tmp47 = g_strdup_printf ("\"%s\"", (_tmp46 = vala_data_type_get_cname ((_tmp45 = vala_type_register_function_get_type_declaration (self)), FALSE))))))));
+	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_constant_new ((_tmp47 = g_strdup_printf ("\"%s\"", (_tmp46 = vala_typesymbol_get_cname ((_tmp45 = vala_typeregister_function_get_type_declaration (self)), FALSE))))))));
 	(_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL)));
-	(_tmp47 = (g_free (_tmp47), NULL));
-	(_tmp46 = (g_free (_tmp46), NULL));
-	(_tmp45 = (g_object_unref (_tmp45), NULL));
+	_tmp47 = (g_free (_tmp47), NULL);
+	_tmp46 = (g_free (_tmp46), NULL);
+	(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
 	_tmp49 = NULL;
 	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp49 = vala_ccode_identifier_new ("&g_define_type_info"))));
 	(_tmp49 == NULL ? NULL : (_tmp49 = (g_object_unref (_tmp49), NULL)));
@@ -291,9 +296,9 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	}
 	_tmp52 = NULL;
 	_tmp51 = NULL;
-	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp52 = vala_ccode_constant_new ((_tmp51 = vala_type_register_function_get_type_flags (self))))));
+	vala_ccode_function_call_add_argument (reg_call, VALA_CCODE_EXPRESSION ((_tmp52 = vala_ccode_constant_new ((_tmp51 = vala_typeregister_function_get_type_flags (self))))));
 	(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
-	(_tmp51 = (g_free (_tmp51), NULL));
+	_tmp51 = (g_free (_tmp51), NULL);
 	_tmp55 = NULL;
 	_tmp54 = NULL;
 	_tmp53 = NULL;
@@ -302,8 +307,8 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	(_tmp54 == NULL ? NULL : (_tmp54 = (g_object_unref (_tmp54), NULL)));
 	(_tmp53 == NULL ? NULL : (_tmp53 = (g_object_unref (_tmp53), NULL)));
 	_tmp56 = NULL;
-	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE ((_tmp56 = vala_type_register_function_get_type_interface_init_statements (self))));
-	(_tmp56 = (g_object_unref (_tmp56), NULL));
+	vala_ccode_block_add_statement (type_init, VALA_CCODE_NODE ((_tmp56 = vala_typeregister_function_get_type_interface_init_statements (self))));
+	(_tmp56 == NULL ? NULL : (_tmp56 = (g_object_unref (_tmp56), NULL)));
 	if (!plugin) {
 		ValaCCodeIdentifier* _tmp57;
 		ValaCCodeFunctionCall* _tmp58;
@@ -340,11 +345,11 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
 	(_tmp64 == NULL ? NULL : (_tmp64 = (g_object_unref (_tmp64), NULL)));
 	_tmp66 = NULL;
 	vala_ccode_fragment_append (self->priv->declaration_fragment, VALA_CCODE_NODE ((_tmp66 = vala_ccode_function_copy (fun))));
-	(_tmp66 = (g_object_unref (_tmp66), NULL));
+	(_tmp66 == NULL ? NULL : (_tmp66 = (g_object_unref (_tmp66), NULL)));
 	vala_ccode_function_set_block (fun, type_block);
 	vala_ccode_fragment_append (self->priv->definition_fragment, VALA_CCODE_NODE (fun));
 	(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
-	(type_id_name = (g_free (type_id_name), NULL));
+	type_id_name = (g_free (type_id_name), NULL);
 	(type_block == NULL ? NULL : (type_block = (g_object_unref (type_block), NULL)));
 	(cdecl_ == NULL ? NULL : (cdecl_ = (g_object_unref (cdecl_), NULL)));
 	(fun == NULL ? NULL : (fun = (g_object_unref (fun), NULL)));
@@ -359,8 +364,8 @@ void vala_type_register_function_init_from_type (ValaTypeRegisterFunction* self,
  *
  * @return type to be registered
  */
-ValaDataType* vala_type_register_function_get_type_declaration (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_type_declaration (self);
+ValaTypesymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_declaration (self);
 }
 
 
@@ -369,8 +374,8 @@ ValaDataType* vala_type_register_function_get_type_declaration (ValaTypeRegister
  *
  * @return C struct name
  */
-char* vala_type_register_function_get_type_struct_name (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_type_struct_name (self);
+char* vala_typeregister_function_get_type_struct_name (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_struct_name (self);
 }
 
 
@@ -379,8 +384,8 @@ char* vala_type_register_function_get_type_struct_name (ValaTypeRegisterFunction
  *
  * @return C function name
  */
-char* vala_type_register_function_get_base_init_func_name (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_base_init_func_name (self);
+char* vala_typeregister_function_get_base_init_func_name (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_base_init_func_name (self);
 }
 
 
@@ -389,8 +394,8 @@ char* vala_type_register_function_get_base_init_func_name (ValaTypeRegisterFunct
  *
  * @return C function name
  */
-char* vala_type_register_function_get_class_init_func_name (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_class_init_func_name (self);
+char* vala_typeregister_function_get_class_init_func_name (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_class_init_func_name (self);
 }
 
 
@@ -399,8 +404,8 @@ char* vala_type_register_function_get_class_init_func_name (ValaTypeRegisterFunc
  *
  * @return C instance struct size
  */
-char* vala_type_register_function_get_instance_struct_size (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_instance_struct_size (self);
+char* vala_typeregister_function_get_instance_struct_size (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_struct_size (self);
 }
 
 
@@ -409,8 +414,8 @@ char* vala_type_register_function_get_instance_struct_size (ValaTypeRegisterFunc
  *
  * @return C function name
  */
-char* vala_type_register_function_get_instance_init_func_name (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_instance_init_func_name (self);
+char* vala_typeregister_function_get_instance_init_func_name (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_instance_init_func_name (self);
 }
 
 
@@ -419,8 +424,8 @@ char* vala_type_register_function_get_instance_init_func_name (ValaTypeRegisterF
  *
  * @return C parent type name
  */
-char* vala_type_register_function_get_parent_type_name (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_parent_type_name (self);
+char* vala_typeregister_function_get_parent_type_name (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_parent_type_name (self);
 }
 
 
@@ -429,14 +434,14 @@ char* vala_type_register_function_get_parent_type_name (ValaTypeRegisterFunction
  *
  * @return type flags
  */
-static char* vala_type_register_function_real_get_type_flags (ValaTypeRegisterFunction* self) {
-	g_return_val_if_fail (VALA_IS_TYPE_REGISTER_FUNCTION (self), NULL);
+static char* vala_typeregister_function_real_get_type_flags (ValaTypeRegisterFunction* self) {
+	g_return_val_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self), NULL);
 	return g_strdup ("0");
 }
 
 
-char* vala_type_register_function_get_type_flags (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_type_flags (self);
+char* vala_typeregister_function_get_type_flags (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_flags (self);
 }
 
 
@@ -445,14 +450,14 @@ char* vala_type_register_function_get_type_flags (ValaTypeRegisterFunction* self
  *
  * @return C declarations
  */
-static ValaCCodeFragment* vala_type_register_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self) {
-	g_return_val_if_fail (VALA_IS_TYPE_REGISTER_FUNCTION (self), NULL);
+static ValaCCodeFragment* vala_typeregister_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self) {
+	g_return_val_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self), NULL);
 	return vala_ccode_fragment_new ();
 }
 
 
-ValaCCodeFragment* vala_type_register_function_get_type_interface_init_declaration (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_declaration (self);
+ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_declaration (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_declaration (self);
 }
 
 
@@ -461,8 +466,8 @@ ValaCCodeFragment* vala_type_register_function_get_type_interface_init_declarati
  *
  * @return C statements
  */
-ValaCCodeFragment* vala_type_register_function_get_type_interface_init_statements (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_statements (self);
+ValaCCodeFragment* vala_typeregister_function_get_type_interface_init_statements (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_interface_init_statements (self);
 }
 
 
@@ -471,9 +476,9 @@ ValaCCodeFragment* vala_type_register_function_get_type_interface_init_statement
  *
  * @return C function declaration fragment
  */
-ValaCCodeFragment* vala_type_register_function_get_declaration (ValaTypeRegisterFunction* self) {
+ValaCCodeFragment* vala_typeregister_function_get_declaration (ValaTypeRegisterFunction* self) {
 	ValaCCodeFragment* _tmp0;
-	g_return_val_if_fail (VALA_IS_TYPE_REGISTER_FUNCTION (self), NULL);
+	g_return_val_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self), NULL);
 	_tmp0 = NULL;
 	return (_tmp0 = self->priv->declaration_fragment, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
@@ -484,9 +489,9 @@ ValaCCodeFragment* vala_type_register_function_get_declaration (ValaTypeRegister
  *
  * @return C function definition fragment
  */
-ValaCCodeFragment* vala_type_register_function_get_definition (ValaTypeRegisterFunction* self) {
+ValaCCodeFragment* vala_typeregister_function_get_definition (ValaTypeRegisterFunction* self) {
 	ValaCCodeFragment* _tmp0;
-	g_return_val_if_fail (VALA_IS_TYPE_REGISTER_FUNCTION (self), NULL);
+	g_return_val_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self), NULL);
 	_tmp0 = NULL;
 	return (_tmp0 = self->priv->definition_fragment, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
@@ -495,43 +500,64 @@ ValaCCodeFragment* vala_type_register_function_get_definition (ValaTypeRegisterF
 /**
  * Returns the accessibility for this type.
  */
-ValaSymbolAccessibility vala_type_register_function_get_accessibility (ValaTypeRegisterFunction* self) {
-	return VALA_TYPE_REGISTER_FUNCTION_GET_CLASS (self)->get_accessibility (self);
+ValaSymbolAccessibility vala_typeregister_function_get_accessibility (ValaTypeRegisterFunction* self) {
+	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_accessibility (self);
 }
 
 
-static void vala_type_register_function_class_init (ValaTypeRegisterFunctionClass * klass) {
-	vala_type_register_function_parent_class = g_type_class_peek_parent (klass);
+/**
+ * C function to register a type at runtime.
+ */
+ValaTypeRegisterFunction* vala_typeregister_function_new (void) {
+	ValaTypeRegisterFunction * self;
+	self = g_object_newv (VALA_TYPE_TYPEREGISTER_FUNCTION, 0, NULL);
+	return self;
+}
+
+
+static void vala_typeregister_function_class_init (ValaTypeRegisterFunctionClass * klass) {
+	vala_typeregister_function_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaTypeRegisterFunctionPrivate));
-	G_OBJECT_CLASS (klass)->dispose = vala_type_register_function_dispose;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_type_register_function_real_get_type_flags;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_type_register_function_real_get_type_interface_init_declaration;
+	G_OBJECT_CLASS (klass)->dispose = vala_typeregister_function_dispose;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_flags = vala_typeregister_function_real_get_type_flags;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_declaration = vala_typeregister_function_real_get_type_interface_init_declaration;
 }
 
 
-static void vala_type_register_function_init (ValaTypeRegisterFunction * self) {
-	self->priv = VALA_TYPE_REGISTER_FUNCTION_GET_PRIVATE (self);
+static void vala_typeregister_function_init (ValaTypeRegisterFunction * self) {
+	self->priv = VALA_TYPEREGISTER_FUNCTION_GET_PRIVATE (self);
 	self->priv->declaration_fragment = vala_ccode_fragment_new ();
 	self->priv->definition_fragment = vala_ccode_fragment_new ();
 }
 
 
-static void vala_type_register_function_dispose (GObject * obj) {
+static void vala_typeregister_function_dispose (GObject * obj) {
 	ValaTypeRegisterFunction * self;
-	self = VALA_TYPE_REGISTER_FUNCTION (obj);
+	self = VALA_TYPEREGISTER_FUNCTION (obj);
 	(self->priv->declaration_fragment == NULL ? NULL : (self->priv->declaration_fragment = (g_object_unref (self->priv->declaration_fragment), NULL)));
 	(self->priv->definition_fragment == NULL ? NULL : (self->priv->definition_fragment = (g_object_unref (self->priv->definition_fragment), NULL)));
-	G_OBJECT_CLASS (vala_type_register_function_parent_class)->dispose (obj);
+	G_OBJECT_CLASS (vala_typeregister_function_parent_class)->dispose (obj);
 }
 
 
-GType vala_type_register_function_get_type (void) {
-	static GType vala_type_register_function_type_id = 0;
-	if (G_UNLIKELY (vala_type_register_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_type_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeRegisterFunction), 0, (GInstanceInitFunc) vala_type_register_function_init };
-		vala_type_register_function_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaTypeRegisterFunction", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+GType vala_typeregister_function_get_type (void) {
+	static GType vala_typeregister_function_type_id = 0;
+	if (G_UNLIKELY (vala_typeregister_function_type_id == 0)) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeregister_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeRegisterFunction), 0, (GInstanceInitFunc) vala_typeregister_function_init };
+		vala_typeregister_function_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaTypeRegisterFunction", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
-	return vala_type_register_function_type_id;
+	return vala_typeregister_function_type_id;
+}
+
+
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
 }
 
 
