@@ -25,6 +25,10 @@ topbuilddir=$builddir/..
 srcdir=`dirname $0`
 topsrcdir=$srcdir/..
 vapidir=$topsrcdir/vapi
+exe=$EXEEXT
+
+# make sure we detect failed test cases
+set -o pipefail
 
 export G_DEBUG=fatal_warnings
 
@@ -44,14 +48,14 @@ do
 		CODE=1
 		continue
 	fi
-	if ! $CC $CFLAGS $(pkg-config --cflags --libs gobject-2.0) -o $testbuild $testbuild.c $LDLIBS > $testbuild.err 2>&1
+	if ! $CC $CFLAGS $testbuild.c $(pkg-config --cflags --libs gobject-2.0) -o $testbuild $LDLIBS > $testbuild.err 2>&1
 	then
 		CODE=1
 		continue
 	fi
-	if ./$testbuild | tee $testbuild.err | cmp -s $testsrc.exp
+	if ./$testbuild 2>&1 | tee $testbuild.err | cmp -s $testsrc.exp
 	then
-		rm $testbuild.c $testbuild.h $testbuild $testbuild.err
+		rm $testbuild.c $testbuild.h $testbuild$exe $testbuild.err
 	else
 		CODE=1
 	fi
