@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaAddressofExpressionPrivate {
 	ValaExpression* _inner;
 };
@@ -33,11 +36,13 @@ enum  {
 	VALA_ADDRESSOF_EXPRESSION_INNER
 };
 static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_addressof_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_addressof_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_addressof_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_addressof_expression_parent_class = NULL;
 static void vala_addressof_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new address-of expression.
  *
@@ -52,7 +57,10 @@ ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, V
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_ADDRESSOF_EXPRESSION, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
@@ -73,17 +81,24 @@ static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeV
 }
 
 
-static void vala_addressof_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
+static void vala_addressof_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_addressof_expression_get_inner (self)) == old_node) {
-		vala_addressof_expression_set_inner (self, VALA_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
+	if (vala_addressof_expression_get_inner (self) == old_node) {
+		vala_addressof_expression_set_inner (self, new_node);
 	}
 }
 
 
+static gboolean vala_addressof_expression_real_is_pure (ValaExpression* base) {
+	ValaAddressofExpression * self;
+	self = VALA_ADDRESSOF_EXPRESSION (base);
+	return vala_expression_is_pure (vala_addressof_expression_get_inner (self));
+}
+
+
 ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* self) {
 	g_return_val_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self), NULL);
 	return self->priv->_inner;
@@ -91,10 +106,12 @@ ValaExpression* vala_addressof_expression_get_inner (ValaAddressofExpression* se
 
 
 void vala_addressof_expression_set_inner (ValaAddressofExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
@@ -134,7 +151,8 @@ static void vala_addressof_expression_class_init (ValaAddressofExpressionClass *
 	G_OBJECT_CLASS (klass)->set_property = vala_addressof_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_addressof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_addressof_expression_real_accept;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_addressof_expression_real_replace;
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_addressof_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_addressof_expression_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ADDRESSOF_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
