@@ -1,6 +1,6 @@
 /* valaarraycreationexpression.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  * 	Jürg Billeter <j@bitron.ch>
  */
 
@@ -29,6 +29,7 @@
 #include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -46,24 +47,25 @@ typedef struct _ValaArrayCreationExpressionPrivate ValaArrayCreationExpressionPr
  * Represents an array creation expression e.g. "new int[] {1,2,3}".
  */
 struct _ValaArrayCreationExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaArrayCreationExpressionPrivate * priv;
 };
 struct _ValaArrayCreationExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size);
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self);
-ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
-ValaTypeReference* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self);
-void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaTypeReference* value);
+ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference);
+ValaDataType* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self);
+void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaDataType* value);
 gint vala_array_creation_expression_get_rank (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_rank (ValaArrayCreationExpression* self, gint value);
 ValaInitializerList* vala_array_creation_expression_get_initializer_list (ValaArrayCreationExpression* self);
 void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpression* self, ValaInitializerList* value);
 GType vala_array_creation_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
