@@ -46,16 +46,17 @@ typedef struct _ValaArrayMoveMethodPrivate ValaArrayMoveMethodPrivate;
  * Represents the Array.move method.
  */
 struct _ValaArrayMoveMethod {
-	ValaMethod parent;
+	ValaMethod parent_instance;
 	ValaArrayMoveMethodPrivate * priv;
 };
 struct _ValaArrayMoveMethodClass {
-	ValaMethodClass parent;
+	ValaMethodClass parent_class;
 };
 
 ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference);
 GType vala_array_move_method_get_type (void);
 
+
 G_END_DECLS
 
 #endif
