@@ -61,7 +61,7 @@ static ValaDataType* vala_array_type_real_copy (ValaDataType* base);
 static char* vala_array_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
 static gboolean vala_array_type_real_is_array (ValaDataType* base);
 static char* vala_array_type_real_to_string (ValaCodeNode* base);
-static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static gboolean vala_array_type_real_is_reference_type_or_type_parameter (ValaDataType* base);
 static gpointer vala_array_type_parent_class = NULL;
 static void vala_array_type_dispose (GObject * obj);
@@ -73,7 +73,7 @@ ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaS
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArrayType * self;
-	g_return_val_if_fail (element_type == NULL || VALA_IS_DATA_TYPE (element_type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
@@ -99,6 +99,7 @@ ValaArrayType* vala_array_type_new (ValaDataType* element_type, gint rank, ValaS
 static ValaSymbol* vala_array_type_real_get_member (ValaDataType* base, const char* member_name) {
 	ValaArrayType * self;
 	self = VALA_ARRAY_TYPE (base);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	if (_vala_strcmp0 (member_name, "length") == 0) {
 		return VALA_SYMBOL (vala_array_type_get_length_field (self));
 	} else {
@@ -242,11 +243,8 @@ static ValaDataType* vala_array_type_real_copy (ValaDataType* base) {
 	result = vala_array_type_new (self->priv->_element_type, self->priv->_rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
 	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_out (VALA_DATA_TYPE (result), vala_data_type_get_is_out (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
-	vala_data_type_set_requires_null_check (VALA_DATA_TYPE (result), vala_data_type_get_requires_null_check (VALA_DATA_TYPE (self)));
 	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_ref (VALA_DATA_TYPE (result), vala_data_type_get_is_ref (VALA_DATA_TYPE (self)));
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -299,22 +297,22 @@ static char* vala_array_type_real_to_string (ValaCodeNode* base) {
 }
 
 
-static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaArrayType * self;
 	ValaAttribute* _tmp0;
 	gboolean _tmp1;
 	ValaArrayType* _tmp5;
 	ValaDataType* _tmp4;
 	ValaArrayType* target_array_type;
-	gboolean _tmp9;
+	gboolean _tmp8;
 	self = VALA_ARRAY_TYPE (base);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	_tmp0 = NULL;
 	if ((_tmp1 = VALA_IS_POINTER_TYPE (target_type) || (vala_data_type_get_data_type (target_type) != NULL && (_tmp0 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
+		/* any array type can be cast to a generic pointer */
 		return TRUE;
 	}
-	/* any array type can be cast to a generic pointer 
-	 temporarily ignore type parameters */
+	/* temporarily ignore type parameters */
 	if (vala_data_type_get_type_parameter (target_type) != NULL) {
 		return TRUE;
 	}
@@ -325,19 +323,14 @@ static gboolean vala_array_type_real_compatible (ValaDataType* base, ValaDataTyp
 		gboolean _tmp6;
 		return (_tmp6 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp6);
 	}
-	if (vala_data_type_compatible (self->priv->_element_type, target_array_type->priv->_element_type, TRUE) && vala_data_type_compatible (target_array_type->priv->_element_type, self->priv->_element_type, TRUE)) {
-		gboolean _tmp8;
-		if (vala_data_type_get_requires_null_check (VALA_DATA_TYPE (self)) && !vala_data_type_get_nullable (target_type)) {
-			gboolean _tmp7;
-			return (_tmp7 = !enable_non_null, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp7);
-		}
-		return (_tmp8 = TRUE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp8);
+	if (vala_data_type_compatible (self->priv->_element_type, target_array_type->priv->_element_type) && vala_data_type_compatible (target_array_type->priv->_element_type, self->priv->_element_type)) {
+		gboolean _tmp7;
+		return (_tmp7 = TRUE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp7);
 	}
-	return (_tmp9 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp9);
+	return (_tmp8 = FALSE, (target_array_type == NULL ? NULL : (target_array_type = (g_object_unref (target_array_type), NULL))), _tmp8);
 }
 
 
-/* incompatibility between null and non-null types*/
 static gboolean vala_array_type_real_is_reference_type_or_type_parameter (ValaDataType* base) {
 	ValaArrayType * self;
 	self = VALA_ARRAY_TYPE (base);
