@@ -27,6 +27,7 @@
 #include <glib-object.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -40,6 +41,8 @@ G_BEGIN_DECLS
 
 typedef struct _ValaAssignmentPrivate ValaAssignmentPrivate;
 
+#define VALA_TYPE_ASSIGNMENT_OPERATOR (vala_assignment_operator_get_type ())
+
 /**
  * Represents an assignment expression in the source code.
  *
@@ -53,6 +56,7 @@ struct _ValaAssignmentClass {
 	ValaExpressionClass parent_class;
 };
 typedef enum  {
+	VALA_ASSIGNMENT_OPERATOR_NONE,
 	VALA_ASSIGNMENT_OPERATOR_SIMPLE,
 	VALA_ASSIGNMENT_OPERATOR_BITWISE_OR,
 	VALA_ASSIGNMENT_OPERATOR_BITWISE_AND,
@@ -66,6 +70,7 @@ typedef enum  {
 	VALA_ASSIGNMENT_OPERATOR_SHIFT_RIGHT
 } ValaAssignmentOperator;
 
+
 ValaAssignment* vala_assignment_new (ValaExpression* left, ValaExpression* right, ValaAssignmentOperator operator, ValaSourceReference* source_reference);
 ValaExpression* vala_assignment_get_left (ValaAssignment* self);
 void vala_assignment_set_left (ValaAssignment* self, ValaExpression* value);
@@ -74,6 +79,8 @@ void vala_assignment_set_operator (ValaAssignment* self, ValaAssignmentOperator
 ValaExpression* vala_assignment_get_right (ValaAssignment* self);
 void vala_assignment_set_right (ValaAssignment* self, ValaExpression* value);
 GType vala_assignment_get_type (void);
+GType vala_assignment_operator_get_type (void);
+
 
 G_END_DECLS
 
