@@ -25,14 +25,15 @@
 #include <gee/collection.h>
 #include <vala/valanamedargument.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaliteralexpression.h>
-#include <vala/valaliteral.h>
 #include <vala/valastringliteral.h>
 #include <vala/valaintegerliteral.h>
 #include <vala/valarealliteral.h>
 #include <vala/valaunaryexpression.h>
 #include <vala/valabooleanliteral.h>
 
+
+
+
 struct _ValaAttributePrivate {
 	char* _name;
 };
@@ -46,6 +47,7 @@ static void vala_attribute_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new attribute.
  *
@@ -55,6 +57,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference) {
 	ValaAttribute * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ATTRIBUTE, 0, NULL);
 	vala_attribute_set_name (self, name);
@@ -70,7 +73,7 @@ ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source
  */
 void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg) {
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
-	g_return_if_fail (arg == NULL || VALA_IS_NAMED_ARGUMENT (arg));
+	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (arg));
 	gee_collection_add (GEE_COLLECTION (self->args), arg);
 }
 
@@ -83,6 +86,8 @@ void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg) {
  */
 gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -92,7 +97,6 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 			ValaNamedArgument* arg;
 			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					gboolean _tmp0;
 					return (_tmp0 = TRUE, (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp0);
@@ -114,6 +118,8 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
  */
 char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -123,20 +129,19 @@ char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
 			ValaNamedArgument* arg;
 			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
-					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* _tmp0;
-						ValaLiteral* lit;
-						_tmp0 = NULL;
-						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-						if (VALA_IS_STRING_LITERAL (lit)) {
-							char* _tmp1;
-							_tmp1 = NULL;
-							return (_tmp1 = vala_string_literal_eval ((VALA_STRING_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
-						}
-						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
+					ValaStringLiteral* _tmp1;
+					ValaExpression* _tmp0;
+					ValaStringLiteral* lit;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_STRING_LITERAL (_tmp0) ? ((ValaStringLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (lit != NULL) {
+						char* _tmp2;
+						_tmp2 = NULL;
+						return (_tmp2 = vala_string_literal_eval (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
 					}
+					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
@@ -155,6 +160,8 @@ char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
  */
 gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0);
+	g_return_val_if_fail (name != NULL, 0);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -164,19 +171,18 @@ gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
 			ValaNamedArgument* arg;
 			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
-					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* _tmp0;
-						ValaLiteral* lit;
-						_tmp0 = NULL;
-						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-						if (VALA_IS_INTEGER_LITERAL (lit)) {
-							gint _tmp1;
-							return (_tmp1 = atoi (vala_integer_literal_get_value ((VALA_INTEGER_LITERAL (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
-						}
-						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
+					ValaIntegerLiteral* _tmp1;
+					ValaExpression* _tmp0;
+					ValaIntegerLiteral* lit;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_INTEGER_LITERAL (_tmp0) ? ((ValaIntegerLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (lit != NULL) {
+						gint _tmp2;
+						return (_tmp2 = atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
 					}
+					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
@@ -195,6 +201,8 @@ gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
  */
 double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0.0);
+	g_return_val_if_fail (name != NULL, 0.0);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -204,48 +212,49 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 			ValaNamedArgument* arg;
 			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
-					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* _tmp0;
-						ValaLiteral* lit;
+					if (VALA_IS_REAL_LITERAL (vala_named_argument_get_argument (arg))) {
+						ValaRealLiteral* _tmp0;
+						ValaRealLiteral* lit;
+						double _tmp1;
 						_tmp0 = NULL;
-						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-						if (VALA_IS_REAL_LITERAL (lit)) {
-							double _tmp1;
-							return (_tmp1 = strtod (vala_real_literal_get_value ((VALA_REAL_LITERAL (lit))), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
-						} else {
-							if (VALA_IS_INTEGER_LITERAL (lit)) {
-								gint _tmp2;
-								return ((double) (_tmp2 = atoi (vala_integer_literal_get_value ((VALA_INTEGER_LITERAL (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2));
-							}
-						}
-						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
+						lit = (_tmp0 = VALA_REAL_LITERAL (vala_named_argument_get_argument (arg)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+						return (_tmp1 = strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
 					} else {
-						if (VALA_IS_UNARY_EXPRESSION (vala_named_argument_get_argument (arg))) {
-							ValaUnaryExpression* _tmp3;
-							ValaUnaryExpression* unary;
-							_tmp3 = NULL;
-							unary = (_tmp3 = VALA_UNARY_EXPRESSION (vala_named_argument_get_argument (arg)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
-							if (vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_MINUS) {
-								if (VALA_IS_LITERAL_EXPRESSION (vala_unary_expression_get_inner (unary))) {
-									ValaLiteral* _tmp4;
-									ValaLiteral* lit;
-									_tmp4 = NULL;
-									lit = (_tmp4 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_unary_expression_get_inner (unary)))), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
-									if (VALA_IS_REAL_LITERAL (lit)) {
-										double _tmp5;
-										return (_tmp5 = -strtod (vala_real_literal_get_value ((VALA_REAL_LITERAL (lit))), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp5);
+						if (VALA_IS_INTEGER_LITERAL (vala_named_argument_get_argument (arg))) {
+							ValaIntegerLiteral* _tmp2;
+							ValaIntegerLiteral* lit;
+							gint _tmp3;
+							_tmp2 = NULL;
+							lit = (_tmp2 = VALA_INTEGER_LITERAL (vala_named_argument_get_argument (arg)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+							return ((double) (_tmp3 = atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp3));
+						} else {
+							if (VALA_IS_UNARY_EXPRESSION (vala_named_argument_get_argument (arg))) {
+								ValaUnaryExpression* _tmp4;
+								ValaUnaryExpression* unary;
+								_tmp4 = NULL;
+								unary = (_tmp4 = VALA_UNARY_EXPRESSION (vala_named_argument_get_argument (arg)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+								if (vala_unary_expression_get_operator (unary) == VALA_UNARY_OPERATOR_MINUS) {
+									if (VALA_IS_REAL_LITERAL (vala_unary_expression_get_inner (unary))) {
+										ValaRealLiteral* _tmp5;
+										ValaRealLiteral* lit;
+										double _tmp6;
+										_tmp5 = NULL;
+										lit = (_tmp5 = VALA_REAL_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
+										return (_tmp6 = -strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp6);
 									} else {
-										if (VALA_IS_INTEGER_LITERAL (lit)) {
-											gint _tmp6;
-											return ((double) (_tmp6 = -atoi (vala_integer_literal_get_value ((VALA_INTEGER_LITERAL (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp6));
+										if (VALA_IS_INTEGER_LITERAL (vala_unary_expression_get_inner (unary))) {
+											ValaIntegerLiteral* _tmp7;
+											ValaIntegerLiteral* lit;
+											gint _tmp8;
+											_tmp7 = NULL;
+											lit = (_tmp7 = VALA_INTEGER_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
+											return ((double) (_tmp8 = -atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp8));
 										}
 									}
-									(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 								}
+								(unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL)));
 							}
-							(unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL)));
 						}
 					}
 				}
@@ -266,6 +275,8 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
  */
 gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -275,19 +286,18 @@ gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name) {
 			ValaNamedArgument* arg;
 			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
-					if (VALA_IS_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg))) {
-						ValaLiteral* _tmp0;
-						ValaLiteral* lit;
-						_tmp0 = NULL;
-						lit = (_tmp0 = vala_literal_expression_get_literal ((VALA_LITERAL_EXPRESSION (vala_named_argument_get_argument (arg)))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-						if (VALA_IS_BOOLEAN_LITERAL (lit)) {
-							gboolean _tmp1;
-							return (_tmp1 = vala_boolean_literal_get_value ((VALA_BOOLEAN_LITERAL (lit))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
-						}
-						(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
+					ValaBooleanLiteral* _tmp1;
+					ValaExpression* _tmp0;
+					ValaBooleanLiteral* lit;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_BOOLEAN_LITERAL (_tmp0) ? ((ValaBooleanLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (lit != NULL) {
+						gboolean _tmp2;
+						return (_tmp2 = vala_boolean_literal_get_value (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
 					}
+					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
