@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALABASEACCESS_H__
-#define __VALABASEACCESS_H__
+#ifndef __VALA_VALABASEACCESS_H__
+#define __VALA_VALABASEACCESS_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,16 +46,17 @@ typedef struct _ValaBaseAccessPrivate ValaBaseAccessPrivate;
  * Represents an access to base class members in the source code.
  */
 struct _ValaBaseAccess {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaBaseAccessPrivate * priv;
 };
 struct _ValaBaseAccessClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaBaseAccess* vala_base_access_new (ValaSourceReference* source);
 GType vala_base_access_get_type (void);
 
+
 G_END_DECLS
 
 #endif
