@@ -65,14 +65,14 @@ ValaBasicBlock* vala_basic_block_new_exit (void) {
 
 void vala_basic_block_add_node (ValaBasicBlock* self, ValaCodeNode* node) {
 	g_return_if_fail (VALA_IS_BASIC_BLOCK (self));
-	g_return_if_fail (node == NULL || VALA_IS_CODE_NODE (node));
+	g_return_if_fail (VALA_IS_CODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->nodes), node);
 }
 
 
 void vala_basic_block_connect (ValaBasicBlock* self, ValaBasicBlock* target) {
 	g_return_if_fail (VALA_IS_BASIC_BLOCK (self));
-	g_return_if_fail (target == NULL || VALA_IS_BASIC_BLOCK (target));
+	g_return_if_fail (VALA_IS_BASIC_BLOCK (target));
 	if (!gee_collection_contains (GEE_COLLECTION (self->priv->successors), target)) {
 		gee_collection_add (GEE_COLLECTION (self->priv->successors), target);
 	}
