@@ -42,6 +42,8 @@ G_BEGIN_DECLS
 
 typedef struct _ValaBinaryExpressionPrivate ValaBinaryExpressionPrivate;
 
+#define VALA_TYPE_BINARY_OPERATOR (vala_binary_operator_get_type ())
+
 /**
  * Represents an expression with two operands in the source code.
  *
@@ -55,6 +57,7 @@ struct _ValaBinaryExpressionClass {
 	ValaExpressionClass parent_class;
 };
 typedef enum  {
+	VALA_BINARY_OPERATOR_NONE,
 	VALA_BINARY_OPERATOR_PLUS,
 	VALA_BINARY_OPERATOR_MINUS,
 	VALA_BINARY_OPERATOR_MUL,
@@ -76,6 +79,7 @@ typedef enum  {
 	VALA_BINARY_OPERATOR_IN
 } ValaBinaryOperator;
 
+
 ValaBinaryExpression* vala_binary_expression_new (ValaBinaryOperator op, ValaExpression* _left, ValaExpression* _right, ValaSourceReference* source);
 ValaBinaryOperator vala_binary_expression_get_operator (ValaBinaryExpression* self);
 void vala_binary_expression_set_operator (ValaBinaryExpression* self, ValaBinaryOperator value);
@@ -84,6 +88,8 @@ void vala_binary_expression_set_left (ValaBinaryExpression* self, ValaExpression
 ValaExpression* vala_binary_expression_get_right (ValaBinaryExpression* self);
 void vala_binary_expression_set_right (ValaBinaryExpression* self, ValaExpression* value);
 GType vala_binary_expression_get_type (void);
+GType vala_binary_operator_get_type (void);
+
 
 G_END_DECLS
 
