@@ -1,6 +1,6 @@
 /* valabooleanliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaBooleanLiteralPrivate {
 	gboolean _value;
 };
@@ -34,10 +37,12 @@ enum  {
 };
 static void vala_boolean_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_boolean_literal_real_to_string (ValaCodeNode* base);
+static gboolean vala_boolean_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_boolean_literal_parent_class = NULL;
 static void vala_boolean_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new boolean literal.
  *
@@ -47,7 +52,7 @@ static void vala_boolean_literal_dispose (GObject * obj);
  */
 ValaBooleanLiteral* vala_boolean_literal_new (gboolean b, ValaSourceReference* source) {
 	ValaBooleanLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_BOOLEAN_LITERAL, 0, NULL);
 	vala_boolean_literal_set_value (self, b);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -58,7 +63,7 @@ ValaBooleanLiteral* vala_boolean_literal_new (gboolean b, ValaSourceReference* s
 static void vala_boolean_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBooleanLiteral * self;
 	self = VALA_BOOLEAN_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_boolean_literal (visitor, self);
 }
 
@@ -66,7 +71,7 @@ static void vala_boolean_literal_real_accept (ValaCodeNode* base, ValaCodeVisito
 static char* vala_boolean_literal_real_to_string (ValaCodeNode* base) {
 	ValaBooleanLiteral * self;
 	self = VALA_BOOLEAN_LITERAL (base);
-	if (vala_boolean_literal_get_value (self)) {
+	if (self->priv->_value) {
 		return g_strdup ("true");
 	} else {
 		return g_strdup ("false");
@@ -74,6 +79,13 @@ static char* vala_boolean_literal_real_to_string (ValaCodeNode* base) {
 }
 
 
+static gboolean vala_boolean_literal_real_is_pure (ValaExpression* base) {
+	ValaBooleanLiteral * self;
+	self = VALA_BOOLEAN_LITERAL (base);
+	return TRUE;
+}
+
+
 gboolean vala_boolean_literal_get_value (ValaBooleanLiteral* self) {
 	g_return_val_if_fail (VALA_IS_BOOLEAN_LITERAL (self), FALSE);
 	return self->priv->_value;
@@ -122,6 +134,7 @@ static void vala_boolean_literal_class_init (ValaBooleanLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_boolean_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_boolean_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_boolean_literal_real_to_string;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_boolean_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_BOOLEAN_LITERAL_VALUE, g_param_spec_boolean ("value", "value", "value", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
