@@ -44,7 +44,7 @@ static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NU
  */
 ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
 	ValaBreakStatement * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_BREAK_STATEMENT, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
@@ -54,7 +54,7 @@ ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBreakStatement * self;
 	self = VALA_BREAK_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_break_statement (visitor, self);
 }
 
