@@ -1,11 +1,11 @@
 /* valacastexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,16 +20,18 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valacastexpression.h"
-#include <vala/valatypereference.h>
-#include <vala/valasourcereference.h>
 #include <vala/valacastexpression.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaCastExpressionPrivate {
-	ValaTypeReference* _type_reference;
 	gboolean _is_silent_cast;
 	ValaExpression* _inner;
+	ValaDataType* _data_type;
 };
 #define VALA_CAST_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionPrivate))
 enum  {
@@ -39,11 +41,14 @@ enum  {
 	VALA_CAST_EXPRESSION_IS_SILENT_CAST
 };
 static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_cast_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
+static void vala_cast_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
+static gboolean vala_cast_expression_real_is_pure (ValaExpression* base);
+static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_cast_expression_parent_class = NULL;
 static void vala_cast_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new cast expression.
  *
@@ -51,20 +56,25 @@ static void vala_cast_expression_dispose (GObject * obj);
  * @param type  target type
  * @return      newly created cast expression
  */
-ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaTypeReference* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast)
-{
+ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataType* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCastExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type_reference), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 3);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type_reference), __params_it++);
-	(__params_it->name = "is-silent-cast", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, is_silent_cast), __params_it++);
+	__params_it->name = "is-silent-cast";
+	g_value_init (&__params_it->value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&__params_it->value, is_silent_cast);
+	__params_it++;
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CAST_EXPRESSION, __params_it - __params, __params);
+	vala_cast_expression_set_type_reference (self, type_reference);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
 		--__params_it;
@@ -75,10 +85,9 @@ ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaTypeRef
 }
 
 
-static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCastExpression * self;
-	self = ((ValaCastExpression*) base);
+	self = VALA_CAST_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_cast_expression_get_inner (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_cast_expression_get_type_reference (self)), visitor);
@@ -86,67 +95,82 @@ static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisito
 }
 
 
-static void vala_cast_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_cast_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaCastExpression * self;
-	self = ((ValaCastExpression*) base);
-	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
-	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	if (VALA_CODE_NODE (vala_cast_expression_get_inner (self)) == old_node) {
-		vala_cast_expression_set_inner (self, VALA_EXPRESSION (new_node));
+	self = VALA_CAST_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
+	if (vala_cast_expression_get_inner (self) == old_node) {
+		vala_cast_expression_set_inner (self, new_node);
 	}
 }
 
 
-ValaExpression* vala_cast_expression_get_inner (ValaCastExpression* self)
-{
+static gboolean vala_cast_expression_real_is_pure (ValaExpression* base) {
+	ValaCastExpression * self;
+	self = VALA_CAST_EXPRESSION (base);
+	return vala_expression_is_pure (vala_cast_expression_get_inner (self));
+}
+
+
+static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaCastExpression * self;
+	self = VALA_CAST_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_cast_expression_get_type_reference (self) == old_type) {
+		vala_cast_expression_set_type_reference (self, new_type);
+	}
+}
+
+
+ValaExpression* vala_cast_expression_get_inner (ValaCastExpression* self) {
 	g_return_val_if_fail (VALA_IS_CAST_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* value)
-{
+void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
-ValaTypeReference* vala_cast_expression_get_type_reference (ValaCastExpression* self)
-{
+ValaDataType* vala_cast_expression_get_type_reference (ValaCastExpression* self) {
 	g_return_val_if_fail (VALA_IS_CAST_EXPRESSION (self), NULL);
-	return self->priv->_type_reference;
+	return self->priv->_data_type;
 }
 
 
-void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaTypeReference* value)
-{
-	ValaTypeReference* _tmp1;
+void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
-gboolean vala_cast_expression_get_is_silent_cast (ValaCastExpression* self)
-{
+gboolean vala_cast_expression_get_is_silent_cast (ValaCastExpression* self) {
 	g_return_val_if_fail (VALA_IS_CAST_EXPRESSION (self), FALSE);
 	return self->priv->_is_silent_cast;
 }
 
 
-void vala_cast_expression_set_is_silent_cast (ValaCastExpression* self, gboolean value)
-{
+void vala_cast_expression_set_is_silent_cast (ValaCastExpression* self, gboolean value) {
 	g_return_if_fail (VALA_IS_CAST_EXPRESSION (self));
 	self->priv->_is_silent_cast = value;
 }
 
 
-static void vala_cast_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_cast_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (object);
 	switch (property_id) {
@@ -166,8 +190,7 @@ static void vala_cast_expression_get_property (GObject * object, guint property_
 }
 
 
-static void vala_cast_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_cast_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (object);
 	switch (property_id) {
@@ -187,43 +210,37 @@ static void vala_cast_expression_set_property (GObject * object, guint property_
 }
 
 
-static void vala_cast_expression_class_init (ValaCastExpressionClass * klass)
-{
+static void vala_cast_expression_class_init (ValaCastExpressionClass * klass) {
 	vala_cast_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaCastExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_cast_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_cast_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_cast_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_cast_expression_real_accept;
-	VALA_CODE_NODE_CLASS (klass)->replace = vala_cast_expression_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_IS_SILENT_CAST, g_param_spec_boolean ("is-silent-cast", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_cast_expression_real_replace_expression;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_cast_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_cast_expression_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CAST_EXPRESSION_IS_SILENT_CAST, g_param_spec_boolean ("is-silent-cast", "is-silent-cast", "is-silent-cast", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_cast_expression_init (ValaCastExpression * self)
-{
+static void vala_cast_expression_init (ValaCastExpression * self) {
 	self->priv = VALA_CAST_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_cast_expression_dispose (GObject * obj)
-{
+static void vala_cast_expression_dispose (GObject * obj) {
 	ValaCastExpression * self;
-	ValaCastExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_CAST_EXPRESSION (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_CAST_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_CAST_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	G_OBJECT_CLASS (vala_cast_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_cast_expression_get_type (void)
-{
+GType vala_cast_expression_get_type (void) {
 	static GType vala_cast_expression_type_id = 0;
 	if (G_UNLIKELY (vala_cast_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_init };
