@@ -1,6 +1,6 @@
 /* valacharacterliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <vala/valacharacterliteral.h>
@@ -26,6 +26,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valareport.h>
 
+
+
+
 struct _ValaCharacterLiteralPrivate {
 	char* _value;
 };
@@ -35,11 +38,13 @@ enum  {
 	VALA_CHARACTER_LITERAL_VALUE
 };
 static void vala_character_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_character_literal_real_is_pure (ValaExpression* base);
 static GObject * vala_character_literal_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_character_literal_parent_class = NULL;
 static void vala_character_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new character literal.
  *
@@ -51,10 +56,14 @@ ValaCharacterLiteral* vala_character_literal_new (const char* c, ValaSourceRefer
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCharacterLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (c != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "value", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, c), __params_it++);
+	__params_it->name = "value";
+	g_value_init (&__params_it->value, G_TYPE_STRING);
+	g_value_set_string (&__params_it->value, c);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CHARACTER_LITERAL, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	while (__params_it > __params) {
@@ -69,7 +78,7 @@ ValaCharacterLiteral* vala_character_literal_new (const char* c, ValaSourceRefer
 static void vala_character_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCharacterLiteral * self;
 	self = VALA_CHARACTER_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_character_literal (visitor, self);
 }
 
@@ -86,6 +95,13 @@ gunichar vala_character_literal_get_char (ValaCharacterLiteral* self) {
 }
 
 
+static gboolean vala_character_literal_real_is_pure (ValaExpression* base) {
+	ValaCharacterLiteral * self;
+	self = VALA_CHARACTER_LITERAL (base);
+	return TRUE;
+}
+
+
 char* vala_character_literal_get_value (ValaCharacterLiteral* self) {
 	g_return_val_if_fail (VALA_IS_CHARACTER_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -159,6 +175,7 @@ static void vala_character_literal_class_init (ValaCharacterLiteralClass * klass
 	G_OBJECT_CLASS (klass)->constructor = vala_character_literal_constructor;
 	G_OBJECT_CLASS (klass)->dispose = vala_character_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_character_literal_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_character_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CHARACTER_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
@@ -171,7 +188,7 @@ static void vala_character_literal_init (ValaCharacterLiteral * self) {
 static void vala_character_literal_dispose (GObject * obj) {
 	ValaCharacterLiteral * self;
 	self = VALA_CHARACTER_LITERAL (obj);
-	(self->priv->_value = (g_free (self->priv->_value), NULL));
+	self->priv->_value = (g_free (self->priv->_value), NULL);
 	G_OBJECT_CLASS (vala_character_literal_parent_class)->dispose (obj);
 }
 
