@@ -43,18 +43,22 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valaclasstype.h>
 #include <vala/valavoidtype.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
 #include <vala/valareport.h>
-#include <vala/valasourcefile.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valacodegenerator.h>
+
+
+
 
 struct _ValaClassPrivate {
 	ValaClass* _base_class;
 	gboolean _is_abstract;
 	gboolean _is_static;
+	gboolean _has_private_fields;
 	char* cname;
 	char* const_cname;
 	char* lower_case_cprefix;
@@ -68,7 +72,7 @@ struct _ValaClassPrivate {
 	char* marshaller_type_name;
 	char* get_value_function;
 	char* set_value_function;
-	gboolean _has_private_fields;
+	char* type_signature;
 	GeeList* type_parameters;
 	GeeList* base_types;
 	GeeList* constants;
@@ -82,8 +86,9 @@ struct _ValaClassPrivate {
 	GeeList* delegates;
 	ValaMethod* _default_construction_method;
 	ValaConstructor* _constructor;
-	ValaDestructor* _destructor;
+	ValaConstructor* _static_constructor;
 	gboolean _is_error_base;
+	ValaDestructor* _destructor;
 };
 #define VALA_CLASS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CLASS, ValaClassPrivate))
 enum  {
@@ -94,6 +99,7 @@ enum  {
 	VALA_CLASS_HAS_PRIVATE_FIELDS,
 	VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD,
 	VALA_CLASS_CONSTRUCTOR,
+	VALA_CLASS_STATIC_CONSTRUCTOR,
 	VALA_CLASS_DESTRUCTOR,
 	VALA_CLASS_IS_ERROR_BASE
 };
@@ -105,6 +111,7 @@ static char* vala_class_get_lower_case_csuffix (ValaClass* self);
 static char* vala_class_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static char* vala_class_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_class_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix);
+static char* vala_class_real_get_type_signature (ValaTypesymbol* base);
 static gboolean vala_class_real_is_reference_type (ValaTypesymbol* base);
 static void vala_class_process_ccode_attribute (ValaClass* self, ValaAttribute* a);
 static gboolean vala_class_get_has_type_id (ValaClass* self);
@@ -113,6 +120,7 @@ static char* vala_class_real_get_marshaller_type_name (ValaTypesymbol* base);
 static char* vala_class_real_get_get_value_function (ValaTypesymbol* base);
 static char* vala_class_real_get_set_value_function (ValaTypesymbol* base);
 static gboolean vala_class_real_is_reference_counting (ValaTypesymbol* base);
+static gboolean vala_class_is_fundamental (ValaClass* self);
 static char* vala_class_real_get_ref_function (ValaTypesymbol* base);
 static char* vala_class_real_get_unref_function (ValaTypesymbol* base);
 static char* vala_class_real_get_dup_function (ValaTypesymbol* base);
@@ -120,12 +128,15 @@ static char* vala_class_real_get_free_function (ValaTypesymbol* base);
 static gboolean vala_class_real_is_subtype_of (ValaTypesymbol* base, ValaTypesymbol* t);
 static gint vala_class_real_get_type_parameter_index (ValaTypesymbol* base, const char* name);
 static void vala_class_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static ValaCodeBinding* vala_class_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
+static void vala_class_set_has_private_fields (ValaClass* self, gboolean value);
 static gpointer vala_class_parent_class = NULL;
 static void vala_class_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new class.
  *
@@ -135,10 +146,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference) {
 	ValaClass * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -151,7 +163,7 @@ ValaClass* vala_class_new (const char* name, ValaSourceReference* source_referen
  */
 void vala_class_add_base_type (ValaClass* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	gee_collection_add (GEE_COLLECTION (self->priv->base_types), type);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (type), VALA_CODE_NODE (self));
 }
@@ -175,7 +187,7 @@ GeeCollection* vala_class_get_base_types (ValaClass* self) {
  */
 void vala_class_add_type_parameter (ValaClass* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_TYPESYMBOL (self);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
@@ -200,7 +212,7 @@ GeeCollection* vala_class_get_type_parameters (ValaClass* self) {
  */
 void vala_class_add_constant (ValaClass* self, ValaConstant* c) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	g_return_if_fail (VALA_IS_CONSTANT (c));
 	gee_collection_add (GEE_COLLECTION (self->priv->constants), c);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (c)), VALA_SYMBOL (c));
 }
@@ -213,10 +225,10 @@ void vala_class_add_constant (ValaClass* self, ValaConstant* c) {
  */
 void vala_class_add_field (ValaClass* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
 	if (vala_symbol_get_access (VALA_SYMBOL (f)) == VALA_SYMBOL_ACCESSIBILITY_PRIVATE && vala_field_get_instance (f)) {
-		self->priv->_has_private_fields = TRUE;
+		vala_class_set_has_private_fields (self, TRUE);
 	}
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (f)), VALA_SYMBOL (f));
 }
@@ -242,10 +254,13 @@ void vala_class_add_method (ValaClass* self, ValaMethod* m) {
 	GeeCollection* _tmp2;
 	gboolean _tmp3;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	if (vala_method_get_instance (m) || VALA_IS_CREATION_METHOD (m)) {
 		ValaFormalParameter* _tmp1;
 		ValaClassType* _tmp0;
+		if (vala_method_get_this_parameter (m) != NULL) {
+			vala_scope_remove (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))));
+		}
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_class_type_new (self))), NULL)));
@@ -255,14 +270,16 @@ void vala_class_add_method (ValaClass* self, ValaMethod* m) {
 	}
 	_tmp2 = NULL;
 	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size ((_tmp2 = vala_method_get_postconditions (m))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
-		ValaVariableDeclarator* _tmp4;
-		ValaDataType* _tmp5;
-		_tmp4 = NULL;
-		vala_method_set_result_var (m, (_tmp4 = vala_variable_declarator_new ("result", NULL, NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		ValaLocalVariable* _tmp5;
+		ValaDataType* _tmp4;
+		if (vala_method_get_result_var (m) != NULL) {
+			vala_scope_remove (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))));
+		}
 		_tmp5 = NULL;
-		vala_variable_declarator_set_type_reference (vala_method_get_result_var (m), (_tmp5 = vala_data_type_copy (vala_method_get_return_type (m))));
+		_tmp4 = NULL;
+		vala_method_set_result_var (m, (_tmp5 = vala_local_variable_new ((_tmp4 = vala_data_type_copy (vala_method_get_return_type (m))), "result", NULL, NULL)));
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	if (VALA_IS_CREATION_METHOD (m)) {
@@ -319,7 +336,7 @@ void vala_class_add_property (ValaClass* self, ValaProperty* prop, gboolean no_f
 	ValaFormalParameter* _tmp1;
 	ValaClassType* _tmp0;
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	gee_collection_add (GEE_COLLECTION (self->priv->properties), prop);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (prop)), VALA_SYMBOL (prop));
 	_tmp1 = NULL;
@@ -328,7 +345,7 @@ void vala_class_add_property (ValaClass* self, ValaProperty* prop, gboolean no_f
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (prop)), vala_symbol_get_name (VALA_SYMBOL (vala_property_get_this_parameter (prop))), VALA_SYMBOL (vala_property_get_this_parameter (prop)));
-	if (!no_field && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))) {
+	if (!no_field && !vala_symbol_get_external_package (VALA_SYMBOL (self))) {
 		gboolean empty_get;
 		gboolean empty_set;
 		empty_get = (vala_property_get_get_accessor (prop) != NULL && vala_property_accessor_get_body (vala_property_get_get_accessor (prop)) == NULL);
@@ -355,6 +372,7 @@ void vala_class_add_property (ValaClass* self, ValaProperty* prop, gboolean no_f
 			_tmp3 = NULL;
 			f = (_tmp3 = vala_field_new ((_tmp2 = g_strdup_printf ("_%s", vala_symbol_get_name (VALA_SYMBOL (prop)))), field_type, vala_property_get_default_expression (prop), vala_code_node_get_source_reference (VALA_CODE_NODE (prop))), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
 			vala_symbol_set_access (VALA_SYMBOL (f), VALA_SYMBOL_ACCESSIBILITY_PRIVATE);
+			vala_property_set_field (prop, f);
 			vala_class_add_field (self, f);
 			(field_type == NULL ? NULL : (field_type = (g_object_unref (field_type), NULL)));
 			(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
@@ -381,7 +399,7 @@ GeeCollection* vala_class_get_properties (ValaClass* self) {
  */
 void vala_class_add_signal (ValaClass* self, ValaSignal* sig) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	gee_collection_add (GEE_COLLECTION (self->priv->signals), sig);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (sig)), VALA_SYMBOL (sig));
 }
@@ -405,7 +423,7 @@ GeeCollection* vala_class_get_signals (ValaClass* self) {
  */
 void vala_class_add_class (ValaClass* self, ValaClass* cl) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 	gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
 }
@@ -418,7 +436,7 @@ void vala_class_add_class (ValaClass* self, ValaClass* cl) {
  */
 void vala_class_add_struct (ValaClass* self, ValaStruct* st) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 	gee_collection_add (GEE_COLLECTION (self->priv->structs), st);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (st)), VALA_SYMBOL (st));
 }
@@ -431,7 +449,7 @@ void vala_class_add_struct (ValaClass* self, ValaStruct* st) {
  */
 void vala_class_add_enum (ValaClass* self, ValaEnum* en) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	g_return_if_fail (VALA_IS_ENUM (en));
 	gee_collection_add (GEE_COLLECTION (self->priv->enums), en);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (en)), VALA_SYMBOL (en));
 }
@@ -444,7 +462,7 @@ void vala_class_add_enum (ValaClass* self, ValaEnum* en) {
  */
 void vala_class_add_delegate (ValaClass* self, ValaDelegate* d) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	g_return_if_fail (VALA_IS_DELEGATE (d));
 	gee_collection_add (GEE_COLLECTION (self->priv->delegates), d);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (d)), VALA_SYMBOL (d));
 }
@@ -453,7 +471,7 @@ void vala_class_add_delegate (ValaClass* self, ValaDelegate* d) {
 static void vala_class_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_class (visitor, self);
 }
 
@@ -461,7 +479,7 @@ static void vala_class_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_class_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* type_collection;
 		GeeIterator* type_it;
@@ -567,8 +585,11 @@ static void vala_class_real_accept_children (ValaCodeNode* base, ValaCodeVisitor
 		}
 		(sig_it == NULL ? NULL : (sig_it = (g_object_unref (sig_it), NULL)));
 	}
-	if (vala_class_get_constructor (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_class_get_constructor (self)), visitor);
+	if (self->priv->_constructor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_constructor), visitor);
+	}
+	if (self->priv->_static_constructor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_static_constructor), visitor);
 	}
 	if (vala_class_get_destructor (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_class_get_destructor (self)), visitor);
@@ -686,6 +707,7 @@ void vala_class_set_cname (ValaClass* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_CLASS (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -771,6 +793,15 @@ static char* vala_class_real_get_upper_case_cname (ValaTypesymbol* base, const c
 }
 
 
+static char* vala_class_real_get_type_signature (ValaTypesymbol* base) {
+	ValaClass * self;
+	const char* _tmp0;
+	self = VALA_CLASS (base);
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->type_signature, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+}
+
+
 static gboolean vala_class_real_is_reference_type (ValaTypesymbol* base) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
@@ -780,7 +811,7 @@ static gboolean vala_class_real_is_reference_type (ValaTypesymbol* base) {
 
 static void vala_class_process_ccode_attribute (ValaClass* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_CLASS (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "ref_function")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -872,6 +903,11 @@ static void vala_class_process_ccode_attribute (ValaClass* self, ValaAttribute*
 		}
 		val = (g_free (val), NULL);
 	}
+	if (vala_attribute_has_argument (a, "type_signature")) {
+		char* _tmp13;
+		_tmp13 = NULL;
+		self->priv->type_signature = (_tmp13 = vala_attribute_get_string (a, "type_signature"), (self->priv->type_signature = (g_free (self->priv->type_signature), NULL)), _tmp13);
+	}
 }
 
 
@@ -906,7 +942,7 @@ void vala_class_process_attributes (ValaClass* self) {
 
 static gboolean vala_class_get_has_type_id (ValaClass* self) {
 	g_return_val_if_fail (VALA_IS_CLASS (self), FALSE);
-	return self->priv->has_type_id || (vala_class_get_base_class (self) != NULL && vala_class_get_has_type_id (vala_class_get_base_class (self)));
+	return self->priv->has_type_id || (self->priv->_base_class != NULL && vala_class_get_has_type_id (self->priv->_base_class));
 }
 
 
@@ -934,6 +970,7 @@ void vala_class_set_type_id (ValaClass* self, const char* type_id) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_CLASS (self));
+	g_return_if_fail (type_id != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->type_id = (_tmp1 = (_tmp0 = type_id, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->type_id = (g_free (self->priv->type_id), NULL)), _tmp1);
@@ -945,10 +982,10 @@ static char* vala_class_real_get_marshaller_type_name (ValaTypesymbol* base) {
 	const char* _tmp2;
 	self = VALA_CLASS (base);
 	if (self->priv->marshaller_type_name == NULL) {
-		if (vala_class_get_base_class (self) != NULL) {
+		if (self->priv->_base_class != NULL) {
 			char* _tmp0;
 			_tmp0 = NULL;
-			self->priv->marshaller_type_name = (_tmp0 = vala_typesymbol_get_marshaller_type_name (VALA_TYPESYMBOL (vala_class_get_base_class (self))), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), _tmp0);
+			self->priv->marshaller_type_name = (_tmp0 = vala_typesymbol_get_marshaller_type_name (VALA_TYPESYMBOL (self->priv->_base_class)), (self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL)), _tmp0);
 		} else {
 			char* _tmp1;
 			_tmp1 = NULL;
@@ -965,10 +1002,10 @@ static char* vala_class_real_get_get_value_function (ValaTypesymbol* base) {
 	const char* _tmp2;
 	self = VALA_CLASS (base);
 	if (self->priv->get_value_function == NULL) {
-		if (vala_class_get_base_class (self) != NULL) {
+		if (self->priv->_base_class != NULL) {
 			char* _tmp0;
 			_tmp0 = NULL;
-			self->priv->get_value_function = (_tmp0 = vala_typesymbol_get_get_value_function (VALA_TYPESYMBOL (vala_class_get_base_class (self))), (self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL)), _tmp0);
+			self->priv->get_value_function = (_tmp0 = vala_typesymbol_get_get_value_function (VALA_TYPESYMBOL (self->priv->_base_class)), (self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL)), _tmp0);
 		} else {
 			char* _tmp1;
 			_tmp1 = NULL;
@@ -985,10 +1022,10 @@ static char* vala_class_real_get_set_value_function (ValaTypesymbol* base) {
 	const char* _tmp2;
 	self = VALA_CLASS (base);
 	if (self->priv->set_value_function == NULL) {
-		if (vala_class_get_base_class (self) != NULL) {
+		if (self->priv->_base_class != NULL) {
 			char* _tmp0;
 			_tmp0 = NULL;
-			self->priv->set_value_function = (_tmp0 = vala_typesymbol_get_set_value_function (VALA_TYPESYMBOL (vala_class_get_base_class (self))), (self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL)), _tmp0);
+			self->priv->set_value_function = (_tmp0 = vala_typesymbol_get_set_value_function (VALA_TYPESYMBOL (self->priv->_base_class)), (self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL)), _tmp0);
 		} else {
 			char* _tmp1;
 			_tmp1 = NULL;
@@ -1010,15 +1047,32 @@ static gboolean vala_class_real_is_reference_counting (ValaTypesymbol* base) {
 }
 
 
+static gboolean vala_class_is_fundamental (ValaClass* self) {
+	g_return_val_if_fail (VALA_IS_CLASS (self), FALSE);
+	if (self->priv->_base_class != NULL && _vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (self->priv->_base_class)), "TypeInstance") == 0 && _vala_strcmp0 (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (self->priv->_base_class))), "GLib") == 0) {
+		return TRUE;
+	}
+	return FALSE;
+}
+
+
 static char* vala_class_real_get_ref_function (ValaTypesymbol* base) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	if (self->priv->ref_function == NULL && vala_class_get_base_class (self) != NULL) {
-		return vala_typesymbol_get_ref_function (VALA_TYPESYMBOL (vala_class_get_base_class (self)));
-	} else {
-		const char* _tmp1;
+	if (self->priv->ref_function == NULL && vala_class_is_fundamental (self)) {
+		char* _tmp1;
+		char* _tmp0;
 		_tmp1 = NULL;
-		return (_tmp1 = self->priv->ref_function, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+		_tmp0 = NULL;
+		self->priv->ref_function = (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (self))), "ref", NULL), (self->priv->ref_function = (g_free (self->priv->ref_function), NULL)), _tmp1);
+		_tmp0 = (g_free (_tmp0), NULL);
+	}
+	if (self->priv->ref_function == NULL && self->priv->_base_class != NULL) {
+		return vala_typesymbol_get_ref_function (VALA_TYPESYMBOL (self->priv->_base_class));
+	} else {
+		const char* _tmp3;
+		_tmp3 = NULL;
+		return (_tmp3 = self->priv->ref_function, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 	}
 }
 
@@ -1036,12 +1090,20 @@ void vala_class_set_ref_function (ValaClass* self, const char* name) {
 static char* vala_class_real_get_unref_function (ValaTypesymbol* base) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	if (self->priv->unref_function == NULL && vala_class_get_base_class (self) != NULL) {
-		return vala_typesymbol_get_unref_function (VALA_TYPESYMBOL (vala_class_get_base_class (self)));
-	} else {
-		const char* _tmp1;
+	if (self->priv->unref_function == NULL && vala_class_is_fundamental (self)) {
+		char* _tmp1;
+		char* _tmp0;
 		_tmp1 = NULL;
-		return (_tmp1 = self->priv->unref_function, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+		_tmp0 = NULL;
+		self->priv->unref_function = (_tmp1 = g_strconcat ((_tmp0 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (self))), "unref", NULL), (self->priv->unref_function = (g_free (self->priv->unref_function), NULL)), _tmp1);
+		_tmp0 = (g_free (_tmp0), NULL);
+	}
+	if (self->priv->unref_function == NULL && self->priv->_base_class != NULL) {
+		return vala_typesymbol_get_unref_function (VALA_TYPESYMBOL (self->priv->_base_class));
+	} else {
+		const char* _tmp3;
+		_tmp3 = NULL;
+		return (_tmp3 = self->priv->unref_function, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 	}
 }
 
@@ -1103,6 +1165,7 @@ void vala_class_set_free_function (ValaClass* self, const char* name) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_CLASS (self));
+	g_return_if_fail (name != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->free_function = (_tmp1 = (_tmp0 = name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->free_function = (g_free (self->priv->free_function), NULL)), _tmp1);
@@ -1112,7 +1175,7 @@ void vala_class_set_free_function (ValaClass* self, const char* name) {
 static gboolean vala_class_real_is_subtype_of (ValaTypesymbol* base, ValaTypesymbol* t) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	g_return_val_if_fail (t == NULL || VALA_IS_TYPESYMBOL (t), FALSE);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (t), FALSE);
 	if (VALA_TYPESYMBOL (self) == t) {
 		return TRUE;
 	}
@@ -1142,6 +1205,7 @@ static gint vala_class_real_get_type_parameter_index (ValaTypesymbol* base, cons
 	ValaClass * self;
 	gint i;
 	self = VALA_CLASS (base);
+	g_return_val_if_fail (name != NULL, 0);
 	i = 0;
 	{
 		GeeList* parameter_collection;
@@ -1169,12 +1233,12 @@ static gint vala_class_real_get_type_parameter_index (ValaTypesymbol* base, cons
 static void vala_class_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaClass * self;
 	self = VALA_CLASS (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->base_types)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->base_types)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -1187,6 +1251,14 @@ static void vala_class_real_replace_type (ValaCodeNode* base, ValaDataType* old_
 }
 
 
+static ValaCodeBinding* vala_class_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaClass * self;
+	self = VALA_CLASS (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_class_binding (codegen, self);
+}
+
+
 ValaClass* vala_class_get_base_class (ValaClass* self) {
 	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
 	return self->priv->_base_class;
@@ -1233,6 +1305,12 @@ gboolean vala_class_get_has_private_fields (ValaClass* self) {
 }
 
 
+static void vala_class_set_has_private_fields (ValaClass* self, gboolean value) {
+	g_return_if_fail (VALA_IS_CLASS (self));
+	self->priv->_has_private_fields = value;
+}
+
+
 ValaMethod* vala_class_get_default_construction_method (ValaClass* self) {
 	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
 	return self->priv->_default_construction_method;
@@ -1265,6 +1343,22 @@ void vala_class_set_constructor (ValaClass* self, ValaConstructor* value) {
 }
 
 
+ValaConstructor* vala_class_get_static_constructor (ValaClass* self) {
+	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
+	return self->priv->_static_constructor;
+}
+
+
+void vala_class_set_static_constructor (ValaClass* self, ValaConstructor* value) {
+	ValaConstructor* _tmp2;
+	ValaConstructor* _tmp1;
+	g_return_if_fail (VALA_IS_CLASS (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_static_constructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_static_constructor == NULL ? NULL : (self->priv->_static_constructor = (g_object_unref (self->priv->_static_constructor), NULL))), _tmp2);
+}
+
+
 ValaDestructor* vala_class_get_destructor (ValaClass* self) {
 	g_return_val_if_fail (VALA_IS_CLASS (self), NULL);
 	return self->priv->_destructor;
@@ -1278,6 +1372,19 @@ void vala_class_set_destructor (ValaClass* self, ValaDestructor* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_destructor = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL))), _tmp2);
+	if (self->priv->_destructor != NULL) {
+		ValaFormalParameter* _tmp4;
+		ValaClassType* _tmp3;
+		if (vala_destructor_get_this_parameter (self->priv->_destructor) != NULL) {
+			vala_scope_remove (vala_symbol_get_scope (VALA_SYMBOL (self->priv->_destructor)), vala_symbol_get_name (VALA_SYMBOL (vala_destructor_get_this_parameter (self->priv->_destructor))));
+		}
+		_tmp4 = NULL;
+		_tmp3 = NULL;
+		vala_destructor_set_this_parameter (self->priv->_destructor, (_tmp4 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp3 = vala_class_type_new (self))), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self->priv->_destructor)), vala_symbol_get_name (VALA_SYMBOL (vala_destructor_get_this_parameter (self->priv->_destructor))), VALA_SYMBOL (vala_destructor_get_this_parameter (self->priv->_destructor)));
+	}
 }
 
 
@@ -1315,6 +1422,9 @@ static void vala_class_get_property (GObject * object, guint property_id, GValue
 		case VALA_CLASS_CONSTRUCTOR:
 		g_value_set_object (value, vala_class_get_constructor (self));
 		break;
+		case VALA_CLASS_STATIC_CONSTRUCTOR:
+		g_value_set_object (value, vala_class_get_static_constructor (self));
+		break;
 		case VALA_CLASS_DESTRUCTOR:
 		g_value_set_object (value, vala_class_get_destructor (self));
 		break;
@@ -1341,12 +1451,18 @@ static void vala_class_set_property (GObject * object, guint property_id, const
 		case VALA_CLASS_IS_STATIC:
 		vala_class_set_is_static (self, g_value_get_boolean (value));
 		break;
+		case VALA_CLASS_HAS_PRIVATE_FIELDS:
+		vala_class_set_has_private_fields (self, g_value_get_boolean (value));
+		break;
 		case VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD:
 		vala_class_set_default_construction_method (self, g_value_get_object (value));
 		break;
 		case VALA_CLASS_CONSTRUCTOR:
 		vala_class_set_constructor (self, g_value_get_object (value));
 		break;
+		case VALA_CLASS_STATIC_CONSTRUCTOR:
+		vala_class_set_static_constructor (self, g_value_get_object (value));
+		break;
 		case VALA_CLASS_DESTRUCTOR:
 		vala_class_set_destructor (self, g_value_get_object (value));
 		break;
@@ -1373,6 +1489,7 @@ static void vala_class_class_init (ValaClassClass * klass) {
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_class_real_get_lower_case_cname;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_class_real_get_lower_case_cprefix;
 	VALA_TYPESYMBOL_CLASS (klass)->get_upper_case_cname = vala_class_real_get_upper_case_cname;
+	VALA_TYPESYMBOL_CLASS (klass)->get_type_signature = vala_class_real_get_type_signature;
 	VALA_TYPESYMBOL_CLASS (klass)->is_reference_type = vala_class_real_is_reference_type;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_id = vala_class_real_get_type_id;
 	VALA_TYPESYMBOL_CLASS (klass)->get_marshaller_type_name = vala_class_real_get_marshaller_type_name;
@@ -1386,12 +1503,14 @@ static void vala_class_class_init (ValaClassClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->is_subtype_of = vala_class_real_is_subtype_of;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_parameter_index = vala_class_real_get_type_parameter_index;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_class_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_class_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_BASE_CLASS, g_param_spec_object ("base-class", "base-class", "base-class", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_STATIC, g_param_spec_boolean ("is-static", "is-static", "is-static", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_HAS_PRIVATE_FIELDS, g_param_spec_boolean ("has-private-fields", "has-private-fields", "has-private-fields", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_HAS_PRIVATE_FIELDS, g_param_spec_boolean ("has-private-fields", "has-private-fields", "has-private-fields", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_DEFAULT_CONSTRUCTION_METHOD, g_param_spec_object ("default-construction-method", "default-construction-method", "default-construction-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_CONSTRUCTOR, g_param_spec_object ("constructor", "constructor", "constructor", VALA_TYPE_CONSTRUCTOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_STATIC_CONSTRUCTOR, g_param_spec_object ("static-constructor", "static-constructor", "static-constructor", VALA_TYPE_CONSTRUCTOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_DESTRUCTOR, g_param_spec_object ("destructor", "destructor", "destructor", VALA_TYPE_DESTRUCTOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_IS_ERROR_BASE, g_param_spec_boolean ("is-error-base", "is-error-base", "is-error-base", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -1429,6 +1548,7 @@ static void vala_class_dispose (GObject * obj) {
 	self->priv->marshaller_type_name = (g_free (self->priv->marshaller_type_name), NULL);
 	self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL);
 	self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL);
+	self->priv->type_signature = (g_free (self->priv->type_signature), NULL);
 	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
 	(self->priv->base_types == NULL ? NULL : (self->priv->base_types = (g_object_unref (self->priv->base_types), NULL)));
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
@@ -1442,6 +1562,7 @@ static void vala_class_dispose (GObject * obj) {
 	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (g_object_unref (self->priv->delegates), NULL)));
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
 	(self->priv->_constructor == NULL ? NULL : (self->priv->_constructor = (g_object_unref (self->priv->_constructor), NULL)));
+	(self->priv->_static_constructor == NULL ? NULL : (self->priv->_static_constructor = (g_object_unref (self->priv->_static_constructor), NULL)));
 	(self->priv->_destructor == NULL ? NULL : (self->priv->_destructor = (g_object_unref (self->priv->_destructor), NULL)));
 	G_OBJECT_CLASS (vala_class_parent_class)->dispose (obj);
 }
