@@ -1,6 +1,6 @@
 /* valaclasstype.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,10 @@
  */
 
 #include <vala/valaclasstype.h>
-#include <vala/valadatatype.h>
+#include <vala/valacodenode.h>
+
+
+
 
 struct _ValaClassTypePrivate {
 	ValaClass* _class_symbol;
@@ -31,20 +34,56 @@ enum  {
 	VALA_CLASS_TYPE_DUMMY_PROPERTY,
 	VALA_CLASS_TYPE_CLASS_SYMBOL
 };
+static ValaDataType* vala_class_type_real_copy (ValaDataType* base);
 static gpointer vala_class_type_parent_class = NULL;
 static void vala_class_type_dispose (GObject * obj);
 
 
+
 ValaClassType* vala_class_type_new (ValaClass* class_symbol) {
 	ValaClassType * self;
-	g_return_val_if_fail (class_symbol == NULL || VALA_IS_CLASS (class_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_CLASS (class_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS_TYPE, 0, NULL);
-	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (class_symbol));
 	vala_class_type_set_class_symbol (self, class_symbol);
+	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (class_symbol));
 	return self;
 }
 
 
+static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
+	ValaClassType * self;
+	ValaClassType* result;
+	self = VALA_CLASS_TYPE (base);
+	result = vala_class_type_new (self->priv->_class_symbol);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
+	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
+	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
+	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
+	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
+	{
+		GeeList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (self));
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
+			ValaDataType* arg;
+			arg = ((ValaDataType*) gee_iterator_get (arg_it));
+			{
+				ValaDataType* _tmp0;
+				_tmp0 = NULL;
+				vala_data_type_add_type_argument (VALA_DATA_TYPE (result), (_tmp0 = vala_data_type_copy (arg)));
+				(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
+			}
+		}
+		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
+	}
+	return VALA_DATA_TYPE (result);
+}
+
+
 ValaClass* vala_class_type_get_class_symbol (ValaClassType* self) {
 	g_return_val_if_fail (VALA_IS_CLASS_TYPE (self), NULL);
 	return self->priv->_class_symbol;
@@ -91,6 +130,7 @@ static void vala_class_type_class_init (ValaClassTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_class_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_class_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_class_type_dispose;
+	VALA_DATA_TYPE_CLASS (klass)->copy = vala_class_type_real_copy;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_TYPE_CLASS_SYMBOL, g_param_spec_object ("class-symbol", "class-symbol", "class-symbol", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
