@@ -63,19 +63,20 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_constant_binding) (ValaCodeGenerator* self, ValaConstant* node);
 	ValaCodeBinding* (*create_field_binding) (ValaCodeGenerator* self, ValaField* node);
 	ValaCodeBinding* (*create_method_binding) (ValaCodeGenerator* self, ValaMethod* node);
+	ValaCodeBinding* (*create_dynamic_method_binding) (ValaCodeGenerator* self, ValaDynamicMethod* node);
 	ValaCodeBinding* (*create_creation_method_binding) (ValaCodeGenerator* self, ValaCreationMethod* node);
 	ValaCodeBinding* (*create_formal_parameter_binding) (ValaCodeGenerator* self, ValaFormalParameter* node);
 	ValaCodeBinding* (*create_property_binding) (ValaCodeGenerator* self, ValaProperty* node);
 	ValaCodeBinding* (*create_property_accessor_binding) (ValaCodeGenerator* self, ValaPropertyAccessor* node);
 	ValaCodeBinding* (*create_signal_binding) (ValaCodeGenerator* self, ValaSignal* node);
+	ValaCodeBinding* (*create_dynamic_signal_binding) (ValaCodeGenerator* self, ValaDynamicSignal* node);
 	ValaCodeBinding* (*create_constructor_binding) (ValaCodeGenerator* self, ValaConstructor* node);
 	ValaCodeBinding* (*create_destructor_binding) (ValaCodeGenerator* self, ValaDestructor* node);
 	ValaCodeBinding* (*create_type_parameter_binding) (ValaCodeGenerator* self, ValaTypeParameter* node);
 	ValaCodeBinding* (*create_block_binding) (ValaCodeGenerator* self, ValaBlock* node);
 	ValaCodeBinding* (*create_empty_statement_binding) (ValaCodeGenerator* self, ValaEmptyStatement* node);
 	ValaCodeBinding* (*create_declaration_statement_binding) (ValaCodeGenerator* self, ValaDeclarationStatement* node);
-	ValaCodeBinding* (*create_local_variable_declaration_binding) (ValaCodeGenerator* self, ValaLocalVariableDeclaration* node);
-	ValaCodeBinding* (*create_variable_declarator_binding) (ValaCodeGenerator* self, ValaVariableDeclarator* node);
+	ValaCodeBinding* (*create_local_variable_binding) (ValaCodeGenerator* self, ValaLocalVariable* node);
 	ValaCodeBinding* (*create_initializer_list_binding) (ValaCodeGenerator* self, ValaInitializerList* node);
 	ValaCodeBinding* (*create_expression_statement_binding) (ValaCodeGenerator* self, ValaExpressionStatement* node);
 	ValaCodeBinding* (*create_if_statement_binding) (ValaCodeGenerator* self, ValaIfStatement* node);
@@ -101,10 +102,8 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_real_literal_binding) (ValaCodeGenerator* self, ValaRealLiteral* node);
 	ValaCodeBinding* (*create_string_literal_binding) (ValaCodeGenerator* self, ValaStringLiteral* node);
 	ValaCodeBinding* (*create_null_literal_binding) (ValaCodeGenerator* self, ValaNullLiteral* node);
-	ValaCodeBinding* (*create_literal_expression_binding) (ValaCodeGenerator* self, ValaLiteralExpression* node);
 	ValaCodeBinding* (*create_parenthesized_expression_binding) (ValaCodeGenerator* self, ValaParenthesizedExpression* node);
 	ValaCodeBinding* (*create_member_access_binding) (ValaCodeGenerator* self, ValaMemberAccess* node);
-	ValaCodeBinding* (*create_member_access_simple_binding) (ValaCodeGenerator* self, ValaMemberAccess* node);
 	ValaCodeBinding* (*create_invocation_expression_binding) (ValaCodeGenerator* self, ValaInvocationExpression* node);
 	ValaCodeBinding* (*create_element_access_binding) (ValaCodeGenerator* self, ValaElementAccess* node);
 	ValaCodeBinding* (*create_base_access_binding) (ValaCodeGenerator* self, ValaBaseAccess* node);
@@ -121,7 +120,6 @@ struct _ValaCodeGeneratorClass {
 	ValaCodeBinding* (*create_type_check_binding) (ValaCodeGenerator* self, ValaTypeCheck* node);
 	ValaCodeBinding* (*create_conditional_expression_binding) (ValaCodeGenerator* self, ValaConditionalExpression* node);
 	ValaCodeBinding* (*create_lambda_expression_binding) (ValaCodeGenerator* self, ValaLambdaExpression* node);
-	ValaCodeBinding* (*create_lambda_expression_with_statement_body_binding) (ValaCodeGenerator* self, ValaLambdaExpression* node);
 	ValaCodeBinding* (*create_assignment_binding) (ValaCodeGenerator* self, ValaAssignment* node);
 };
 
@@ -138,19 +136,20 @@ ValaCodeBinding* vala_code_generator_create_delegate_binding (ValaCodeGenerator*
 ValaCodeBinding* vala_code_generator_create_constant_binding (ValaCodeGenerator* self, ValaConstant* node);
 ValaCodeBinding* vala_code_generator_create_field_binding (ValaCodeGenerator* self, ValaField* node);
 ValaCodeBinding* vala_code_generator_create_method_binding (ValaCodeGenerator* self, ValaMethod* node);
+ValaCodeBinding* vala_code_generator_create_dynamic_method_binding (ValaCodeGenerator* self, ValaDynamicMethod* node);
 ValaCodeBinding* vala_code_generator_create_creation_method_binding (ValaCodeGenerator* self, ValaCreationMethod* node);
 ValaCodeBinding* vala_code_generator_create_formal_parameter_binding (ValaCodeGenerator* self, ValaFormalParameter* node);
 ValaCodeBinding* vala_code_generator_create_property_binding (ValaCodeGenerator* self, ValaProperty* node);
 ValaCodeBinding* vala_code_generator_create_property_accessor_binding (ValaCodeGenerator* self, ValaPropertyAccessor* node);
 ValaCodeBinding* vala_code_generator_create_signal_binding (ValaCodeGenerator* self, ValaSignal* node);
+ValaCodeBinding* vala_code_generator_create_dynamic_signal_binding (ValaCodeGenerator* self, ValaDynamicSignal* node);
 ValaCodeBinding* vala_code_generator_create_constructor_binding (ValaCodeGenerator* self, ValaConstructor* node);
 ValaCodeBinding* vala_code_generator_create_destructor_binding (ValaCodeGenerator* self, ValaDestructor* node);
 ValaCodeBinding* vala_code_generator_create_type_parameter_binding (ValaCodeGenerator* self, ValaTypeParameter* node);
 ValaCodeBinding* vala_code_generator_create_block_binding (ValaCodeGenerator* self, ValaBlock* node);
 ValaCodeBinding* vala_code_generator_create_empty_statement_binding (ValaCodeGenerator* self, ValaEmptyStatement* node);
 ValaCodeBinding* vala_code_generator_create_declaration_statement_binding (ValaCodeGenerator* self, ValaDeclarationStatement* node);
-ValaCodeBinding* vala_code_generator_create_local_variable_declaration_binding (ValaCodeGenerator* self, ValaLocalVariableDeclaration* node);
-ValaCodeBinding* vala_code_generator_create_variable_declarator_binding (ValaCodeGenerator* self, ValaVariableDeclarator* node);
+ValaCodeBinding* vala_code_generator_create_local_variable_binding (ValaCodeGenerator* self, ValaLocalVariable* node);
 ValaCodeBinding* vala_code_generator_create_initializer_list_binding (ValaCodeGenerator* self, ValaInitializerList* node);
 ValaCodeBinding* vala_code_generator_create_expression_statement_binding (ValaCodeGenerator* self, ValaExpressionStatement* node);
 ValaCodeBinding* vala_code_generator_create_if_statement_binding (ValaCodeGenerator* self, ValaIfStatement* node);
@@ -176,10 +175,8 @@ ValaCodeBinding* vala_code_generator_create_integer_literal_binding (ValaCodeGen
 ValaCodeBinding* vala_code_generator_create_real_literal_binding (ValaCodeGenerator* self, ValaRealLiteral* node);
 ValaCodeBinding* vala_code_generator_create_string_literal_binding (ValaCodeGenerator* self, ValaStringLiteral* node);
 ValaCodeBinding* vala_code_generator_create_null_literal_binding (ValaCodeGenerator* self, ValaNullLiteral* node);
-ValaCodeBinding* vala_code_generator_create_literal_expression_binding (ValaCodeGenerator* self, ValaLiteralExpression* node);
 ValaCodeBinding* vala_code_generator_create_parenthesized_expression_binding (ValaCodeGenerator* self, ValaParenthesizedExpression* node);
 ValaCodeBinding* vala_code_generator_create_member_access_binding (ValaCodeGenerator* self, ValaMemberAccess* node);
-ValaCodeBinding* vala_code_generator_create_member_access_simple_binding (ValaCodeGenerator* self, ValaMemberAccess* node);
 ValaCodeBinding* vala_code_generator_create_invocation_expression_binding (ValaCodeGenerator* self, ValaInvocationExpression* node);
 ValaCodeBinding* vala_code_generator_create_element_access_binding (ValaCodeGenerator* self, ValaElementAccess* node);
 ValaCodeBinding* vala_code_generator_create_base_access_binding (ValaCodeGenerator* self, ValaBaseAccess* node);
@@ -196,11 +193,11 @@ ValaCodeBinding* vala_code_generator_create_binary_expression_binding (ValaCodeG
 ValaCodeBinding* vala_code_generator_create_type_check_binding (ValaCodeGenerator* self, ValaTypeCheck* node);
 ValaCodeBinding* vala_code_generator_create_conditional_expression_binding (ValaCodeGenerator* self, ValaConditionalExpression* node);
 ValaCodeBinding* vala_code_generator_create_lambda_expression_binding (ValaCodeGenerator* self, ValaLambdaExpression* node);
-ValaCodeBinding* vala_code_generator_create_lambda_expression_with_statement_body_binding (ValaCodeGenerator* self, ValaLambdaExpression* node);
 ValaCodeBinding* vala_code_generator_create_assignment_binding (ValaCodeGenerator* self, ValaAssignment* node);
 ValaCodeGenerator* vala_code_generator_new (void);
 GType vala_code_generator_get_type (void);
 
+
 G_END_DECLS
 
 #endif
