@@ -27,14 +27,18 @@
 #include <vala/valadatatype.h>
 #include <vala/valaexpression.h>
 #include <vala/valaattribute.h>
+#include <vala/valacodegenerator.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
 	ValaSourceReference* _source_reference;
-	ValaCodeBinding* _code_binding;
 	gboolean _error;
 	gboolean _tree_can_fail;
+	ValaCodeBinding* code_binding;
 	ValaCCodeNode* _ccodenode;
 };
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
@@ -43,7 +47,6 @@ enum  {
 	VALA_CODE_NODE_PARENT_NODE,
 	VALA_CODE_NODE_SOURCE_REFERENCE,
 	VALA_CODE_NODE_CCODENODE,
-	VALA_CODE_NODE_CODE_BINDING,
 	VALA_CODE_NODE_ERROR,
 	VALA_CODE_NODE_TREE_CAN_FAIL
 };
@@ -52,8 +55,11 @@ static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVis
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
+static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
 static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -63,7 +69,7 @@ static void vala_code_node_dispose (GObject * obj);
  */
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -79,7 +85,7 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
  */
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -90,8 +96,8 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 }
 
 
@@ -102,8 +108,8 @@ void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, Va
 
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 }
 
 
@@ -120,6 +126,8 @@ void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_
  */
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	/* FIXME: use hash table*/
 	{
 		GList* a_collection;
 		GList* a_it;
@@ -128,10 +136,9 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
 			_tmp1 = NULL;
-			a = (_tmp1 = a_it->data, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			a = (_tmp1 = ((ValaAttribute*) a_it->data), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			{
-				/* FIXME: use hash table*/
-				if (g_utf8_collate (vala_attribute_get_name (a), name) == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
 					return a;
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -154,11 +161,11 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
 	str = g_string_new ("");
 	g_string_append (g_string_append (str, "/* "), g_type_name (G_TYPE_FROM_INSTANCE (G_OBJECT (self))));
-	if (vala_code_node_get_source_reference (self) != NULL) {
+	if (self->priv->_source_reference != NULL) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (vala_code_node_get_source_reference (self))));
-		(_tmp0 = (g_free (_tmp0), NULL));
+		g_string_append (g_string_append (str, "@"), (_tmp0 = vala_source_reference_to_string (self->priv->_source_reference)));
+		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	_tmp1 = NULL;
 	_tmp2 = NULL;
@@ -167,9 +174,54 @@ static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 
 
 char* vala_code_node_to_string (ValaCodeNode* self) {
-	char* result;
-	result = VALA_CODE_NODE_GET_CLASS (self)->to_string (self);
-	return result;
+	return VALA_CODE_NODE_GET_CLASS (self)->to_string (self);
+}
+
+
+/**
+ * Returns the binding to the generated code.
+ *
+ * @return code binding
+ */
+ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	ValaCodeBinding* _tmp1;
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	if (self->priv->code_binding == NULL) {
+		ValaCodeBinding* _tmp0;
+		_tmp0 = NULL;
+		self->priv->code_binding = (_tmp0 = vala_code_node_create_code_binding (self, codegen), (self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL))), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->code_binding, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+}
+
+
+/**
+ * Creates the binding to the generated code.
+ */
+static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return NULL;
+}
+
+
+ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	return VALA_CODE_NODE_GET_CLASS (self)->create_code_binding (self, codegen);
+}
+
+
+/**
+ * Represents a part of the parsed source code.
+ *
+ * Code nodes get created by the parser and are used throughout the whole
+ * compilation process.
+ */
+ValaCodeNode* vala_code_node_new (void) {
+	ValaCodeNode * self;
+	self = g_object_newv (VALA_TYPE_CODE_NODE, 0, NULL);
+	return self;
 }
 
 
@@ -211,14 +263,14 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 	ValaCCodeNode* _tmp4;
 	ValaCCodeNode* _tmp3;
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	if (vala_code_node_get_source_reference (self) != NULL) {
+	if (value != NULL && self->priv->_source_reference != NULL) {
 		ValaCCodeLineDirective* _tmp2;
 		char* _tmp1;
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (self))))), vala_source_reference_get_first_line (vala_code_node_get_source_reference (self)))));
+		vala_ccode_node_set_line (value, (_tmp2 = vala_ccode_line_directive_new ((_tmp1 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference)))), vala_source_reference_get_first_line (self->priv->_source_reference))));
 		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
-		(_tmp1 = (g_free (_tmp1), NULL));
+		_tmp1 = (g_free (_tmp1), NULL);
 	}
 	_tmp4 = NULL;
 	_tmp3 = NULL;
@@ -226,22 +278,6 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 }
 
 
-ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	return self->priv->_code_binding;
-}
-
-
-void vala_code_node_set_code_binding (ValaCodeNode* self, ValaCodeBinding* value) {
-	ValaCodeBinding* _tmp2;
-	ValaCodeBinding* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_code_binding = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_code_binding == NULL ? NULL : (self->priv->_code_binding = (g_object_unref (self->priv->_code_binding), NULL))), _tmp2);
-}
-
-
 gboolean vala_code_node_get_error (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
 	return self->priv->_error;
@@ -279,9 +315,6 @@ static void vala_code_node_get_property (GObject * object, guint property_id, GV
 		case VALA_CODE_NODE_CCODENODE:
 		g_value_set_object (value, vala_code_node_get_ccodenode (self));
 		break;
-		case VALA_CODE_NODE_CODE_BINDING:
-		g_value_set_object (value, vala_code_node_get_code_binding (self));
-		break;
 		case VALA_CODE_NODE_ERROR:
 		g_value_set_boolean (value, vala_code_node_get_error (self));
 		break;
@@ -308,9 +341,6 @@ static void vala_code_node_set_property (GObject * object, guint property_id, co
 		case VALA_CODE_NODE_CCODENODE:
 		vala_code_node_set_ccodenode (self, g_value_get_object (value));
 		break;
-		case VALA_CODE_NODE_CODE_BINDING:
-		vala_code_node_set_code_binding (self, g_value_get_object (value));
-		break;
 		case VALA_CODE_NODE_ERROR:
 		vala_code_node_set_error (self, g_value_get_boolean (value));
 		break;
@@ -335,10 +365,10 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_code_node_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_code_node_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_code_node_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", VALA_TYPE_CODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "source-reference", "source-reference", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CCODENODE, g_param_spec_object ("ccodenode", "ccodenode", "ccodenode", VALA_TYPE_CCODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CODE_BINDING, g_param_spec_object ("code-binding", "code-binding", "code-binding", VALA_TYPE_CODE_BINDING, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_ERROR, g_param_spec_boolean ("error", "error", "error", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "tree-can-fail", "tree-can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -354,7 +384,7 @@ static void vala_code_node_dispose (GObject * obj) {
 	self = VALA_CODE_NODE (obj);
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
 	(self->attributes == NULL ? NULL : (self->attributes = (g_list_foreach (self->attributes, ((GFunc) g_object_unref), NULL), g_list_free (self->attributes), NULL)));
-	(self->priv->_code_binding == NULL ? NULL : (self->priv->_code_binding = (g_object_unref (self->priv->_code_binding), NULL)));
+	(self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL)));
 	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL)));
 	G_OBJECT_CLASS (vala_code_node_parent_class)->dispose (obj);
 }
@@ -370,5 +400,16 @@ GType vala_code_node_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
