@@ -58,10 +58,10 @@ ValaConditionalExpression* vala_conditional_expression_new (ValaExpression* cond
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaConditionalExpression * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (true_expr == NULL || VALA_IS_EXPRESSION (true_expr), NULL);
-	g_return_val_if_fail (false_expr == NULL || VALA_IS_EXPRESSION (false_expr), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (true_expr), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (false_expr), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	__params_it->name = "condition";
@@ -90,7 +90,7 @@ ValaConditionalExpression* vala_conditional_expression_new (ValaExpression* cond
 static void vala_conditional_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaConditionalExpression * self;
 	self = VALA_CONDITIONAL_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_condition), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_true_expression), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_false_expression), visitor);
