@@ -1,11 +1,11 @@
 /* valaconstant.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACONSTANT_H__
-#define __VALACONSTANT_H__
+#ifndef __VALA_VALACONSTANT_H__
+#define __VALA_VALACONSTANT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,21 +47,23 @@ typedef struct _ValaConstantPrivate ValaConstantPrivate;
  * Represents a type member with a constant value.
  */
 struct _ValaConstant {
-	ValaMember parent;
+	ValaMember parent_instance;
 	ValaConstantPrivate * priv;
 };
 struct _ValaConstantClass {
-	ValaMemberClass parent;
+	ValaMemberClass parent_class;
 };
 
-ValaConstant* vala_constant_new (const char* name, ValaTypeReference* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
+ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 char* vala_constant_get_cname (ValaConstant* self);
-ValaTypeReference* vala_constant_get_type_reference (ValaConstant* self);
-void vala_constant_set_type_reference (ValaConstant* self, ValaTypeReference* value);
+void vala_constant_process_attributes (ValaConstant* self);
+ValaDataType* vala_constant_get_type_reference (ValaConstant* self);
+void vala_constant_set_type_reference (ValaConstant* self, ValaDataType* value);
 ValaExpression* vala_constant_get_initializer (ValaConstant* self);
 void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value);
 GType vala_constant_get_type (void);
 
+
 G_END_DECLS
 
 #endif
