@@ -42,13 +42,11 @@
 struct _ValaDataTypePrivate {
 	gboolean _transfers_ownership;
 	gboolean _takes_ownership;
-	gboolean _is_out;
 	gboolean _nullable;
-	gboolean _requires_null_check;
 	ValaTypesymbol* _data_type;
 	ValaTypeParameter* _type_parameter;
 	gboolean _floating_reference;
-	gboolean _is_ref;
+	gboolean _is_dynamic;
 	GeeList* type_argument_list;
 };
 #define VALA_DATA_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DATA_TYPE, ValaDataTypePrivate))
@@ -56,13 +54,11 @@ enum  {
 	VALA_DATA_TYPE_DUMMY_PROPERTY,
 	VALA_DATA_TYPE_TRANSFERS_OWNERSHIP,
 	VALA_DATA_TYPE_TAKES_OWNERSHIP,
-	VALA_DATA_TYPE_IS_OUT,
 	VALA_DATA_TYPE_NULLABLE,
-	VALA_DATA_TYPE_REQUIRES_NULL_CHECK,
 	VALA_DATA_TYPE_DATA_TYPE,
 	VALA_DATA_TYPE_TYPE_PARAMETER,
 	VALA_DATA_TYPE_FLOATING_REFERENCE,
-	VALA_DATA_TYPE_IS_REF
+	VALA_DATA_TYPE_IS_DYNAMIC
 };
 static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_data_type_real_get_cname (ValaDataType* self, gboolean var_type, gboolean const_type);
@@ -71,7 +67,7 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base);
 static gboolean vala_data_type_real_equals (ValaDataType* self, ValaDataType* type2);
 static gboolean vala_data_type_real_stricter (ValaDataType* self, ValaDataType* type2);
 static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
-static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType* target_type);
 static gboolean vala_data_type_real_is_invokable (ValaDataType* self);
 static ValaDataType* vala_data_type_real_get_return_type (ValaDataType* self);
 static GeeCollection* vala_data_type_real_get_parameters (ValaDataType* self);
@@ -94,7 +90,7 @@ static void vala_data_type_dispose (GObject * obj);
  */
 void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg) {
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	g_return_if_fail (arg == NULL || VALA_IS_DATA_TYPE (arg));
+	g_return_if_fail (VALA_IS_DATA_TYPE (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -123,7 +119,7 @@ void vala_data_type_remove_all_type_arguments (ValaDataType* self) {
 static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDataType * self;
 	self = VALA_DATA_TYPE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (gee_collection_get_size (GEE_COLLECTION (self->priv->type_argument_list)) > 0) {
 		{
 			GeeList* type_arg_collection;
@@ -161,45 +157,39 @@ static char* vala_data_type_real_get_cname (ValaDataType* self, gboolean var_typ
 		}
 	}
 	ptr = NULL;
-	if (self->priv->_type_parameter != NULL || (!vala_typesymbol_is_reference_type (self->priv->_data_type) && !self->priv->_is_ref && !self->priv->_is_out)) {
+	if (self->priv->_type_parameter != NULL || !vala_typesymbol_is_reference_type (self->priv->_data_type)) {
 		char* _tmp2;
 		_tmp2 = NULL;
 		ptr = (_tmp2 = g_strdup (""), (ptr = (g_free (ptr), NULL)), _tmp2);
 	} else {
-		if ((vala_typesymbol_is_reference_type (self->priv->_data_type) && !self->priv->_is_ref && !self->priv->_is_out) || (!vala_typesymbol_is_reference_type (self->priv->_data_type) && (self->priv->_is_ref || self->priv->_is_out))) {
-			char* _tmp3;
-			_tmp3 = NULL;
-			ptr = (_tmp3 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), _tmp3);
-		} else {
-			char* _tmp4;
-			_tmp4 = NULL;
-			ptr = (_tmp4 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), _tmp4);
-		}
+		char* _tmp3;
+		_tmp3 = NULL;
+		ptr = (_tmp3 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), _tmp3);
 	}
 	if (self->priv->_data_type != NULL) {
+		char* _tmp4;
 		char* _tmp5;
 		char* _tmp6;
-		char* _tmp7;
+		_tmp4 = NULL;
 		_tmp5 = NULL;
 		_tmp6 = NULL;
-		_tmp7 = NULL;
-		return (_tmp7 = (_tmp6 = g_strconcat ((_tmp5 = vala_typesymbol_get_cname (self->priv->_data_type, const_type)), ptr, NULL), (_tmp5 = (g_free (_tmp5), NULL)), _tmp6), (ptr = (g_free (ptr), NULL)), _tmp7);
+		return (_tmp6 = (_tmp5 = g_strconcat ((_tmp4 = vala_typesymbol_get_cname (self->priv->_data_type, const_type)), ptr, NULL), (_tmp4 = (g_free (_tmp4), NULL)), _tmp5), (ptr = (g_free (ptr), NULL)), _tmp6);
 	} else {
 		if (self->priv->_type_parameter != NULL) {
 			if (const_type) {
+				char* _tmp7;
+				_tmp7 = NULL;
+				return (_tmp7 = g_strdup ("gconstpointer"), (ptr = (g_free (ptr), NULL)), _tmp7);
+			} else {
 				char* _tmp8;
 				_tmp8 = NULL;
-				return (_tmp8 = g_strdup ("gconstpointer"), (ptr = (g_free (ptr), NULL)), _tmp8);
-			} else {
-				char* _tmp9;
-				_tmp9 = NULL;
-				return (_tmp9 = g_strdup ("gpointer"), (ptr = (g_free (ptr), NULL)), _tmp9);
+				return (_tmp8 = g_strdup ("gpointer"), (ptr = (g_free (ptr), NULL)), _tmp8);
 			}
 		} else {
-			gpointer _tmp10;
+			gpointer _tmp9;
 			/* raise error */
 			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
-			return (_tmp10 = NULL, (ptr = (g_free (ptr), NULL)), _tmp10);
+			return (_tmp9 = NULL, (ptr = (g_free (ptr), NULL)), _tmp9);
 		}
 	}
 	ptr = (g_free (ptr), NULL);
@@ -323,7 +313,7 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base) {
 					} else {
 						first = FALSE;
 					}
-					if (!type_arg->priv->_takes_ownership) {
+					if (vala_data_type_is_reference_type_or_type_parameter (type_arg) && !type_arg->priv->_takes_ownership) {
 						char* _tmp6;
 						_tmp6 = NULL;
 						s = (_tmp6 = g_strconcat (s, ("weak "), NULL), (s = (g_free (s), NULL)), _tmp6);
@@ -378,19 +368,13 @@ ValaDataType* vala_data_type_copy (ValaDataType* self) {
  */
 static gboolean vala_data_type_real_equals (ValaDataType* self, ValaDataType* type2) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	g_return_val_if_fail (type2 == NULL || VALA_IS_DATA_TYPE (type2), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type2), FALSE);
 	if (type2->priv->_transfers_ownership != self->priv->_transfers_ownership) {
 		return FALSE;
 	}
 	if (type2->priv->_takes_ownership != self->priv->_takes_ownership) {
 		return FALSE;
 	}
-	if (type2->priv->_is_ref != self->priv->_is_ref) {
-		return FALSE;
-	}
-	if (type2->priv->_is_out != self->priv->_is_out) {
-		return FALSE;
-	}
 	if (type2->priv->_nullable != self->priv->_nullable) {
 		return FALSE;
 	}
@@ -426,27 +410,21 @@ gboolean vala_data_type_equals (ValaDataType* self, ValaDataType* type2) {
  */
 static gboolean vala_data_type_real_stricter (ValaDataType* self, ValaDataType* type2) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	g_return_val_if_fail (type2 == NULL || VALA_IS_DATA_TYPE (type2), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type2), FALSE);
 	if (type2->priv->_transfers_ownership != self->priv->_transfers_ownership) {
 		return FALSE;
 	}
 	if (type2->priv->_takes_ownership != self->priv->_takes_ownership) {
 		return FALSE;
 	}
-	if (type2->priv->_is_ref != self->priv->_is_ref) {
-		return FALSE;
-	}
-	if (type2->priv->_is_out != self->priv->_is_out) {
-		return FALSE;
-	}
 	if (!type2->priv->_nullable && self->priv->_nullable) {
 		return FALSE;
 	}
 	if (type2->priv->_data_type != self->priv->_data_type) {
+		/* FIXME: allow this type reference to refer to a
+		        subtype of the type type2 is referring to*/
 		return FALSE;
 	}
-	/* FIXME: allow this type reference to refer to a
-	        subtype of the type type2 is referring to*/
 	if (type2->priv->_type_parameter != self->priv->_type_parameter) {
 		return FALSE;
 	}
@@ -465,12 +443,12 @@ gboolean vala_data_type_stricter (ValaDataType* self, ValaDataType* type2) {
 static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaDataType * self;
 	self = VALA_DATA_TYPE (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->type_argument_list)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->type_argument_list)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -483,11 +461,11 @@ static void vala_data_type_real_replace_type (ValaCodeNode* base, ValaDataType*
 }
 
 
-static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType* target_type) {
 	ValaAttribute* _tmp2;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	if (VALA_IS_DELEGATE_TYPE (target_type) && VALA_IS_DELEGATE_TYPE (self)) {
 		return vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (target_type))) == vala_delegate_type_get_delegate_symbol ((VALA_DELEGATE_TYPE (self)));
 	}
@@ -517,52 +495,44 @@ static gboolean vala_data_type_real_compatible (ValaDataType* self, ValaDataType
 		return TRUE;
 	}
 	if (self->priv->_data_type == target_type->priv->_data_type) {
-		if (self->priv->_requires_null_check && !target_type->priv->_nullable && self->priv->_data_type != NULL && vala_typesymbol_is_reference_type (self->priv->_data_type)) {
-			return !enable_non_null;
-		}
 		return TRUE;
 	}
-	/* incompatibility between null and non-null types*/
 	if (VALA_IS_STRUCT (self->priv->_data_type) && VALA_IS_STRUCT (target_type->priv->_data_type)) {
-		ValaStruct* _tmp13;
+		ValaStruct* _tmp12;
 		ValaStruct* expr_struct;
-		ValaStruct* _tmp14;
+		ValaStruct* _tmp13;
 		ValaStruct* expect_struct;
+		_tmp12 = NULL;
+		expr_struct = (_tmp12 = VALA_STRUCT (self->priv->_data_type), (_tmp12 == NULL ? NULL : g_object_ref (_tmp12)));
 		_tmp13 = NULL;
-		expr_struct = (_tmp13 = VALA_STRUCT (self->priv->_data_type), (_tmp13 == NULL ? NULL : g_object_ref (_tmp13)));
-		_tmp14 = NULL;
-		expect_struct = (_tmp14 = VALA_STRUCT (target_type->priv->_data_type), (_tmp14 == NULL ? NULL : g_object_ref (_tmp14)));
+		expect_struct = (_tmp13 = VALA_STRUCT (target_type->priv->_data_type), (_tmp13 == NULL ? NULL : g_object_ref (_tmp13)));
 		/* integer types may be implicitly cast to floating point types */
 		if (vala_struct_is_integer_type (expr_struct) && vala_struct_is_floating_type (expect_struct)) {
-			gboolean _tmp15;
-			return (_tmp15 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp15);
+			gboolean _tmp14;
+			return (_tmp14 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp14);
 		}
 		if ((vala_struct_is_integer_type (expr_struct) && vala_struct_is_integer_type (expect_struct)) || (vala_struct_is_floating_type (expr_struct) && vala_struct_is_floating_type (expect_struct))) {
 			if (vala_struct_get_rank (expr_struct) <= vala_struct_get_rank (expect_struct)) {
-				gboolean _tmp16;
-				return (_tmp16 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp16);
+				gboolean _tmp15;
+				return (_tmp15 = TRUE, (expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL))), (expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL))), _tmp15);
 			}
 		}
 		(expr_struct == NULL ? NULL : (expr_struct = (g_object_unref (expr_struct), NULL)));
 		(expect_struct == NULL ? NULL : (expect_struct = (g_object_unref (expect_struct), NULL)));
 	}
 	if (self->priv->_data_type != NULL && target_type->priv->_data_type != NULL && vala_typesymbol_is_subtype_of (self->priv->_data_type, target_type->priv->_data_type)) {
-		if (self->priv->_requires_null_check && !target_type->priv->_nullable && vala_typesymbol_is_reference_type (self->priv->_data_type)) {
-			return !enable_non_null;
-		}
 		return TRUE;
 	}
 	return FALSE;
 }
 
 
-gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_type, gboolean enable_non_null) {
-	return VALA_DATA_TYPE_GET_CLASS (self)->compatible (self, target_type, enable_non_null);
+gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_type) {
+	return VALA_DATA_TYPE_GET_CLASS (self)->compatible (self, target_type);
 }
 
 
-/* incompatibility between null and non-null types
-*
+/**
  * Returns whether instances of this type are invokable.
  *
  * @return true if invokable, false otherwise
@@ -655,6 +625,7 @@ GeeCollection* vala_data_type_get_symbols (ValaDataType* self) {
 
 static ValaSymbol* vala_data_type_real_get_member (ValaDataType* self, const char* member_name) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	if (self->priv->_data_type != NULL) {
 		return vala_semantic_analyzer_symbol_lookup_inherited (VALA_SYMBOL (self->priv->_data_type), member_name);
 	}
@@ -669,6 +640,7 @@ ValaSymbol* vala_data_type_get_member (ValaDataType* self, const char* member_na
 
 static ValaSymbol* vala_data_type_real_get_pointer_member (ValaDataType* self, const char* member_name) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	return NULL;
 }
 
@@ -719,6 +691,30 @@ char* vala_data_type_get_type_id (ValaDataType* self) {
 }
 
 
+/**
+ * Returns type signature as used for GVariant and D-Bus.
+ */
+char* vala_data_type_get_type_signature (ValaDataType* self) {
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
+	if (self->priv->_data_type != NULL) {
+		return vala_typesymbol_get_type_signature (self->priv->_data_type);
+	} else {
+		return NULL;
+	}
+}
+
+
+/**
+ * A reference to a data type. This is used to specify static types of
+ * expressions.
+ */
+ValaDataType* vala_data_type_new (void) {
+	ValaDataType * self;
+	self = g_object_newv (VALA_TYPE_DATA_TYPE, 0, NULL);
+	return self;
+}
+
+
 gboolean vala_data_type_get_transfers_ownership (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
 	return self->priv->_transfers_ownership;
@@ -743,18 +739,6 @@ void vala_data_type_set_takes_ownership (ValaDataType* self, gboolean value) {
 }
 
 
-gboolean vala_data_type_get_is_out (ValaDataType* self) {
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	return self->priv->_is_out;
-}
-
-
-void vala_data_type_set_is_out (ValaDataType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	self->priv->_is_out = value;
-}
-
-
 gboolean vala_data_type_get_nullable (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
 	return self->priv->_nullable;
@@ -767,18 +751,6 @@ void vala_data_type_set_nullable (ValaDataType* self, gboolean value) {
 }
 
 
-gboolean vala_data_type_get_requires_null_check (ValaDataType* self) {
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	return self->priv->_requires_null_check;
-}
-
-
-void vala_data_type_set_requires_null_check (ValaDataType* self, gboolean value) {
-	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	self->priv->_requires_null_check = value;
-}
-
-
 ValaTypesymbol* vala_data_type_get_data_type (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
 	return self->priv->_data_type;
@@ -819,15 +791,15 @@ void vala_data_type_set_floating_reference (ValaDataType* self, gboolean value)
 }
 
 
-gboolean vala_data_type_get_is_ref (ValaDataType* self) {
+gboolean vala_data_type_get_is_dynamic (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), FALSE);
-	return self->priv->_is_ref;
+	return self->priv->_is_dynamic;
 }
 
 
-void vala_data_type_set_is_ref (ValaDataType* self, gboolean value) {
+void vala_data_type_set_is_dynamic (ValaDataType* self, gboolean value) {
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	self->priv->_is_ref = value;
+	self->priv->_is_dynamic = value;
 }
 
 
@@ -841,15 +813,9 @@ static void vala_data_type_get_property (GObject * object, guint property_id, GV
 		case VALA_DATA_TYPE_TAKES_OWNERSHIP:
 		g_value_set_boolean (value, vala_data_type_get_takes_ownership (self));
 		break;
-		case VALA_DATA_TYPE_IS_OUT:
-		g_value_set_boolean (value, vala_data_type_get_is_out (self));
-		break;
 		case VALA_DATA_TYPE_NULLABLE:
 		g_value_set_boolean (value, vala_data_type_get_nullable (self));
 		break;
-		case VALA_DATA_TYPE_REQUIRES_NULL_CHECK:
-		g_value_set_boolean (value, vala_data_type_get_requires_null_check (self));
-		break;
 		case VALA_DATA_TYPE_DATA_TYPE:
 		g_value_set_object (value, vala_data_type_get_data_type (self));
 		break;
@@ -859,8 +825,8 @@ static void vala_data_type_get_property (GObject * object, guint property_id, GV
 		case VALA_DATA_TYPE_FLOATING_REFERENCE:
 		g_value_set_boolean (value, vala_data_type_get_floating_reference (self));
 		break;
-		case VALA_DATA_TYPE_IS_REF:
-		g_value_set_boolean (value, vala_data_type_get_is_ref (self));
+		case VALA_DATA_TYPE_IS_DYNAMIC:
+		g_value_set_boolean (value, vala_data_type_get_is_dynamic (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -879,15 +845,9 @@ static void vala_data_type_set_property (GObject * object, guint property_id, co
 		case VALA_DATA_TYPE_TAKES_OWNERSHIP:
 		vala_data_type_set_takes_ownership (self, g_value_get_boolean (value));
 		break;
-		case VALA_DATA_TYPE_IS_OUT:
-		vala_data_type_set_is_out (self, g_value_get_boolean (value));
-		break;
 		case VALA_DATA_TYPE_NULLABLE:
 		vala_data_type_set_nullable (self, g_value_get_boolean (value));
 		break;
-		case VALA_DATA_TYPE_REQUIRES_NULL_CHECK:
-		vala_data_type_set_requires_null_check (self, g_value_get_boolean (value));
-		break;
 		case VALA_DATA_TYPE_DATA_TYPE:
 		vala_data_type_set_data_type (self, g_value_get_object (value));
 		break;
@@ -897,8 +857,8 @@ static void vala_data_type_set_property (GObject * object, guint property_id, co
 		case VALA_DATA_TYPE_FLOATING_REFERENCE:
 		vala_data_type_set_floating_reference (self, g_value_get_boolean (value));
 		break;
-		case VALA_DATA_TYPE_IS_REF:
-		vala_data_type_set_is_ref (self, g_value_get_boolean (value));
+		case VALA_DATA_TYPE_IS_DYNAMIC:
+		vala_data_type_set_is_dynamic (self, g_value_get_boolean (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -933,13 +893,11 @@ static void vala_data_type_class_init (ValaDataTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_data_type_real_get_type_id;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "transfers-ownership", "transfers-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "takes-ownership", "takes-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_IS_OUT, g_param_spec_boolean ("is-out", "is-out", "is-out", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_NULLABLE, g_param_spec_boolean ("nullable", "nullable", "nullable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_REQUIRES_NULL_CHECK, g_param_spec_boolean ("requires-null-check", "requires-null-check", "requires-null-check", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_DATA_TYPE, g_param_spec_object ("data-type", "data-type", "data-type", VALA_TYPE_TYPESYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TYPE_PARAMETER, g_param_spec_object ("type-parameter", "type-parameter", "type-parameter", VALA_TYPE_TYPEPARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_FLOATING_REFERENCE, g_param_spec_boolean ("floating-reference", "floating-reference", "floating-reference", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_IS_REF, g_param_spec_boolean ("is-ref", "is-ref", "is-ref", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_IS_DYNAMIC, g_param_spec_boolean ("is-dynamic", "is-dynamic", "is-dynamic", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
