@@ -1,6 +1,6 @@
 /* valadeclarationstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,12 +21,15 @@
  */
 
 #include <vala/valadeclarationstatement.h>
-#include <vala/valalocalvariabledeclaration.h>
+#include <vala/valasymbol.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaDeclarationStatementPrivate {
-	ValaLocalVariableDeclaration* _declaration;
+	ValaSymbol* _declaration;
 };
 #define VALA_DECLARATION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DECLARATION_STATEMENT, ValaDeclarationStatementPrivate))
 enum  {
@@ -39,6 +42,7 @@ static ValaStatementIface* vala_declaration_statement_vala_statement_parent_ifac
 static void vala_declaration_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new declaration statement.
  *
@@ -46,20 +50,20 @@ static void vala_declaration_statement_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created declaration statement
  */
-ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source) {
+ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaDeclarationStatement * self;
-	g_return_val_if_fail (decl == NULL || VALA_IS_LOCAL_VARIABLE_DECLARATION (decl), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SYMBOL (declaration), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "declaration";
-	g_value_init (&__params_it->value, VALA_TYPE_LOCAL_VARIABLE_DECLARATION);
-	g_value_set_object (&__params_it->value, decl);
+	g_value_init (&__params_it->value, VALA_TYPE_SYMBOL);
+	g_value_set_object (&__params_it->value, declaration);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_DECLARATION_STATEMENT, __params_it - __params, __params);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -72,21 +76,21 @@ ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDecla
 static void vala_declaration_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDeclarationStatement * self;
 	self = VALA_DECLARATION_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_declaration_statement_get_declaration (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_declaration), visitor);
 	vala_code_visitor_visit_declaration_statement (visitor, self);
 }
 
 
-ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self) {
+ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self) {
 	g_return_val_if_fail (VALA_IS_DECLARATION_STATEMENT (self), NULL);
 	return self->priv->_declaration;
 }
 
 
-void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value) {
-	ValaLocalVariableDeclaration* _tmp2;
-	ValaLocalVariableDeclaration* _tmp1;
+void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaSymbol* value) {
+	ValaSymbol* _tmp2;
+	ValaSymbol* _tmp1;
 	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
@@ -129,7 +133,7 @@ static void vala_declaration_statement_class_init (ValaDeclarationStatementClass
 	G_OBJECT_CLASS (klass)->set_property = vala_declaration_statement_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_declaration_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_declaration_statement_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "declaration", "declaration", VALA_TYPE_LOCAL_VARIABLE_DECLARATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DECLARATION_STATEMENT_DECLARATION, g_param_spec_object ("declaration", "declaration", "declaration", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
