@@ -88,7 +88,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaDelegate * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_DELEGATE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -105,7 +105,7 @@ ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, Va
  */
 void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_TYPESYMBOL (self);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
@@ -119,7 +119,7 @@ void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p)
  */
 void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_delegate_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
@@ -156,7 +156,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 	gboolean first;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
-	g_return_val_if_fail (m == NULL || VALA_IS_METHOD (m), FALSE);
+	g_return_val_if_fail (VALA_IS_METHOD (m), FALSE);
 	/* method is allowed to ensure stricter return type (stronger postcondition)*/
 	if (!vala_data_type_stricter (vala_method_get_return_type (m), vala_delegate_get_return_type (self))) {
 		return FALSE;
@@ -212,7 +212,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_delegate (visitor, self);
 }
 
@@ -220,7 +220,7 @@ static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* p_collection;
 		GeeIterator* p_it;
@@ -281,6 +281,7 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -289,7 +290,7 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 
 static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -398,8 +399,8 @@ static char* vala_delegate_real_get_set_value_function (ValaTypesymbol* base) {
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_delegate_get_return_type (self) == old_type) {
 		vala_delegate_set_return_type (self, new_type);
 	}
