@@ -88,10 +88,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference) {
 	ValaEnum * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ENUM, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -103,7 +104,7 @@ ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference
  */
 void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (value == NULL || VALA_IS_ENUM_VALUE (value));
+	g_return_if_fail (VALA_IS_ENUM_VALUE (value));
 	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (value)), VALA_SYMBOL (value));
 }
@@ -116,7 +117,7 @@ void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value) {
  */
 void vala_enum_add_method (ValaEnum* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
 		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
@@ -162,7 +163,7 @@ GeeCollection* vala_enum_get_methods (ValaEnum* self) {
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum (visitor, self);
 }
 
@@ -170,7 +171,7 @@ static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnum * self;
 	self = VALA_ENUM (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* value_collection;
 		GeeIterator* value_it;
@@ -289,6 +290,7 @@ static void vala_enum_set_cname (ValaEnum* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -327,6 +329,7 @@ void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ENUM (self));
+	g_return_if_fail (cprefix != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
@@ -335,7 +338,7 @@ void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix) {
 
 static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_ENUM (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
