@@ -62,10 +62,14 @@ GeeCollection* vala_enum_get_methods (ValaEnum* self);
 char* vala_enum_get_cprefix (ValaEnum* self);
 void vala_enum_set_cprefix (ValaEnum* self, const char* cprefix);
 void vala_enum_process_attributes (ValaEnum* self);
+void vala_enum_set_type_id (ValaEnum* self, const char* type_id);
 gboolean vala_enum_get_is_flags (ValaEnum* self);
 void vala_enum_set_is_flags (ValaEnum* self, gboolean value);
+gboolean vala_enum_get_has_type_id (ValaEnum* self);
+void vala_enum_set_has_type_id (ValaEnum* self, gboolean value);
 GType vala_enum_get_type (void);
 
+
 G_END_DECLS
 
 #endif
