@@ -53,10 +53,11 @@ static void vala_enum_value_dispose (GObject * obj);
  */
 ValaEnumValue* vala_enum_value_new (const char* name, ValaSourceReference* source_reference) {
 	ValaEnumValue * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -70,12 +71,13 @@ ValaEnumValue* vala_enum_value_new (const char* name, ValaSourceReference* sourc
  */
 ValaEnumValue* vala_enum_value_new_with_value (const char* name, ValaExpression* value, ValaSourceReference* source_reference) {
 	ValaEnumValue * self;
-	g_return_val_if_fail (value == NULL || VALA_IS_EXPRESSION (value), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (value), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ENUM_VALUE, 0, NULL);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_enum_value_set_value (self, value);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -118,7 +120,7 @@ ValaCCodeConstant* vala_enum_value_get_canonical_cconstant (ValaEnumValue* self)
 static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum_value (visitor, self);
 }
 
@@ -126,7 +128,7 @@ static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaEnumValue * self;
 	self = VALA_ENUM_VALUE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (self->priv->_value != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_value), visitor);
 	}
