@@ -82,10 +82,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* source_reference) {
 	ValaErrorDomain * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ERROR_DOMAIN, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -97,7 +98,7 @@ ValaErrorDomain* vala_error_domain_new (const char* name, ValaSourceReference* s
  */
 void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
 	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (ecode == NULL || VALA_IS_ERROR_CODE (ecode));
+	g_return_if_fail (VALA_IS_ERROR_CODE (ecode));
 	gee_collection_add (GEE_COLLECTION (self->priv->codes), ecode);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ecode)), VALA_SYMBOL (ecode));
 }
@@ -110,7 +111,7 @@ void vala_error_domain_add_code (ValaErrorDomain* self, ValaErrorCode* ecode) {
  */
 void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
 		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
@@ -156,7 +157,7 @@ GeeCollection* vala_error_domain_get_methods (ValaErrorDomain* self) {
 static void vala_error_domain_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorDomain * self;
 	self = VALA_ERROR_DOMAIN (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_error_domain (visitor, self);
 }
 
@@ -164,7 +165,7 @@ static void vala_error_domain_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_error_domain_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorDomain * self;
 	self = VALA_ERROR_DOMAIN (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* ecode_collection;
 		GeeIterator* ecode_it;
@@ -283,6 +284,7 @@ static void vala_error_domain_set_cname (ValaErrorDomain* self, const char* cnam
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -321,6 +323,7 @@ void vala_error_domain_set_cprefix (ValaErrorDomain* self, const char* cprefix)
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
+	g_return_if_fail (cprefix != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cprefix = (g_free (self->priv->cprefix), NULL)), _tmp1);
@@ -329,7 +332,7 @@ void vala_error_domain_set_cprefix (ValaErrorDomain* self, const char* cprefix)
 
 static void vala_error_domain_process_ccode_attribute (ValaErrorDomain* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_ERROR_DOMAIN (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
