@@ -1,6 +1,6 @@
 /* valaexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,18 +21,22 @@
  */
 
 #include <vala/valaexpression.h>
-#include <vala/valatypereference.h>
+#include <vala/valadatatype.h>
 #include <vala/valasymbol.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
+
+
+
 
 struct _ValaExpressionPrivate {
-	ValaTypeReference* _static_type;
-	ValaTypeReference* _expected_type;
+	ValaDataType* _static_type;
+	ValaDataType* _expected_type;
 	ValaSymbol* _symbol_reference;
 	gboolean _ref_leaked;
 	gboolean _ref_missing;
 	gboolean _ref_sink;
 	gboolean _can_fail;
+	gboolean _lvalue;
 };
 #define VALA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_EXPRESSION, ValaExpressionPrivate))
 enum  {
@@ -43,21 +47,42 @@ enum  {
 	VALA_EXPRESSION_REF_LEAKED,
 	VALA_EXPRESSION_REF_MISSING,
 	VALA_EXPRESSION_REF_SINK,
-	VALA_EXPRESSION_CAN_FAIL
+	VALA_EXPRESSION_CAN_FAIL,
+	VALA_EXPRESSION_LVALUE
 };
 static gpointer vala_expression_parent_class = NULL;
 static void vala_expression_dispose (GObject * obj);
 
 
-ValaTypeReference* vala_expression_get_static_type (ValaExpression* self) {
+
+/**
+ * Returns whether this expression is pure, i.e. whether this expression
+ * is free of side-effects.
+ */
+gboolean vala_expression_is_pure (ValaExpression* self) {
+	return VALA_EXPRESSION_GET_CLASS (self)->is_pure (self);
+}
+
+
+/**
+ * Base class for all code nodes that might be used as an expression.
+ */
+ValaExpression* vala_expression_new (void) {
+	ValaExpression * self;
+	self = g_object_newv (VALA_TYPE_EXPRESSION, 0, NULL);
+	return self;
+}
+
+
+ValaDataType* vala_expression_get_static_type (ValaExpression* self) {
 	g_return_val_if_fail (VALA_IS_EXPRESSION (self), NULL);
 	return self->priv->_static_type;
 }
 
 
-void vala_expression_set_static_type (ValaExpression* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+void vala_expression_set_static_type (ValaExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
@@ -65,15 +90,15 @@ void vala_expression_set_static_type (ValaExpression* self, ValaTypeReference* v
 }
 
 
-ValaTypeReference* vala_expression_get_expected_type (ValaExpression* self) {
+ValaDataType* vala_expression_get_expected_type (ValaExpression* self) {
 	g_return_val_if_fail (VALA_IS_EXPRESSION (self), NULL);
 	return self->priv->_expected_type;
 }
 
 
-void vala_expression_set_expected_type (ValaExpression* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp2;
-	ValaTypeReference* _tmp1;
+void vala_expression_set_expected_type (ValaExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_EXPRESSION (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
@@ -141,6 +166,18 @@ void vala_expression_set_can_fail (ValaExpression* self, gboolean value) {
 }
 
 
+gboolean vala_expression_get_lvalue (ValaExpression* self) {
+	g_return_val_if_fail (VALA_IS_EXPRESSION (self), FALSE);
+	return self->priv->_lvalue;
+}
+
+
+void vala_expression_set_lvalue (ValaExpression* self, gboolean value) {
+	g_return_if_fail (VALA_IS_EXPRESSION (self));
+	self->priv->_lvalue = value;
+}
+
+
 static void vala_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaExpression * self;
 	self = VALA_EXPRESSION (object);
@@ -166,6 +203,9 @@ static void vala_expression_get_property (GObject * object, guint property_id, G
 		case VALA_EXPRESSION_CAN_FAIL:
 		g_value_set_boolean (value, vala_expression_get_can_fail (self));
 		break;
+		case VALA_EXPRESSION_LVALUE:
+		g_value_set_boolean (value, vala_expression_get_lvalue (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -198,6 +238,9 @@ static void vala_expression_set_property (GObject * object, guint property_id, c
 		case VALA_EXPRESSION_CAN_FAIL:
 		vala_expression_set_can_fail (self, g_value_get_boolean (value));
 		break;
+		case VALA_EXPRESSION_LVALUE:
+		vala_expression_set_lvalue (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -211,19 +254,20 @@ static void vala_expression_class_init (ValaExpressionClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_expression_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_STATIC_TYPE, g_param_spec_object ("static-type", "static-type", "static-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_EXPECTED_TYPE, g_param_spec_object ("expected-type", "expected-type", "expected-type", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_STATIC_TYPE, g_param_spec_object ("static-type", "static-type", "static-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_EXPECTED_TYPE, g_param_spec_object ("expected-type", "expected-type", "expected-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_SYMBOL_REFERENCE, g_param_spec_object ("symbol-reference", "symbol-reference", "symbol-reference", VALA_TYPE_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_REF_LEAKED, g_param_spec_boolean ("ref-leaked", "ref-leaked", "ref-leaked", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_REF_MISSING, g_param_spec_boolean ("ref-missing", "ref-missing", "ref-missing", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_REF_SINK, g_param_spec_boolean ("ref-sink", "ref-sink", "ref-sink", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_CAN_FAIL, g_param_spec_boolean ("can-fail", "can-fail", "can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_EXPRESSION_LVALUE, g_param_spec_boolean ("lvalue", "lvalue", "lvalue", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_expression_init (ValaExpression * self) {
 	self->priv = VALA_EXPRESSION_GET_PRIVATE (self);
-	self->temp_vars = gee_array_list_new (VALA_TYPE_VARIABLE_DECLARATOR, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	self->temp_vars = gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
 }
 
 
