@@ -1,6 +1,6 @@
 /* valafield.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -51,7 +51,6 @@ enum  {
 };
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_field_set_cname (ValaField* self, const char* cname);
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a);
 static gboolean vala_field_real_get_lock_used (ValaLockable* base);
 static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used);
@@ -75,14 +74,15 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaField * self;
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_FIELD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_field_set_type_reference (self, type_reference);
 	vala_field_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -90,7 +90,7 @@ ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaE
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_field (visitor, self);
 }
@@ -99,7 +99,7 @@ static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
@@ -125,10 +125,16 @@ char* vala_field_get_cname (ValaField* self) {
 }
 
 
-static void vala_field_set_cname (ValaField* self, const char* cname) {
+/**
+ * Sets the name of this field as it is used in C code.
+ *
+ * @param cname the name to be used in C code
+ */
+void vala_field_set_cname (ValaField* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_FIELD (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -158,7 +164,7 @@ char* vala_field_get_default_cname (ValaField* self) {
 
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FIELD (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -237,8 +243,8 @@ static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used) {
 static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_field_get_type_reference (self) == old_type) {
 		vala_field_set_type_reference (self, new_type);
 	}
