@@ -47,30 +47,31 @@ typedef struct _ValaForeachStatementPrivate ValaForeachStatementPrivate;
  * over the elements of a collection.
  */
 struct _ValaForeachStatement {
-	ValaBlock parent;
+	ValaBlock parent_instance;
 	ValaForeachStatementPrivate * priv;
 };
 struct _ValaForeachStatementClass {
-	ValaBlockClass parent;
+	ValaBlockClass parent_class;
 };
 
-ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
-ValaTypeReference* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
-void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaTypeReference* value);
+ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
+ValaDataType* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
+void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaDataType* value);
 char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self);
 void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const char* value);
 ValaExpression* vala_foreach_statement_get_collection (ValaForeachStatement* self);
 void vala_foreach_statement_set_collection (ValaForeachStatement* self, ValaExpression* value);
 ValaBlock* vala_foreach_statement_get_body (ValaForeachStatement* self);
 void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaBlock* value);
-ValaVariableDeclarator* vala_foreach_statement_get_variable_declarator (ValaForeachStatement* self);
-void vala_foreach_statement_set_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
-ValaVariableDeclarator* vala_foreach_statement_get_collection_variable_declarator (ValaForeachStatement* self);
-void vala_foreach_statement_set_collection_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
-ValaVariableDeclarator* vala_foreach_statement_get_iterator_variable_declarator (ValaForeachStatement* self);
-void vala_foreach_statement_set_iterator_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
+ValaLocalVariable* vala_foreach_statement_get_element_variable (ValaForeachStatement* self);
+void vala_foreach_statement_set_element_variable (ValaForeachStatement* self, ValaLocalVariable* value);
+ValaLocalVariable* vala_foreach_statement_get_collection_variable (ValaForeachStatement* self);
+void vala_foreach_statement_set_collection_variable (ValaForeachStatement* self, ValaLocalVariable* value);
+ValaLocalVariable* vala_foreach_statement_get_iterator_variable (ValaForeachStatement* self);
+void vala_foreach_statement_set_iterator_variable (ValaForeachStatement* self, ValaLocalVariable* value);
 GType vala_foreach_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
