@@ -29,6 +29,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaForStatementPrivate {
 	GeeList* initializer;
 	GeeList* iterator;
@@ -49,6 +52,7 @@ static ValaStatementIface* vala_for_statement_vala_statement_parent_iface = NULL
 static void vala_for_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new for statement.
  *
@@ -61,8 +65,8 @@ ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock*
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForStatement * self;
-	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -89,7 +93,7 @@ ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock*
  */
 void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init) {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	g_return_if_fail (init == NULL || VALA_IS_EXPRESSION (init));
+	g_return_if_fail (VALA_IS_EXPRESSION (init));
 	vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializer), init);
 }
@@ -113,7 +117,7 @@ GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self) {
  */
 void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter) {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	g_return_if_fail (iter == NULL || VALA_IS_EXPRESSION (iter));
+	g_return_if_fail (VALA_IS_EXPRESSION (iter));
 	vala_code_node_set_parent_node (VALA_CODE_NODE (iter), VALA_CODE_NODE (self));
 	gee_collection_add (GEE_COLLECTION (self->priv->iterator), iter);
 }
@@ -133,7 +137,7 @@ GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self) {
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_for_statement (visitor, self);
 }
 
@@ -141,7 +145,7 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* init_expr_collection;
 		GeeIterator* init_expr_it;
@@ -185,8 +189,8 @@ static void vala_for_statement_real_accept_children (ValaCodeNode* base, ValaCod
 static void vala_for_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_for_statement_get_condition (self) == old_node) {
 		vala_for_statement_set_condition (self, new_node);
 		return;
@@ -194,7 +198,7 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->initializer)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->initializer)); i++) {
 			ValaExpression* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -207,7 +211,7 @@ static void vala_for_statement_real_replace_expression (ValaCodeNode* base, Vala
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->iterator)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->iterator)); i++) {
 			ValaExpression* _tmp2;
 			gboolean _tmp3;
 			_tmp2 = NULL;
