@@ -28,6 +28,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaInitializerListPrivate {
 	GeeList* initializers;
 };
@@ -38,10 +41,12 @@ enum  {
 };
 static void vala_initializer_list_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_initializer_list_real_is_pure (ValaExpression* base);
 static gpointer vala_initializer_list_parent_class = NULL;
 static void vala_initializer_list_dispose (GObject * obj);
 
 
+
 /**
  * Appends the specified expression to this initializer list.
  *
@@ -73,7 +78,7 @@ GeeCollection* vala_initializer_list_get_initializers (ValaInitializerList* self
  */
 ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference) {
 	ValaInitializerList * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_INITIALIZER_LIST, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -91,7 +96,7 @@ static void vala_initializer_list_real_accept_children (ValaCodeNode* base, Vala
 		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
 		while (gee_iterator_next (expr_it)) {
 			ValaExpression* expr;
-			expr = gee_iterator_get (expr_it);
+			expr = ((ValaExpression*) gee_iterator_get (expr_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (expr), visitor);
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
@@ -110,6 +115,31 @@ static void vala_initializer_list_real_accept (ValaCodeNode* base, ValaCodeVisit
 }
 
 
+static gboolean vala_initializer_list_real_is_pure (ValaExpression* base) {
+	ValaInitializerList * self;
+	self = VALA_INITIALIZER_LIST (base);
+	{
+		GeeList* initializer_collection;
+		GeeIterator* initializer_it;
+		initializer_collection = self->priv->initializers;
+		initializer_it = gee_iterable_iterator (GEE_ITERABLE (initializer_collection));
+		while (gee_iterator_next (initializer_it)) {
+			ValaExpression* initializer;
+			initializer = ((ValaExpression*) gee_iterator_get (initializer_it));
+			{
+				if (!vala_expression_is_pure (initializer)) {
+					gboolean _tmp0;
+					return (_tmp0 = FALSE, (initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL))), (initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL))), _tmp0);
+				}
+				(initializer == NULL ? NULL : (initializer = (g_object_unref (initializer), NULL)));
+			}
+		}
+		(initializer_it == NULL ? NULL : (initializer_it = (g_object_unref (initializer_it), NULL)));
+	}
+	return TRUE;
+}
+
+
 gint vala_initializer_list_get_size (ValaInitializerList* self) {
 	g_return_val_if_fail (VALA_IS_INITIALIZER_LIST (self), 0);
 	return gee_collection_get_size (GEE_COLLECTION (self->priv->initializers));
@@ -137,6 +167,7 @@ static void vala_initializer_list_class_init (ValaInitializerListClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_initializer_list_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_initializer_list_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_initializer_list_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_initializer_list_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INITIALIZER_LIST_SIZE, g_param_spec_int ("size", "size", "size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
