@@ -46,11 +46,11 @@ typedef struct _ValaInitializerListPrivate ValaInitializerListPrivate;
  * Represents an array or struct initializer list in the source code.
  */
 struct _ValaInitializerList {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaInitializerListPrivate * priv;
 };
 struct _ValaInitializerListClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr);
@@ -59,6 +59,7 @@ ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_refe
 gint vala_initializer_list_get_size (ValaInitializerList* self);
 GType vala_initializer_list_get_type (void);
 
+
 G_END_DECLS
 
 #endif
