@@ -25,6 +25,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+
+
+
 struct _ValaInstanceCastPrivate {
 	ValaTypesymbol* _type_reference;
 	ValaCCodeExpression* _inner;
@@ -40,6 +43,7 @@ static gpointer vala_instance_cast_parent_class = NULL;
 static void vala_instance_cast_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new instance cast expression.
  *
@@ -51,8 +55,8 @@ ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypesym
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInstanceCast * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (type == NULL || VALA_IS_TYPESYMBOL (type), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -115,10 +119,10 @@ static GObject * vala_instance_cast_constructor (GType type, guint n_construct_p
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_ccode_function_call_set_call (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ((_tmp0 = vala_typesymbol_get_upper_case_cname (vala_instance_cast_get_type_reference (self), NULL))))));
+		vala_ccode_function_call_set_call (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ((_tmp0 = vala_typesymbol_get_upper_case_cname (self->priv->_type_reference, NULL))))));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		_tmp0 = (g_free (_tmp0), NULL);
-		vala_ccode_function_call_add_argument (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION (vala_instance_cast_get_inner (self)));
+		vala_ccode_function_call_add_argument (VALA_CCODE_FUNCTION_CALL (self), VALA_CCODE_EXPRESSION (self->priv->_inner));
 	}
 	return obj;
 }
