@@ -42,17 +42,17 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valainterfacetype.h>
 #include <vala/valavoidtype.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valacodegenerator.h>
 
 
 
 
 struct _ValaInterfacePrivate {
 	gboolean _is_static;
-	gboolean _declaration_only;
 	GeeList* type_parameters;
 	GeeList* prerequisites;
 	GeeList* methods;
@@ -71,8 +71,7 @@ struct _ValaInterfacePrivate {
 #define VALA_INTERFACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE, ValaInterfacePrivate))
 enum  {
 	VALA_INTERFACE_DUMMY_PROPERTY,
-	VALA_INTERFACE_IS_STATIC,
-	VALA_INTERFACE_DECLARATION_ONLY
+	VALA_INTERFACE_IS_STATIC
 };
 static char* vala_interface_real_get_cname (ValaTypesymbol* base, gboolean const_type);
 static char* vala_interface_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
@@ -86,13 +85,13 @@ static char* vala_interface_real_get_ref_function (ValaTypesymbol* base);
 static char* vala_interface_real_get_unref_function (ValaTypesymbol* base);
 static gboolean vala_interface_real_is_subtype_of (ValaTypesymbol* base, ValaTypesymbol* t);
 static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAttribute* a);
-static void vala_interface_process_dbus_interface_attribute (ValaInterface* self, ValaAttribute* a);
 static char* vala_interface_real_get_marshaller_type_name (ValaTypesymbol* base);
 static char* vala_interface_real_get_get_value_function (ValaTypesymbol* base);
 static char* vala_interface_real_get_set_value_function (ValaTypesymbol* base);
 static char* vala_interface_real_get_type_id (ValaTypesymbol* base);
 static gint vala_interface_real_get_type_parameter_index (ValaTypesymbol* base, const char* name);
 static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static ValaCodeBinding* vala_interface_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_interface_parent_class = NULL;
 static void vala_interface_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -109,10 +108,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source_reference) {
 	ValaInterface * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_INTERFACE, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -124,7 +124,7 @@ ValaInterface* vala_interface_new (const char* name, ValaSourceReference* source
  */
 void vala_interface_add_type_parameter (ValaInterface* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_TYPESYMBOL (self);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
@@ -150,7 +150,7 @@ GeeCollection* vala_interface_get_type_parameters (ValaInterface* self) {
  */
 void vala_interface_add_prerequisite (ValaInterface* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	gee_collection_add (GEE_COLLECTION (self->priv->prerequisites), type);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (type), VALA_CODE_NODE (self));
 }
@@ -164,7 +164,7 @@ void vala_interface_add_prerequisite (ValaInterface* self, ValaDataType* type) {
  */
 void vala_interface_prepend_prerequisite (ValaInterface* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	gee_list_insert (self->priv->prerequisites, 0, type);
 }
 
@@ -189,7 +189,7 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 	GeeCollection* _tmp2;
 	gboolean _tmp3;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	if (VALA_IS_CREATION_METHOD (m)) {
 		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "construction methods may only be declared within classes and structs");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
@@ -207,14 +207,13 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 	}
 	_tmp2 = NULL;
 	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size ((_tmp2 = vala_method_get_postconditions (m))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
-		ValaVariableDeclarator* _tmp4;
-		ValaDataType* _tmp5;
-		_tmp4 = NULL;
-		vala_method_set_result_var (m, (_tmp4 = vala_variable_declarator_new ("result", NULL, NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		ValaLocalVariable* _tmp5;
+		ValaDataType* _tmp4;
 		_tmp5 = NULL;
-		vala_variable_declarator_set_type_reference (vala_method_get_result_var (m), (_tmp5 = vala_data_type_copy (vala_method_get_return_type (m))));
+		_tmp4 = NULL;
+		vala_method_set_result_var (m, (_tmp5 = vala_local_variable_new ((_tmp4 = vala_data_type_copy (vala_method_get_return_type (m))), "result", NULL, NULL)));
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
@@ -241,7 +240,7 @@ GeeCollection* vala_interface_get_methods (ValaInterface* self) {
  */
 void vala_interface_add_field (ValaInterface* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (f)), VALA_SYMBOL (f));
 }
@@ -265,7 +264,7 @@ GeeCollection* vala_interface_get_fields (ValaInterface* self) {
  */
 void vala_interface_add_property (ValaInterface* self, ValaProperty* prop) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	gee_collection_add (GEE_COLLECTION (self->priv->properties), prop);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (prop)), VALA_SYMBOL (prop));
 }
@@ -289,7 +288,7 @@ GeeCollection* vala_interface_get_properties (ValaInterface* self) {
  */
 void vala_interface_add_signal (ValaInterface* self, ValaSignal* sig) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	gee_collection_add (GEE_COLLECTION (self->priv->signals), sig);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (sig)), VALA_SYMBOL (sig));
 }
@@ -313,7 +312,7 @@ GeeCollection* vala_interface_get_signals (ValaInterface* self) {
  */
 void vala_interface_add_class (ValaInterface* self, ValaClass* cl) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 	gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
 }
@@ -326,7 +325,7 @@ void vala_interface_add_class (ValaInterface* self, ValaClass* cl) {
  */
 void vala_interface_add_struct (ValaInterface* self, ValaStruct* st) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 	gee_collection_add (GEE_COLLECTION (self->priv->structs), st);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (st)), VALA_SYMBOL (st));
 }
@@ -339,7 +338,7 @@ void vala_interface_add_struct (ValaInterface* self, ValaStruct* st) {
  */
 void vala_interface_add_enum (ValaInterface* self, ValaEnum* en) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	g_return_if_fail (VALA_IS_ENUM (en));
 	gee_collection_add (GEE_COLLECTION (self->priv->enums), en);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (en)), VALA_SYMBOL (en));
 }
@@ -352,7 +351,7 @@ void vala_interface_add_enum (ValaInterface* self, ValaEnum* en) {
  */
 void vala_interface_add_delegate (ValaInterface* self, ValaDelegate* d) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	g_return_if_fail (VALA_IS_DELEGATE (d));
 	gee_collection_add (GEE_COLLECTION (self->priv->delegates), d);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (d)), VALA_SYMBOL (d));
 }
@@ -440,6 +439,7 @@ void vala_interface_set_lower_case_csuffix (ValaInterface* self, const char* csu
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (csuffix != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->lower_case_csuffix = (_tmp1 = (_tmp0 = csuffix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), _tmp1);
@@ -487,7 +487,7 @@ static char* vala_interface_real_get_upper_case_cname (ValaTypesymbol* base, con
 static void vala_interface_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_interface (visitor, self);
 }
 
@@ -495,7 +495,7 @@ static void vala_interface_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
 static void vala_interface_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* type_collection;
 		GeeIterator* type_it;
@@ -680,7 +680,7 @@ static char* vala_interface_real_get_unref_function (ValaTypesymbol* base) {
 static gboolean vala_interface_real_is_subtype_of (ValaTypesymbol* base, ValaTypesymbol* t) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	g_return_val_if_fail (t == NULL || VALA_IS_TYPESYMBOL (t), FALSE);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (t), FALSE);
 	if (VALA_TYPESYMBOL (self) == t) {
 		return TRUE;
 	}
@@ -708,7 +708,7 @@ static gboolean vala_interface_real_is_subtype_of (ValaTypesymbol* base, ValaTyp
 
 static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "type_cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -746,17 +746,6 @@ static void vala_interface_process_ccode_attribute (ValaInterface* self, ValaAtt
 }
 
 
-static void vala_interface_process_dbus_interface_attribute (ValaInterface* self, ValaAttribute* a) {
-	g_return_if_fail (VALA_IS_INTERFACE (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
-	if (self->priv->_declaration_only) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = g_strdup ("DBusGProxy"), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
-	}
-}
-
-
 /**
  * Process all associated attributes.
  */
@@ -774,10 +763,6 @@ void vala_interface_process_attributes (ValaInterface* self) {
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_interface_process_ccode_attribute (self, a);
-				} else {
-					if (_vala_strcmp0 (vala_attribute_get_name (a), "DBusInterface") == 0) {
-						vala_interface_process_dbus_interface_attribute (self, a);
-					}
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
@@ -816,6 +801,7 @@ void vala_interface_set_type_cname (ValaInterface* self, const char* type_cname)
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_INTERFACE (self));
+	g_return_if_fail (type_cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->type_cname = (_tmp1 = (_tmp0 = type_cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->type_cname = (g_free (self->priv->type_cname), NULL)), _tmp1);
@@ -861,6 +847,7 @@ static gint vala_interface_real_get_type_parameter_index (ValaTypesymbol* base,
 	ValaInterface * self;
 	gint i;
 	self = VALA_INTERFACE (base);
+	g_return_val_if_fail (name != NULL, 0);
 	i = 0;
 	{
 		GeeList* parameter_collection;
@@ -888,12 +875,12 @@ static gint vala_interface_real_get_type_parameter_index (ValaTypesymbol* base,
 static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->prerequisites)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->prerequisites)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -906,6 +893,14 @@ static void vala_interface_real_replace_type (ValaCodeNode* base, ValaDataType*
 }
 
 
+static ValaCodeBinding* vala_interface_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaInterface * self;
+	self = VALA_INTERFACE (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_interface_binding (codegen, self);
+}
+
+
 gboolean vala_interface_get_is_static (ValaInterface* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE (self), FALSE);
 	return self->priv->_is_static;
@@ -918,18 +913,6 @@ void vala_interface_set_is_static (ValaInterface* self, gboolean value) {
 }
 
 
-gboolean vala_interface_get_declaration_only (ValaInterface* self) {
-	g_return_val_if_fail (VALA_IS_INTERFACE (self), FALSE);
-	return self->priv->_declaration_only;
-}
-
-
-void vala_interface_set_declaration_only (ValaInterface* self, gboolean value) {
-	g_return_if_fail (VALA_IS_INTERFACE (self));
-	self->priv->_declaration_only = value;
-}
-
-
 static void vala_interface_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaInterface * self;
 	self = VALA_INTERFACE (object);
@@ -937,9 +920,6 @@ static void vala_interface_get_property (GObject * object, guint property_id, GV
 		case VALA_INTERFACE_IS_STATIC:
 		g_value_set_boolean (value, vala_interface_get_is_static (self));
 		break;
-		case VALA_INTERFACE_DECLARATION_ONLY:
-		g_value_set_boolean (value, vala_interface_get_declaration_only (self));
-		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -954,9 +934,6 @@ static void vala_interface_set_property (GObject * object, guint property_id, co
 		case VALA_INTERFACE_IS_STATIC:
 		vala_interface_set_is_static (self, g_value_get_boolean (value));
 		break;
-		case VALA_INTERFACE_DECLARATION_ONLY:
-		vala_interface_set_declaration_only (self, g_value_get_boolean (value));
-		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -987,8 +964,8 @@ static void vala_interface_class_init (ValaInterfaceClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_id = vala_interface_real_get_type_id;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_parameter_index = vala_interface_real_get_type_parameter_index;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_interface_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_interface_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_IS_STATIC, g_param_spec_boolean ("is-static", "is-static", "is-static", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_DECLARATION_ONLY, g_param_spec_boolean ("declaration-only", "declaration-only", "declaration-only", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
