@@ -30,6 +30,7 @@
 #include <gee/collection.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -80,8 +81,6 @@ char* vala_interface_get_type_cname (ValaInterface* self);
 void vala_interface_set_type_cname (ValaInterface* self, const char* type_cname);
 gboolean vala_interface_get_is_static (ValaInterface* self);
 void vala_interface_set_is_static (ValaInterface* self, gboolean value);
-gboolean vala_interface_get_declaration_only (ValaInterface* self);
-void vala_interface_set_declaration_only (ValaInterface* self, gboolean value);
 GType vala_interface_get_type (void);
 
 
