@@ -1,6 +1,6 @@
 /* valainvocationexpression.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,7 @@
 #include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -47,12 +48,12 @@ typedef struct _ValaInvocationExpressionPrivate ValaInvocationExpressionPrivate;
  * Represents an invocation expression in the source code.
  */
 struct _ValaInvocationExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaInvocationExpressionPrivate * priv;
 	ValaExpression* _call;
 };
 struct _ValaInvocationExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaInvocationExpression* vala_invocation_expression_new (ValaExpression* call, ValaSourceReference* source_reference);
@@ -62,8 +63,11 @@ void vala_invocation_expression_append_array_size (ValaInvocationExpression* sel
 GeeList* vala_invocation_expression_get_array_sizes (ValaInvocationExpression* self);
 ValaExpression* vala_invocation_expression_get_call (ValaInvocationExpression* self);
 void vala_invocation_expression_set_call (ValaInvocationExpression* self, ValaExpression* value);
+ValaCCodeExpression* vala_invocation_expression_get_delegate_target (ValaInvocationExpression* self);
+void vala_invocation_expression_set_delegate_target (ValaInvocationExpression* self, ValaCCodeExpression* value);
 GType vala_invocation_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
