@@ -1,6 +1,6 @@
 /* valamember.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaMemberPrivate {
 	GeeList* cheader_filenames;
 };
@@ -41,10 +44,11 @@ static gpointer vala_member_parent_class = NULL;
 static void vala_member_dispose (GObject * obj);
 
 
+
 static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMember * self;
 	self = VALA_MEMBER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, self);
 }
 
@@ -52,7 +56,8 @@ static void vala_member_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base) {
 	ValaMember * self;
 	self = VALA_MEMBER (base);
-	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0) {
+	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) != NULL) {
+		/* default to header filenames of the namespace */
 		{
 			GeeCollection* filename_collection;
 			GeeIterator* filename_it;
@@ -62,7 +67,6 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
 				char* filename;
 				filename = ((char*) gee_iterator_get (filename_it));
 				{
-					/* default to header filenames of the namespace */
 					vala_member_add_cheader_filename (self, filename);
 					filename = (g_free (filename), NULL);
 				}
@@ -70,7 +74,7 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
 			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
 			(filename_it == NULL ? NULL : (filename_it = (g_object_unref (filename_it), NULL)));
 		}
-		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))) {
+		if (gee_collection_get_size (GEE_COLLECTION (self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && !vala_symbol_get_external_package (VALA_SYMBOL (self))) {
 			char* _tmp0;
 			/* don't add default include directives for VAPI files*/
 			_tmp0 = NULL;
@@ -90,6 +94,7 @@ static GeeCollection* vala_member_real_get_cheader_filenames (ValaSymbol* base)
  */
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename) {
 	g_return_if_fail (VALA_IS_MEMBER (self));
+	g_return_if_fail (filename != NULL);
 	gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
 }
 
