@@ -1,6 +1,6 @@
 /* valamemberaccess.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,10 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaproperty.h>
+#include <vala/valacodegenerator.h>
+
+
+
 
 struct _ValaMemberAccessPrivate {
 	char* _member_name;
@@ -51,10 +55,12 @@ static char* vala_member_access_real_to_string (ValaCodeNode* base);
 static void vala_member_access_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_member_access_real_is_pure (ValaExpression* base);
 static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static ValaCodeBinding* vala_member_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_member_access_parent_class = NULL;
 static void vala_member_access_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new member access expression.
  *
@@ -66,6 +72,7 @@ static void vala_member_access_dispose (GObject * obj);
 ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
 	ValaMemberAccess * self;
 	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
 	vala_member_access_set_inner (self, inner);
@@ -77,6 +84,7 @@ ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* mem
 
 ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference) {
 	ValaMemberAccess * self;
+	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
 	vala_member_access_set_member_name (self, member_name);
@@ -87,13 +95,14 @@ ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSo
 
 ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference) {
 	ValaMemberAccess * self;
-	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_MEMBER_ACCESS, 0, NULL);
-	vala_member_access_set_pointer_member_access (self, TRUE);
 	vala_member_access_set_inner (self, inner);
 	vala_member_access_set_member_name (self, member_name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_member_access_set_pointer_member_access (self, TRUE);
 	return self;
 }
 
@@ -105,7 +114,7 @@ ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const c
  */
 void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaDataType* arg) {
 	g_return_if_fail (VALA_IS_MEMBER_ACCESS (self));
-	g_return_if_fail (arg == NULL || VALA_IS_DATA_TYPE (arg));
+	g_return_if_fail (VALA_IS_DATA_TYPE (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -125,7 +134,7 @@ GeeCollection* vala_member_access_get_type_arguments (ValaMemberAccess* self) {
 static void vala_member_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_member_access_get_inner (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_member_access_get_inner (self)), visitor);
 	}
@@ -154,13 +163,13 @@ static char* vala_member_access_real_to_string (ValaCodeNode* base) {
 	if (vala_member_access_get_inner (self) == NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = vala_member_access_get_member_name (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+		return (_tmp0 = self->priv->_member_name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	} else {
 		char* _tmp2;
 		char* _tmp3;
 		_tmp2 = NULL;
 		_tmp3 = NULL;
-		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), vala_member_access_get_member_name (self)), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
+		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_member_access_get_inner (self)))), self->priv->_member_name), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
 	}
 }
 
@@ -168,8 +177,8 @@ static char* vala_member_access_real_to_string (ValaCodeNode* base) {
 static void vala_member_access_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_member_access_get_inner (self) == old_node) {
 		vala_member_access_set_inner (self, new_node);
 	}
@@ -179,20 +188,20 @@ static void vala_member_access_real_replace_expression (ValaCodeNode* base, Vala
 static gboolean vala_member_access_real_is_pure (ValaExpression* base) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (base);
+	/* accessing property could have side-effects*/
 	return (vala_member_access_get_inner (self) == NULL || vala_expression_is_pure (vala_member_access_get_inner (self))) && !(VALA_IS_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (self))));
 }
 
 
-/* accessing property could have side-effects*/
 static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaMemberAccess * self;
 	self = VALA_MEMBER_ACCESS (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->type_argument_list)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->type_argument_list)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -205,6 +214,14 @@ static void vala_member_access_real_replace_type (ValaCodeNode* base, ValaDataTy
 }
 
 
+static ValaCodeBinding* vala_member_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaMemberAccess * self;
+	self = VALA_MEMBER_ACCESS (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_member_access_binding (codegen, self);
+}
+
+
 ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (self), NULL);
 	return self->priv->_inner;
@@ -339,6 +356,7 @@ static void vala_member_access_class_init (ValaMemberAccessClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_member_access_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_member_access_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_member_access_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_member_access_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_MEMBER_NAME, g_param_spec_string ("member-name", "member-name", "member-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_MEMBER_ACCESS_POINTER_MEMBER_ACCESS, g_param_spec_boolean ("pointer-member-access", "pointer-member-access", "pointer-member-access", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
