@@ -1,6 +1,6 @@
 /* valamemberaccess.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,6 +30,7 @@
 #include <gee/collection.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -47,25 +48,31 @@ typedef struct _ValaMemberAccessPrivate ValaMemberAccessPrivate;
  * Represents an access to a type member in the source code.
  */
 struct _ValaMemberAccess {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaMemberAccessPrivate * priv;
 };
 struct _ValaMemberAccessClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaMemberAccess* vala_member_access_new (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
 ValaMemberAccess* vala_member_access_new_simple (const char* member_name, ValaSourceReference* source_reference);
-void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaTypeReference* arg);
+ValaMemberAccess* vala_member_access_new_pointer (ValaExpression* inner, const char* member_name, ValaSourceReference* source_reference);
+void vala_member_access_add_type_argument (ValaMemberAccess* self, ValaDataType* arg);
 GeeCollection* vala_member_access_get_type_arguments (ValaMemberAccess* self);
 ValaExpression* vala_member_access_get_inner (ValaMemberAccess* self);
 void vala_member_access_set_inner (ValaMemberAccess* self, ValaExpression* value);
 char* vala_member_access_get_member_name (ValaMemberAccess* self);
 void vala_member_access_set_member_name (ValaMemberAccess* self, const char* value);
+gboolean vala_member_access_get_pointer_member_access (ValaMemberAccess* self);
+void vala_member_access_set_pointer_member_access (ValaMemberAccess* self, gboolean value);
 gboolean vala_member_access_get_prototype_access (ValaMemberAccess* self);
 void vala_member_access_set_prototype_access (ValaMemberAccess* self, gboolean value);
+gboolean vala_member_access_get_creation_member (ValaMemberAccess* self);
+void vala_member_access_set_creation_member (ValaMemberAccess* self, gboolean value);
 GType vala_member_access_get_type (void);
 
+
 G_END_DECLS
 
 #endif
