@@ -57,12 +57,13 @@ static void vala_member_initializer_dispose (GObject * obj);
  */
 ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaMemberInitializer * self;
-	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_MEMBER_INITIALIZER, 0, NULL);
-	vala_member_initializer_set_name (self, name);
 	vala_member_initializer_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_member_initializer_set_name (self, name);
 	return self;
 }
 
@@ -70,7 +71,7 @@ ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpres
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
 }
 
