@@ -28,6 +28,7 @@
 #include <vala/valasymbol.h>
 #include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
+#include <vala/valanulltype.h>
 #include <vala/valapointertype.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valasemanticanalyzer.h>
@@ -35,6 +36,9 @@
 #include <vala/valapointerindirection.h>
 #include <vala/valasignal.h>
 
+
+
+
 struct _ValaMemoryManagerPrivate {
 	ValaSymbol* current_symbol;
 };
@@ -57,7 +61,7 @@ static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d);
 static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base, ValaNamedArgument* n);
 static void vala_memory_manager_real_visit_block (ValaCodeVisitor* base, ValaBlock* b);
-static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
+static void vala_memory_manager_real_visit_local_variable (ValaCodeVisitor* base, ValaLocalVariable* local);
 static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list);
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt);
 static void vala_memory_manager_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt);
@@ -82,6 +86,7 @@ static gpointer vala_memory_manager_parent_class = NULL;
 static void vala_memory_manager_dispose (GObject * obj);
 
 
+
 /**
  * Analyze memory usage in the specified code context.
  *
@@ -89,15 +94,15 @@ static void vala_memory_manager_dispose (GObject * obj);
  */
 void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* context) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
 }
 
 
 static void vala_memory_manager_visit_possibly_leaked_expression (ValaMemoryManager* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
-	if (vala_expression_get_static_type (expr) != NULL && vala_data_type_is_reference_type_or_type_parameter (vala_expression_get_static_type (expr)) && vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr))) {
+	g_return_if_fail (VALA_IS_EXPRESSION (expr));
+	if (vala_expression_get_static_type (expr) != NULL && vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr))) {
 		/* mark reference as leaked */
 		vala_expression_set_ref_leaked (expr, TRUE);
 	}
@@ -106,8 +111,8 @@ static void vala_memory_manager_visit_possibly_leaked_expression (ValaMemoryMana
 
 static void vala_memory_manager_visit_possibly_missing_copy_expression (ValaMemoryManager* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_MEMORY_MANAGER (self));
-	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
-	if (vala_expression_get_static_type (expr) != NULL && vala_data_type_is_reference_type_or_type_parameter (vala_expression_get_static_type (expr)) && !vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr))) {
+	g_return_if_fail (VALA_IS_EXPRESSION (expr));
+	if (vala_expression_get_static_type (expr) != NULL && !vala_data_type_get_transfers_ownership (vala_expression_get_static_type (expr)) && !(VALA_IS_NULL_TYPE (vala_expression_get_static_type (expr)))) {
 		/* mark reference as missing */
 		vala_expression_set_ref_missing (expr, TRUE);
 	}
@@ -117,8 +122,8 @@ static void vala_memory_manager_visit_possibly_missing_copy_expression (ValaMemo
 static void vala_memory_manager_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (source_file == NULL || VALA_IS_SOURCE_FILE (source_file));
-	if (!vala_source_file_get_pkg (source_file)) {
+	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
+	if (!vala_source_file_get_external_package (source_file)) {
 		vala_source_file_accept_children (source_file, VALA_CODE_VISITOR (self));
 	}
 }
@@ -127,7 +132,7 @@ static void vala_memory_manager_real_visit_source_file (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 	vala_code_node_accept_children (VALA_CODE_NODE (cl), VALA_CODE_VISITOR (self));
 }
 
@@ -135,7 +140,7 @@ static void vala_memory_manager_real_visit_class (ValaCodeVisitor* base, ValaCla
 static void vala_memory_manager_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
 }
 
@@ -143,7 +148,7 @@ static void vala_memory_manager_real_visit_struct (ValaCodeVisitor* base, ValaSt
 static void vala_memory_manager_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	vala_code_node_accept_children (VALA_CODE_NODE (iface), VALA_CODE_VISITOR (self));
 }
 
@@ -151,7 +156,7 @@ static void vala_memory_manager_real_visit_interface (ValaCodeVisitor* base, Val
 static void vala_memory_manager_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	if (vala_field_get_initializer (f) != NULL) {
 		if (!(VALA_IS_POINTER_TYPE (vala_field_get_type_reference (f)))) {
 			if (vala_data_type_get_takes_ownership (vala_field_get_type_reference (f))) {
@@ -173,7 +178,7 @@ static void vala_memory_manager_real_visit_method (ValaCodeVisitor* base, ValaMe
 	ValaSymbol* _tmp4;
 	ValaSymbol* _tmp3;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	_tmp0 = NULL;
 	old_symbol = (_tmp0 = self->priv->current_symbol, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	_tmp2 = NULL;
@@ -190,7 +195,7 @@ static void vala_memory_manager_real_visit_method (ValaCodeVisitor* base, ValaMe
 static void vala_memory_manager_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 	vala_code_visitor_visit_method (VALA_CODE_VISITOR (self), VALA_METHOD (m));
 }
 
@@ -200,7 +205,7 @@ static void vala_memory_manager_real_visit_property (ValaCodeVisitor* base, Vala
 	ValaSymbol* _tmp1;
 	ValaProperty* _tmp0;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_symbol = (_tmp1 = VALA_SYMBOL ((_tmp0 = prop, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)))), (self->priv->current_symbol == NULL ? NULL : (self->priv->current_symbol = (g_object_unref (self->priv->current_symbol), NULL))), _tmp1);
@@ -211,7 +216,7 @@ static void vala_memory_manager_real_visit_property (ValaCodeVisitor* base, Vala
 static void vala_memory_manager_real_visit_property_accessor (ValaCodeVisitor* base, ValaPropertyAccessor* acc) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (acc == NULL || VALA_IS_PROPERTY_ACCESSOR (acc));
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
 	vala_code_node_accept_children (VALA_CODE_NODE (acc), VALA_CODE_VISITOR (self));
 }
 
@@ -219,7 +224,7 @@ static void vala_memory_manager_real_visit_property_accessor (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, ValaConstructor* c) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTRUCTOR (c));
+	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
 	vala_code_node_accept_children (VALA_CODE_NODE (c), VALA_CODE_VISITOR (self));
 }
 
@@ -227,7 +232,7 @@ static void vala_memory_manager_real_visit_constructor (ValaCodeVisitor* base, V
 static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (d == NULL || VALA_IS_DESTRUCTOR (d));
+	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
 	vala_code_node_accept_children (VALA_CODE_NODE (d), VALA_CODE_VISITOR (self));
 }
 
@@ -235,7 +240,7 @@ static void vala_memory_manager_real_visit_destructor (ValaCodeVisitor* base, Va
 static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base, ValaNamedArgument* n) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (n == NULL || VALA_IS_NAMED_ARGUMENT (n));
+	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (n));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_named_argument_get_argument (n));
 }
 
@@ -243,22 +248,22 @@ static void vala_memory_manager_real_visit_named_argument (ValaCodeVisitor* base
 static void vala_memory_manager_real_visit_block (ValaCodeVisitor* base, ValaBlock* b) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (b == NULL || VALA_IS_BLOCK (b));
+	g_return_if_fail (VALA_IS_BLOCK (b));
 	vala_code_node_accept_children (VALA_CODE_NODE (b), VALA_CODE_VISITOR (self));
 }
 
 
-static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl) {
+static void vala_memory_manager_real_visit_local_variable (ValaCodeVisitor* base, ValaLocalVariable* local) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (decl == NULL || VALA_IS_VARIABLE_DECLARATOR (decl));
-	vala_code_node_accept_children (VALA_CODE_NODE (decl), VALA_CODE_VISITOR (self));
-	if (vala_variable_declarator_get_initializer (decl) != NULL) {
-		if (!(VALA_IS_POINTER_TYPE (vala_variable_declarator_get_type_reference (decl)))) {
-			if (vala_data_type_get_takes_ownership (vala_variable_declarator_get_type_reference (decl))) {
-				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_variable_declarator_get_initializer (decl));
+	g_return_if_fail (VALA_IS_LOCAL_VARIABLE (local));
+	vala_code_node_accept_children (VALA_CODE_NODE (local), VALA_CODE_VISITOR (self));
+	if (vala_local_variable_get_initializer (local) != NULL) {
+		if (!(VALA_IS_POINTER_TYPE (vala_local_variable_get_variable_type (local)))) {
+			if (vala_data_type_get_takes_ownership (vala_local_variable_get_variable_type (local))) {
+				vala_memory_manager_visit_possibly_missing_copy_expression (self, vala_local_variable_get_initializer (local));
 			} else {
-				vala_memory_manager_visit_possibly_leaked_expression (self, vala_variable_declarator_get_initializer (decl));
+				vala_memory_manager_visit_possibly_leaked_expression (self, vala_local_variable_get_initializer (local));
 			}
 		}
 	}
@@ -268,7 +273,7 @@ static void vala_memory_manager_real_visit_variable_declarator (ValaCodeVisitor*
 static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (list == NULL || VALA_IS_INITIALIZER_LIST (list));
+	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
 	vala_code_node_accept_children (VALA_CODE_NODE (list), VALA_CODE_VISITOR (self));
 }
 
@@ -276,7 +281,7 @@ static void vala_memory_manager_real_visit_initializer_list (ValaCodeVisitor* ba
 static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor* base, ValaExpressionStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_EXPRESSION_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_EXPRESSION_STATEMENT (stmt));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_expression_statement_get_expression (stmt));
 }
 
@@ -284,7 +289,7 @@ static void vala_memory_manager_real_visit_expression_statement (ValaCodeVisitor
 static void vala_memory_manager_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_IF_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_IF_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -292,7 +297,7 @@ static void vala_memory_manager_real_visit_if_statement (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (section == NULL || VALA_IS_SWITCH_SECTION (section));
+	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
 	vala_code_node_accept_children (VALA_CODE_NODE (section), VALA_CODE_VISITOR (self));
 }
 
@@ -300,7 +305,7 @@ static void vala_memory_manager_real_visit_switch_section (ValaCodeVisitor* base
 static void vala_memory_manager_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_WHILE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_WHILE_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -308,7 +313,7 @@ static void vala_memory_manager_real_visit_while_statement (ValaCodeVisitor* bas
 static void vala_memory_manager_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_DO_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_DO_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -316,7 +321,7 @@ static void vala_memory_manager_real_visit_do_statement (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_FOR_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOR_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -324,7 +329,7 @@ static void vala_memory_manager_real_visit_for_statement (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_FOREACH_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -332,7 +337,7 @@ static void vala_memory_manager_real_visit_foreach_statement (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_RETURN_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_RETURN_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 	if (vala_return_statement_get_return_expression (stmt) != NULL) {
 		if (VALA_IS_METHOD (self->priv->current_symbol)) {
@@ -372,7 +377,7 @@ static void vala_memory_manager_real_visit_return_statement (ValaCodeVisitor* ba
 static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_THROW_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -380,7 +385,7 @@ static void vala_memory_manager_real_visit_throw_statement (ValaCodeVisitor* bas
 static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_TRY_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -388,7 +393,7 @@ static void vala_memory_manager_real_visit_try_statement (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (clause == NULL || VALA_IS_CATCH_CLAUSE (clause));
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
 	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
 }
 
@@ -396,7 +401,7 @@ static void vala_memory_manager_real_visit_catch_clause (ValaCodeVisitor* base,
 static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (e == NULL || VALA_IS_ARRAY_CREATION_EXPRESSION (e));
+	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (e));
 	if (vala_array_creation_expression_get_initializer_list (e) != NULL) {
 		{
 			GeeCollection* init_collection;
@@ -407,7 +412,11 @@ static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVi
 				ValaExpression* init;
 				init = ((ValaExpression*) gee_iterator_get (init_it));
 				{
-					vala_memory_manager_visit_possibly_missing_copy_expression (self, init);
+					if (vala_data_type_is_reference_type_or_type_parameter (vala_expression_get_static_type (init))) {
+						vala_memory_manager_visit_possibly_missing_copy_expression (self, init);
+					} else {
+						vala_memory_manager_visit_possibly_leaked_expression (self, init);
+					}
 					(init == NULL ? NULL : (init = (g_object_unref (init), NULL)));
 				}
 			}
@@ -421,7 +430,7 @@ static void vala_memory_manager_real_visit_array_creation_expression (ValaCodeVi
 static void vala_memory_manager_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_PARENTHESIZED_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 }
 
@@ -429,7 +438,7 @@ static void vala_memory_manager_real_visit_parenthesized_expression (ValaCodeVis
 static void vala_memory_manager_real_visit_member_access (ValaCodeVisitor* base, ValaMemberAccess* expr) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_MEMBER_ACCESS (expr));
+	g_return_if_fail (VALA_IS_MEMBER_ACCESS (expr));
 	if (vala_member_access_get_inner (expr) != NULL) {
 		vala_memory_manager_visit_possibly_leaked_expression (self, vala_member_access_get_inner (expr));
 	}
@@ -443,7 +452,7 @@ static void vala_memory_manager_real_visit_invocation_expression (ValaCodeVisito
 	GeeCollection* params;
 	GeeIterator* params_it;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_INVOCATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 	_tmp0 = NULL;
 	mtype = (_tmp0 = vala_expression_get_static_type (vala_invocation_expression_get_call (expr)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
@@ -510,7 +519,7 @@ static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeV
 	GeeCollection* params;
 	GeeIterator* params_it;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 	if (!(VALA_IS_METHOD (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))))) {
 		return;
@@ -569,7 +578,7 @@ static void vala_memory_manager_real_visit_object_creation_expression (ValaCodeV
 static void vala_memory_manager_real_visit_binary_expression (ValaCodeVisitor* base, ValaBinaryExpression* expr) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_BINARY_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_BINARY_EXPRESSION (expr));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_binary_expression_get_left (expr));
 	vala_memory_manager_visit_possibly_leaked_expression (self, vala_binary_expression_get_right (expr));
 }
@@ -578,7 +587,7 @@ static void vala_memory_manager_real_visit_binary_expression (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (l == NULL || VALA_IS_LAMBDA_EXPRESSION (l));
+	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (l));
 	vala_code_node_accept_children (VALA_CODE_NODE (l), VALA_CODE_VISITOR (self));
 }
 
@@ -586,7 +595,7 @@ static void vala_memory_manager_real_visit_lambda_expression (ValaCodeVisitor* b
 static void vala_memory_manager_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a) {
 	ValaMemoryManager * self;
 	self = VALA_MEMORY_MANAGER (base);
-	g_return_if_fail (a == NULL || VALA_IS_ASSIGNMENT (a));
+	g_return_if_fail (VALA_IS_ASSIGNMENT (a));
 	vala_code_node_accept_children (VALA_CODE_NODE (a), VALA_CODE_VISITOR (self));
 	if (VALA_IS_POINTER_INDIRECTION (vala_assignment_get_left (a)) || VALA_IS_SIGNAL (vala_expression_get_symbol_reference (vala_assignment_get_left (a)))) {
 	} else {
@@ -629,7 +638,7 @@ static void vala_memory_manager_class_init (ValaMemoryManagerClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_destructor = vala_memory_manager_real_visit_destructor;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_named_argument = vala_memory_manager_real_visit_named_argument;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_block = vala_memory_manager_real_visit_block;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_memory_manager_real_visit_variable_declarator;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_local_variable = vala_memory_manager_real_visit_local_variable;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_memory_manager_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_memory_manager_real_visit_expression_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_memory_manager_real_visit_if_statement;
