@@ -41,7 +41,7 @@
 #include <vala/valadestructor.h>
 #include <vala/valanamedargument.h>
 #include <vala/valablock.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valaifstatement.h>
@@ -93,6 +93,7 @@ void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* cont
 ValaMemoryManager* vala_memory_manager_new (void);
 GType vala_memory_manager_get_type (void);
 
+
 G_END_DECLS
 
 #endif
