@@ -29,7 +29,7 @@
 #include <gee/iterator.h>
 #include <vala/valabasicblock.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valadatatype.h>
 #include <vala/valaexpression.h>
 #include <vala/valablock.h>
@@ -38,6 +38,10 @@
 #include <vala/valascope.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valacodegenerator.h>
+
+
+
 
 struct _ValaMethodPrivate {
 	ValaBasicBlock* _entry_block;
@@ -50,7 +54,7 @@ struct _ValaMethodPrivate {
 	ValaMethod* _base_method;
 	ValaMethod* _base_interface_method;
 	ValaFormalParameter* _this_parameter;
-	ValaVariableDeclarator* _result_var;
+	ValaLocalVariable* _result_var;
 	double _cinstance_parameter_position;
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
@@ -97,6 +101,7 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 static char* vala_method_real_get_default_cname (ValaMethod* self);
 static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a);
 static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static ValaCodeBinding* vala_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static GObject * vala_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_method_parent_class = NULL;
 static void vala_method_dispose (GObject * obj);
@@ -104,6 +109,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new method.
  *
@@ -114,12 +120,13 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaMethod * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_METHOD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_method_set_return_type (self, return_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -131,7 +138,7 @@ ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSo
  */
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_method_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
@@ -152,10 +159,36 @@ GeeCollection* vala_method_get_parameters (ValaMethod* self) {
 }
 
 
+/**
+ * Remove all parameters from this method.
+ */
+void vala_method_clear_parameters (ValaMethod* self) {
+	g_return_if_fail (VALA_IS_METHOD (self));
+	{
+		GeeList* param_collection;
+		GeeIterator* param_it;
+		param_collection = self->priv->parameters;
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			{
+				if (!vala_formal_parameter_get_ellipsis (param)) {
+					vala_scope_remove (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)));
+				}
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+			}
+		}
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
+	}
+	gee_collection_clear (GEE_COLLECTION (self->priv->parameters));
+}
+
+
 static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
 	self = VALA_METHOD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_method (visitor, self);
 }
 
@@ -163,7 +196,7 @@ static void vala_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMethod * self;
 	self = VALA_METHOD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_method_get_return_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_return_type (self)), visitor);
 	}
@@ -197,8 +230,8 @@ static void vala_method_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 		}
 		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
 	}
-	if (vala_method_get_result_var (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_variable_declarator_get_type_reference (vala_method_get_result_var (self))), visitor);
+	if (self->priv->_result_var != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_local_variable_get_variable_type (self->priv->_result_var)), visitor);
 	}
 	{
 		GeeList* precondition_collection;
@@ -263,9 +296,9 @@ char* vala_method_get_cname (ValaMethod* self) {
 static char* vala_method_real_get_default_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (self)), "main") == 0 && vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))) == NULL) {
+		/* avoid conflict with generated main function*/
 		return g_strdup ("_main");
 	} else {
-		/* avoid conflict with generated main function*/
 		if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (self)), "_")) {
 			char* _tmp1;
 			char* _tmp2;
@@ -296,7 +329,7 @@ char* vala_method_get_default_cname (ValaMethod* self) {
  */
 char* vala_method_get_real_cname (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
-	if (vala_method_get_base_method (self) != NULL || vala_method_get_base_interface_method (self) != NULL) {
+	if (self->priv->_base_method != NULL || self->priv->_base_interface_method != NULL) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
@@ -317,6 +350,7 @@ void vala_method_set_cname (ValaMethod* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_METHOD (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -325,7 +359,7 @@ void vala_method_set_cname (ValaMethod* self, const char* cname) {
 
 static void vala_method_process_ccode_attribute (ValaMethod* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -408,10 +442,6 @@ void vala_method_process_attributes (ValaMethod* self) {
 							} else {
 								if (_vala_strcmp0 (vala_attribute_get_name (a), "PrintfFormat") == 0) {
 									vala_method_set_printf_format (self, TRUE);
-								} else {
-									if (_vala_strcmp0 (vala_attribute_get_name (a), "Import") == 0) {
-										vala_symbol_set_is_imported (VALA_SYMBOL (self), TRUE);
-									}
 								}
 							}
 						}
@@ -425,89 +455,116 @@ void vala_method_process_attributes (ValaMethod* self) {
 
 
 /**
- * Checks whether the arguments and return type of the specified method
- * matches this method.
+ * Checks whether the parameters and return type of this method are
+ * compatible with the specified method
  *
- * @param m a method
- * @return  true if the specified method is compatible to this method
+ * @param base_method a method
+ * @param invalid_match error string about which check failed
+ * @return true if the specified method is compatible to this method
  */
-gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
-	GeeCollection* _tmp1;
-	GeeIterator* _tmp2;
+gboolean vala_method_compatible (ValaMethod* self, ValaMethod* base_method, const char** invalid_match) {
 	GeeIterator* method_params_it;
-	GeeCollection* _tmp8;
-	GeeIterator* _tmp9;
-	GeeIterator* method_error_domains_it;
-	gboolean _tmp14;
+	gint param_index;
+	gboolean _tmp13;
 	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
-	g_return_val_if_fail (m2 == NULL || VALA_IS_METHOD (m2), FALSE);
-	if (!vala_data_type_equals (vala_method_get_return_type (m2), vala_method_get_return_type (self))) {
+	g_return_val_if_fail (VALA_IS_METHOD (base_method), FALSE);
+	*invalid_match = NULL;
+	if (!vala_data_type_equals (vala_method_get_return_type (self), vala_method_get_return_type (base_method))) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		(*invalid_match) = (_tmp0 = g_strdup ("incompatible return type"), ((*invalid_match) = (g_free ((*invalid_match)), NULL)), _tmp0);
 		return FALSE;
 	}
-	_tmp1 = NULL;
-	_tmp2 = NULL;
-	method_params_it = (_tmp2 = gee_iterable_iterator (GEE_ITERABLE ((_tmp1 = vala_method_get_parameters (m2)))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
+	method_params_it = gee_iterable_iterator (GEE_ITERABLE (self->priv->parameters));
+	param_index = 1;
 	{
-		GeeList* param_collection;
-		GeeIterator* param_it;
-		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
-			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+		GeeList* base_param_collection;
+		GeeIterator* base_param_it;
+		base_param_collection = base_method->priv->parameters;
+		base_param_it = gee_iterable_iterator (GEE_ITERABLE (base_param_collection));
+		while (gee_iterator_next (base_param_it)) {
+			ValaFormalParameter* base_param;
+			base_param = ((ValaFormalParameter*) gee_iterator_get (base_param_it));
 			{
 				ValaFormalParameter* _tmp4;
 				gboolean _tmp5;
-				/* method may not expect less arguments */
+				/* this method may not expect less arguments */
 				if (!gee_iterator_next (method_params_it)) {
+					char* _tmp2;
 					gboolean _tmp3;
-					return (_tmp3 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
+					_tmp2 = NULL;
+					(*invalid_match) = (_tmp2 = g_strdup ("too few parameters"), ((*invalid_match) = (g_free ((*invalid_match)), NULL)), _tmp2);
+					return (_tmp3 = FALSE, (base_param == NULL ? NULL : (base_param = (g_object_unref (base_param), NULL))), (base_param_it == NULL ? NULL : (base_param_it = (g_object_unref (base_param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp3);
 				}
 				_tmp4 = NULL;
-				if ((_tmp5 = !vala_data_type_equals (vala_formal_parameter_get_type_reference ((_tmp4 = ((ValaFormalParameter*) gee_iterator_get (method_params_it)))), vala_formal_parameter_get_type_reference (param)), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
-					gboolean _tmp6;
-					return (_tmp6 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp6);
+				if ((_tmp5 = !vala_data_type_equals (vala_formal_parameter_get_type_reference (base_param), vala_formal_parameter_get_type_reference ((_tmp4 = ((ValaFormalParameter*) gee_iterator_get (method_params_it))))), (_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL))), _tmp5)) {
+					char* _tmp6;
+					gboolean _tmp7;
+					_tmp6 = NULL;
+					(*invalid_match) = (_tmp6 = g_strdup_printf ("incompatible type of parameter %d", param_index), ((*invalid_match) = (g_free ((*invalid_match)), NULL)), _tmp6);
+					return (_tmp7 = FALSE, (base_param == NULL ? NULL : (base_param = (g_object_unref (base_param), NULL))), (base_param_it == NULL ? NULL : (base_param_it = (g_object_unref (base_param_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp7);
 				}
-				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				param_index++;
+				(base_param == NULL ? NULL : (base_param = (g_object_unref (base_param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
+		(base_param_it == NULL ? NULL : (base_param_it = (g_object_unref (base_param_it), NULL)));
 	}
-	/* method may not expect more arguments */
+	/* this method may not expect more arguments */
 	if (gee_iterator_next (method_params_it)) {
-		gboolean _tmp7;
-		return (_tmp7 = FALSE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp7);
+		char* _tmp8;
+		gboolean _tmp9;
+		_tmp8 = NULL;
+		(*invalid_match) = (_tmp8 = g_strdup ("too many parameters"), ((*invalid_match) = (g_free ((*invalid_match)), NULL)), _tmp8);
+		return (_tmp9 = FALSE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp9);
 	}
-	_tmp8 = NULL;
-	_tmp9 = NULL;
-	method_error_domains_it = (_tmp9 = gee_iterable_iterator (GEE_ITERABLE ((_tmp8 = vala_method_get_error_domains (m2)))), (_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL))), _tmp9);
+	/* this method may throw more but not less errors than the base method */
 	{
-		GeeList* error_domain_collection;
-		GeeIterator* error_domain_it;
-		error_domain_collection = self->priv->error_domains;
-		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
-		while (gee_iterator_next (error_domain_it)) {
-			ValaDataType* error_domain;
-			error_domain = ((ValaDataType*) gee_iterator_get (error_domain_it));
+		GeeList* method_error_domain_collection;
+		GeeIterator* method_error_domain_it;
+		method_error_domain_collection = self->priv->error_domains;
+		method_error_domain_it = gee_iterable_iterator (GEE_ITERABLE (method_error_domain_collection));
+		while (gee_iterator_next (method_error_domain_it)) {
+			ValaDataType* method_error_domain;
+			method_error_domain = ((ValaDataType*) gee_iterator_get (method_error_domain_it));
 			{
-				ValaDataType* _tmp11;
-				gboolean _tmp12;
-				/* method may not have less error domains */
-				if (!gee_iterator_next (method_error_domains_it)) {
-					gboolean _tmp10;
-					return (_tmp10 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp10);
+				gboolean match;
+				match = FALSE;
+				{
+					GeeList* base_method_error_domain_collection;
+					GeeIterator* base_method_error_domain_it;
+					base_method_error_domain_collection = base_method->priv->error_domains;
+					base_method_error_domain_it = gee_iterable_iterator (GEE_ITERABLE (base_method_error_domain_collection));
+					while (gee_iterator_next (base_method_error_domain_it)) {
+						ValaDataType* base_method_error_domain;
+						base_method_error_domain = ((ValaDataType*) gee_iterator_get (base_method_error_domain_it));
+						{
+							if (vala_data_type_compatible (method_error_domain, base_method_error_domain)) {
+								match = TRUE;
+								(base_method_error_domain == NULL ? NULL : (base_method_error_domain = (g_object_unref (base_method_error_domain), NULL)));
+								break;
+							}
+							(base_method_error_domain == NULL ? NULL : (base_method_error_domain = (g_object_unref (base_method_error_domain), NULL)));
+						}
+					}
+					(base_method_error_domain_it == NULL ? NULL : (base_method_error_domain_it = (g_object_unref (base_method_error_domain_it), NULL)));
 				}
-				_tmp11 = NULL;
-				if ((_tmp12 = !vala_data_type_equals ((_tmp11 = ((ValaDataType*) gee_iterator_get (method_error_domains_it))), error_domain), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12)) {
-					gboolean _tmp13;
-					return (_tmp13 = FALSE, (error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL))), (error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp13);
+				if (!match) {
+					char* _tmp11;
+					char* _tmp10;
+					gboolean _tmp12;
+					_tmp11 = NULL;
+					_tmp10 = NULL;
+					(*invalid_match) = (_tmp11 = g_strdup_printf ("incompatible error domain `%s'", (_tmp10 = vala_code_node_to_string (VALA_CODE_NODE (method_error_domain)))), ((*invalid_match) = (g_free ((*invalid_match)), NULL)), _tmp11);
+					_tmp10 = (g_free (_tmp10), NULL);
+					return (_tmp12 = FALSE, (method_error_domain == NULL ? NULL : (method_error_domain = (g_object_unref (method_error_domain), NULL))), (method_error_domain_it == NULL ? NULL : (method_error_domain_it = (g_object_unref (method_error_domain_it), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp12);
 				}
-				(error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL)));
+				(method_error_domain == NULL ? NULL : (method_error_domain = (g_object_unref (method_error_domain), NULL)));
 			}
 		}
-		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
+		(method_error_domain_it == NULL ? NULL : (method_error_domain_it = (g_object_unref (method_error_domain_it), NULL)));
 	}
-	return (_tmp14 = TRUE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), (method_error_domains_it == NULL ? NULL : (method_error_domains_it = (g_object_unref (method_error_domains_it), NULL))), _tmp14);
+	return (_tmp13 = TRUE, (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp13);
 }
 
 
@@ -518,7 +575,7 @@ gboolean vala_method_equals (ValaMethod* self, ValaMethod* m2) {
  */
 void vala_method_add_error_domain (ValaMethod* self, ValaDataType* error_domain) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (error_domain == NULL || VALA_IS_DATA_TYPE (error_domain));
+	g_return_if_fail (VALA_IS_DATA_TYPE (error_domain));
 	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), error_domain);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (error_domain), VALA_CODE_NODE (self));
 }
@@ -542,7 +599,7 @@ GeeCollection* vala_method_get_error_domains (ValaMethod* self) {
  */
 void vala_method_add_precondition (ValaMethod* self, ValaExpression* precondition) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (precondition == NULL || VALA_IS_EXPRESSION (precondition));
+	g_return_if_fail (VALA_IS_EXPRESSION (precondition));
 	gee_collection_add (GEE_COLLECTION (self->priv->preconditions), precondition);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (precondition), VALA_CODE_NODE (self));
 }
@@ -566,7 +623,7 @@ GeeCollection* vala_method_get_preconditions (ValaMethod* self) {
  */
 void vala_method_add_postcondition (ValaMethod* self, ValaExpression* postcondition) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	g_return_if_fail (postcondition == NULL || VALA_IS_EXPRESSION (postcondition));
+	g_return_if_fail (VALA_IS_EXPRESSION (postcondition));
 	gee_collection_add (GEE_COLLECTION (self->priv->postconditions), postcondition);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (postcondition), VALA_CODE_NODE (self));
 }
@@ -586,8 +643,8 @@ GeeCollection* vala_method_get_postconditions (ValaMethod* self) {
 static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaMethod * self;
 	self = VALA_METHOD (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_method_get_return_type (self) == old_type) {
 		vala_method_set_return_type (self, new_type);
 		return;
@@ -595,7 +652,7 @@ static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->error_domains)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->error_domains)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -608,6 +665,14 @@ static void vala_method_real_replace_type (ValaCodeNode* base, ValaDataType* old
 }
 
 
+static ValaCodeBinding* vala_method_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaMethod * self;
+	self = VALA_METHOD (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_method_binding (codegen, self);
+}
+
+
 ValaDataType* vala_method_get_return_type (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_return_type;
@@ -834,15 +899,15 @@ void vala_method_set_this_parameter (ValaMethod* self, ValaFormalParameter* valu
 }
 
 
-ValaVariableDeclarator* vala_method_get_result_var (ValaMethod* self) {
+ValaLocalVariable* vala_method_get_result_var (ValaMethod* self) {
 	g_return_val_if_fail (VALA_IS_METHOD (self), NULL);
 	return self->priv->_result_var;
 }
 
 
-void vala_method_set_result_var (ValaMethod* self, ValaVariableDeclarator* value) {
-	ValaVariableDeclarator* _tmp2;
-	ValaVariableDeclarator* _tmp1;
+void vala_method_set_result_var (ValaMethod* self, ValaLocalVariable* value) {
+	ValaLocalVariable* _tmp2;
+	ValaLocalVariable* _tmp1;
 	g_return_if_fail (VALA_IS_METHOD (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
@@ -1101,6 +1166,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_method_real_accept_children;
 	VALA_METHOD_CLASS (klass)->get_default_cname = vala_method_real_get_default_cname;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_method_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_method_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -1116,7 +1182,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_METHOD, g_param_spec_object ("base-method", "base-method", "base-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BASE_INTERFACE_METHOD, g_param_spec_object ("base-interface-method", "base-interface-method", "base-interface-method", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RESULT_VAR, g_param_spec_object ("result-var", "result-var", "result-var", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_RESULT_VAR, g_param_spec_object ("result-var", "result-var", "result-var", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CINSTANCE_PARAMETER_POSITION, g_param_spec_double ("cinstance-parameter-position", "cinstance-parameter-position", "cinstance-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
