@@ -40,8 +40,9 @@ static gboolean vala_method_type_real_is_invokable (ValaDataType* base);
 static ValaDataType* vala_method_type_real_get_return_type (ValaDataType* base);
 static GeeCollection* vala_method_type_real_get_parameters (ValaDataType* base);
 static ValaDataType* vala_method_type_real_copy (ValaDataType* base);
-static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static char* vala_method_type_real_to_string (ValaCodeNode* base);
+static char* vala_method_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
 static gpointer vala_method_type_parent_class = NULL;
 static void vala_method_type_dispose (GObject * obj);
 
@@ -49,7 +50,7 @@ static void vala_method_type_dispose (GObject * obj);
 
 ValaMethodType* vala_method_type_new (ValaMethod* method_symbol) {
 	ValaMethodType * self;
-	g_return_val_if_fail (method_symbol == NULL || VALA_IS_METHOD (method_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_METHOD (method_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_METHOD_TYPE, 0, NULL);
 	vala_method_type_set_method_symbol (self, method_symbol);
 	return self;
@@ -86,26 +87,26 @@ static ValaDataType* vala_method_type_real_copy (ValaDataType* base) {
 }
 
 
-static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_method_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaMethodType * self;
 	ValaDelegateType* _tmp1;
 	ValaDataType* _tmp0;
 	ValaDelegateType* dt;
 	gboolean _tmp3;
 	self = VALA_METHOD_TYPE (base);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	dt = (_tmp1 = (_tmp0 = target_type, (VALA_IS_DELEGATE_TYPE (_tmp0) ? ((ValaDelegateType*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 	if (dt == NULL) {
 		gboolean _tmp2;
+		/* method types incompatible to anything but delegates*/
 		return (_tmp2 = FALSE, (dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL))), _tmp2);
 	}
 	return (_tmp3 = vala_delegate_matches_method (vala_delegate_type_get_delegate_symbol (dt), self->priv->_method_symbol), (dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL))), _tmp3);
 }
 
 
-/* method types incompatible to anything but delegates*/
 static char* vala_method_type_real_to_string (ValaCodeNode* base) {
 	ValaMethodType * self;
 	self = VALA_METHOD_TYPE (base);
@@ -113,6 +114,13 @@ static char* vala_method_type_real_to_string (ValaCodeNode* base) {
 }
 
 
+static char* vala_method_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+	ValaMethodType * self;
+	self = VALA_METHOD_TYPE (base);
+	return g_strdup ("gpointer");
+}
+
+
 ValaMethod* vala_method_type_get_method_symbol (ValaMethodType* self) {
 	g_return_val_if_fail (VALA_IS_METHOD_TYPE (self), NULL);
 	return self->priv->_method_symbol;
@@ -169,6 +177,7 @@ static void vala_method_type_class_init (ValaMethodTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_method_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_method_type_real_compatible;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_method_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_method_type_real_get_cname;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_TYPE_METHOD_SYMBOL, g_param_spec_object ("method-symbol", "method-symbol", "method-symbol", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
