@@ -1,6 +1,6 @@
 /* valanamespace.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,7 +27,8 @@
 #include <vala/valainterface.h>
 #include <vala/valastruct.h>
 #include <vala/valaenum.h>
-#include <vala/valacallback.h>
+#include <vala/valaerrordomain.h>
+#include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
 #include <vala/valamethod.h>
@@ -38,13 +39,16 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaNamespacePrivate {
-	gboolean _pkg;
 	GeeList* classes;
 	GeeList* interfaces;
 	GeeList* structs;
 	GeeList* enums;
-	GeeList* callbacks;
+	GeeList* error_domains;
+	GeeList* delegates;
 	GeeList* constants;
 	GeeList* fields;
 	GeeList* methods;
@@ -55,8 +59,7 @@ struct _ValaNamespacePrivate {
 };
 #define VALA_NAMESPACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NAMESPACE, ValaNamespacePrivate))
 enum  {
-	VALA_NAMESPACE_DUMMY_PROPERTY,
-	VALA_NAMESPACE_PKG
+	VALA_NAMESPACE_DUMMY_PROPERTY
 };
 static void vala_namespace_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -67,6 +70,8 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 static gpointer vala_namespace_parent_class = NULL;
 static void vala_namespace_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -80,9 +85,9 @@ ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source
 	ValaNamespace * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NAMESPACE, 0, NULL);
-	vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_symbol_set_access (VALA_SYMBOL (self), VALA_SYMBOL_ACCESSIBILITY_PUBLIC);
 	return self;
 }
 
@@ -164,15 +169,28 @@ void vala_namespace_add_enum (ValaNamespace* self, ValaEnum* en) {
 
 
 /**
- * Adds the specified callback to this namespace.
+ * Adds the specified error domain to this namespace.
  *
- * @param cb a callback
+ * @param edomain an error domain
  */
-void vala_namespace_add_callback (ValaNamespace* self, ValaCallback* cb) {
+void vala_namespace_add_error_domain (ValaNamespace* self, ValaErrorDomain* edomain) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
-	g_return_if_fail (VALA_IS_CALLBACK (cb));
-	gee_collection_add (GEE_COLLECTION (self->priv->callbacks), cb);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cb)), VALA_SYMBOL (cb));
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (edomain));
+	gee_collection_add (GEE_COLLECTION (self->priv->error_domains), edomain);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (edomain)), VALA_SYMBOL (edomain));
+}
+
+
+/**
+ * Adds the specified delegate to this namespace.
+ *
+ * @param d a delegate
+ */
+void vala_namespace_add_delegate (ValaNamespace* self, ValaDelegate* d) {
+	g_return_if_fail (VALA_IS_NAMESPACE (self));
+	g_return_if_fail (VALA_IS_DELEGATE (d));
+	gee_collection_add (GEE_COLLECTION (self->priv->delegates), d);
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (d)), VALA_SYMBOL (d));
 }
 
 
@@ -209,6 +227,72 @@ GeeCollection* vala_namespace_get_interfaces (ValaNamespace* self) {
 }
 
 
+/**
+ * Returns a copy of the list of enums.
+ *
+ * @return enum list
+ */
+GeeCollection* vala_namespace_get_enums (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->enums)));
+}
+
+
+/**
+ * Returns a copy of the list of error domains.
+ *
+ * @return error domain list
+ */
+GeeCollection* vala_namespace_get_error_domains (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_ERROR_DOMAIN, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->error_domains)));
+}
+
+
+/**
+ * Returns a copy of the list of fields.
+ *
+ * @return field list
+ */
+GeeCollection* vala_namespace_get_fields (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->fields)));
+}
+
+
+/**
+ * Returns a copy of the list of constants.
+ *
+ * @return constant list
+ */
+GeeCollection* vala_namespace_get_constants (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->constants)));
+}
+
+
+/**
+ * Returns a copy of the list of delegates.
+ *
+ * @return delegate list
+ */
+GeeCollection* vala_namespace_get_delegates (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->delegates)));
+}
+
+
+/**
+ * Returns a copy of the list of methods.
+ *
+ * @return method list
+ */
+GeeCollection* vala_namespace_get_methods (ValaNamespace* self) {
+	g_return_val_if_fail (VALA_IS_NAMESPACE (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->methods)));
+}
+
+
 /**
  * Adds the specified constant to this namespace.
  *
@@ -277,7 +361,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
 		while (gee_iterator_next (ns_it)) {
 			ValaNamespace* ns;
-			ns = gee_iterator_get (ns_it);
+			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ns), visitor);
 				(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
@@ -285,6 +369,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		}
 		(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 	}
+	/* process enums first to avoid order problems in C code */
 	{
 		GeeList* en_collection;
 		GeeIterator* en_it;
@@ -292,15 +377,29 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		en_it = gee_iterable_iterator (GEE_ITERABLE (en_collection));
 		while (gee_iterator_next (en_it)) {
 			ValaEnum* en;
-			en = gee_iterator_get (en_it);
+			en = ((ValaEnum*) gee_iterator_get (en_it));
 			{
-				/* process enums first to avoid order problems in C code */
 				vala_code_node_accept (VALA_CODE_NODE (en), visitor);
 				(en == NULL ? NULL : (en = (g_object_unref (en), NULL)));
 			}
 		}
 		(en_it == NULL ? NULL : (en_it = (g_object_unref (en_it), NULL)));
 	}
+	{
+		GeeList* edomain_collection;
+		GeeIterator* edomain_it;
+		edomain_collection = self->priv->error_domains;
+		edomain_it = gee_iterable_iterator (GEE_ITERABLE (edomain_collection));
+		while (gee_iterator_next (edomain_it)) {
+			ValaErrorDomain* edomain;
+			edomain = ((ValaErrorDomain*) gee_iterator_get (edomain_it));
+			{
+				vala_code_node_accept (VALA_CODE_NODE (edomain), visitor);
+				(edomain == NULL ? NULL : (edomain = (g_object_unref (edomain), NULL)));
+			}
+		}
+		(edomain_it == NULL ? NULL : (edomain_it = (g_object_unref (edomain_it), NULL)));
+	}
 	{
 		GeeList* cl_collection;
 		GeeIterator* cl_it;
@@ -308,7 +407,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		cl_it = gee_iterable_iterator (GEE_ITERABLE (cl_collection));
 		while (gee_iterator_next (cl_it)) {
 			ValaClass* cl;
-			cl = gee_iterator_get (cl_it);
+			cl = ((ValaClass*) gee_iterator_get (cl_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (cl), visitor);
 				(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
@@ -323,7 +422,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		iface_it = gee_iterable_iterator (GEE_ITERABLE (iface_collection));
 		while (gee_iterator_next (iface_it)) {
 			ValaInterface* iface;
-			iface = gee_iterator_get (iface_it);
+			iface = ((ValaInterface*) gee_iterator_get (iface_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (iface), visitor);
 				(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
@@ -338,7 +437,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
 		while (gee_iterator_next (st_it)) {
 			ValaStruct* st;
-			st = gee_iterator_get (st_it);
+			st = ((ValaStruct*) gee_iterator_get (st_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
 				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
@@ -347,19 +446,19 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
 	}
 	{
-		GeeList* cb_collection;
-		GeeIterator* cb_it;
-		cb_collection = self->priv->callbacks;
-		cb_it = gee_iterable_iterator (GEE_ITERABLE (cb_collection));
-		while (gee_iterator_next (cb_it)) {
-			ValaCallback* cb;
-			cb = gee_iterator_get (cb_it);
+		GeeList* d_collection;
+		GeeIterator* d_it;
+		d_collection = self->priv->delegates;
+		d_it = gee_iterable_iterator (GEE_ITERABLE (d_collection));
+		while (gee_iterator_next (d_it)) {
+			ValaDelegate* d;
+			d = ((ValaDelegate*) gee_iterator_get (d_it));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (cb), visitor);
-				(cb == NULL ? NULL : (cb = (g_object_unref (cb), NULL)));
+				vala_code_node_accept (VALA_CODE_NODE (d), visitor);
+				(d == NULL ? NULL : (d = (g_object_unref (d), NULL)));
 			}
 		}
-		(cb_it == NULL ? NULL : (cb_it = (g_object_unref (cb_it), NULL)));
+		(d_it == NULL ? NULL : (d_it = (g_object_unref (d_it), NULL)));
 	}
 	{
 		GeeList* c_collection;
@@ -368,7 +467,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		c_it = gee_iterable_iterator (GEE_ITERABLE (c_collection));
 		while (gee_iterator_next (c_it)) {
 			ValaConstant* c;
-			c = gee_iterator_get (c_it);
+			c = ((ValaConstant*) gee_iterator_get (c_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
 				(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
@@ -383,7 +482,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
 		while (gee_iterator_next (f_it)) {
 			ValaField* f;
-			f = gee_iterator_get (f_it);
+			f = ((ValaField*) gee_iterator_get (f_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
 				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
@@ -398,7 +497,7 @@ static void vala_namespace_real_accept_children (ValaCodeNode* base, ValaCodeVis
 		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
 		while (gee_iterator_next (m_it)) {
 			ValaMethod* m;
-			m = gee_iterator_get (m_it);
+			m = ((ValaMethod*) gee_iterator_get (m_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
 				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
@@ -413,12 +512,23 @@ static char* vala_namespace_real_get_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
 	self = VALA_NAMESPACE (base);
 	if (gee_collection_get_size (GEE_COLLECTION (self->priv->cprefixes)) > 0) {
-		return gee_list_get (((GeeList*) self->priv->cprefixes), 0);
+		return ((char*) gee_list_get (((GeeList*) self->priv->cprefixes), 0));
 	} else {
 		if (NULL != vala_symbol_get_name (VALA_SYMBOL (self))) {
-			const char* _tmp1;
-			_tmp1 = NULL;
-			return (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+			char* parent_prefix;
+			char* _tmp3;
+			parent_prefix = NULL;
+			if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
+				char* _tmp1;
+				_tmp1 = NULL;
+				parent_prefix = (_tmp1 = g_strdup (""), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp1);
+			} else {
+				char* _tmp2;
+				_tmp2 = NULL;
+				parent_prefix = (_tmp2 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp2);
+			}
+			_tmp3 = NULL;
+			return (_tmp3 = g_strconcat (parent_prefix, vala_symbol_get_name (VALA_SYMBOL (self)), NULL), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp3);
 		} else {
 			return g_strdup ("");
 		}
@@ -459,7 +569,7 @@ void vala_namespace_add_cprefix (ValaNamespace* self, const char* cprefix) {
  */
 static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 	ValaNamespace * self;
-	const char* _tmp3;
+	const char* _tmp5;
 	self = VALA_NAMESPACE (base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		if (vala_symbol_get_name (VALA_SYMBOL (self)) == NULL) {
@@ -467,16 +577,28 @@ static char* vala_namespace_real_get_lower_case_cprefix (ValaSymbol* base) {
 			_tmp0 = NULL;
 			self->priv->lower_case_cprefix = (_tmp0 = g_strdup (""), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp0);
 		} else {
-			char* _tmp2;
-			char* _tmp1;
-			_tmp2 = NULL;
-			_tmp1 = NULL;
-			self->priv->lower_case_cprefix = (_tmp2 = g_strdup_printf ("%s_", (_tmp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp2);
-			(_tmp1 = (g_free (_tmp1), NULL));
+			char* parent_prefix;
+			char* _tmp4;
+			char* _tmp3;
+			parent_prefix = NULL;
+			if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
+				char* _tmp1;
+				_tmp1 = NULL;
+				parent_prefix = (_tmp1 = g_strdup (""), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp1);
+			} else {
+				char* _tmp2;
+				_tmp2 = NULL;
+				parent_prefix = (_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), (parent_prefix = (g_free (parent_prefix), NULL)), _tmp2);
+			}
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			self->priv->lower_case_cprefix = (_tmp4 = g_strdup_printf ("%s%s_", parent_prefix, (_tmp3 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (VALA_SYMBOL (self))))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp4);
+			_tmp3 = (g_free (_tmp3), NULL);
+			parent_prefix = (g_free (parent_prefix), NULL);
 		}
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->lower_case_cprefix, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	_tmp5 = NULL;
+	return (_tmp5 = self->priv->lower_case_cprefix, (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 }
 
 
@@ -490,6 +612,7 @@ void vala_namespace_set_lower_case_cprefix (ValaNamespace* self, const char* cpr
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
+	g_return_if_fail (cprefix != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->lower_case_cprefix = (_tmp1 = (_tmp0 = cprefix, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), _tmp1);
@@ -523,7 +646,7 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 		cheader_filename_it = gee_iterable_iterator (GEE_ITERABLE (cheader_filename_collection));
 		while (gee_iterator_next (cheader_filename_it)) {
 			char* cheader_filename;
-			cheader_filename = gee_iterator_get (cheader_filename_it);
+			cheader_filename = ((char*) gee_iterator_get (cheader_filename_it));
 			{
 				if (first) {
 					first = FALSE;
@@ -531,7 +654,7 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 					g_string_append_c (s, ',');
 				}
 				g_string_append (s, cheader_filename);
-				(cheader_filename = (g_free (cheader_filename), NULL));
+				cheader_filename = (g_free (cheader_filename), NULL);
 			}
 		}
 		(cheader_filename_collection == NULL ? NULL : (cheader_filename_collection = (g_object_unref (cheader_filename_collection), NULL)));
@@ -540,7 +663,6 @@ char* vala_namespace_get_cheader_filename (ValaNamespace* self) {
 	_tmp0 = NULL;
 	_tmp1 = NULL;
 	return (_tmp1 = (_tmp0 = s->str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), _tmp1);
-	(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 }
 
 
@@ -581,17 +703,17 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 				name = (_tmp2 = *name_it, (_tmp2 == NULL ? NULL : g_strdup (_tmp2)));
 				{
 					vala_namespace_add_cprefix (self, name);
-					(name = (g_free (name), NULL));
+					name = (g_free (name), NULL);
 				}
 			}
-			(name_collection = (_vala_array_free (name_collection, name_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			name_collection = (_vala_array_free (name_collection, name_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
 	}
 	if (vala_attribute_has_argument (a, "lower_case_cprefix")) {
 		char* _tmp3;
 		_tmp3 = NULL;
 		vala_namespace_set_lower_case_cprefix (self, (_tmp3 = vala_attribute_get_string (a, "lower_case_cprefix")));
-		(_tmp3 = (g_free (_tmp3), NULL));
+		_tmp3 = (g_free (_tmp3), NULL);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
@@ -609,12 +731,12 @@ static void vala_namespace_process_ccode_attribute (ValaNamespace* self, ValaAtt
 				filename = (_tmp4 = *filename_it, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 				{
 					gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
-					(filename = (g_free (filename), NULL));
+					filename = (g_free (filename), NULL);
 				}
 			}
-			(filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL));
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
 		}
-		(val = (g_free (val), NULL));
+		val = (g_free (val), NULL);
 	}
 }
 
@@ -632,9 +754,9 @@ void vala_namespace_process_attributes (ValaNamespace* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_namespace_process_ccode_attribute (self, a);
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -644,58 +766,15 @@ void vala_namespace_process_attributes (ValaNamespace* self) {
 }
 
 
-gboolean vala_namespace_get_pkg (ValaNamespace* self) {
-	g_return_val_if_fail (VALA_IS_NAMESPACE (self), FALSE);
-	return self->priv->_pkg;
-}
-
-
-void vala_namespace_set_pkg (ValaNamespace* self, gboolean value) {
-	g_return_if_fail (VALA_IS_NAMESPACE (self));
-	self->priv->_pkg = value;
-}
-
-
-static void vala_namespace_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
-	ValaNamespace * self;
-	self = VALA_NAMESPACE (object);
-	switch (property_id) {
-		case VALA_NAMESPACE_PKG:
-		g_value_set_boolean (value, vala_namespace_get_pkg (self));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
-static void vala_namespace_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
-	ValaNamespace * self;
-	self = VALA_NAMESPACE (object);
-	switch (property_id) {
-		case VALA_NAMESPACE_PKG:
-		vala_namespace_set_pkg (self, g_value_get_boolean (value));
-		break;
-		default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-		break;
-	}
-}
-
-
 static void vala_namespace_class_init (ValaNamespaceClass * klass) {
 	vala_namespace_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaNamespacePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_namespace_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_namespace_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_namespace_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_namespace_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_namespace_real_accept_children;
 	VALA_SYMBOL_CLASS (klass)->get_cprefix = vala_namespace_real_get_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_namespace_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_namespace_real_get_cheader_filenames;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_NAMESPACE_PKG, g_param_spec_boolean ("pkg", "pkg", "pkg", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -705,7 +784,8 @@ static void vala_namespace_init (ValaNamespace * self) {
 	self->priv->interfaces = GEE_LIST (gee_array_list_new (VALA_TYPE_INTERFACE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->structs = GEE_LIST (gee_array_list_new (VALA_TYPE_STRUCT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->enums = GEE_LIST (gee_array_list_new (VALA_TYPE_ENUM, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->callbacks = GEE_LIST (gee_array_list_new (VALA_TYPE_CALLBACK, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->error_domains = GEE_LIST (gee_array_list_new (VALA_TYPE_ERROR_DOMAIN, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->delegates = GEE_LIST (gee_array_list_new (VALA_TYPE_DELEGATE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->constants = GEE_LIST (gee_array_list_new (VALA_TYPE_CONSTANT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->fields = GEE_LIST (gee_array_list_new (VALA_TYPE_FIELD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
@@ -722,12 +802,13 @@ static void vala_namespace_dispose (GObject * obj) {
 	(self->priv->interfaces == NULL ? NULL : (self->priv->interfaces = (g_object_unref (self->priv->interfaces), NULL)));
 	(self->priv->structs == NULL ? NULL : (self->priv->structs = (g_object_unref (self->priv->structs), NULL)));
 	(self->priv->enums == NULL ? NULL : (self->priv->enums = (g_object_unref (self->priv->enums), NULL)));
-	(self->priv->callbacks == NULL ? NULL : (self->priv->callbacks = (g_object_unref (self->priv->callbacks), NULL)));
+	(self->priv->error_domains == NULL ? NULL : (self->priv->error_domains = (g_object_unref (self->priv->error_domains), NULL)));
+	(self->priv->delegates == NULL ? NULL : (self->priv->delegates = (g_object_unref (self->priv->delegates), NULL)));
 	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
 	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
 	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
 	(self->priv->cprefixes == NULL ? NULL : (self->priv->cprefixes = (g_object_unref (self->priv->cprefixes), NULL)));
-	(self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL));
+	self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL);
 	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
 	(self->priv->namespaces == NULL ? NULL : (self->priv->namespaces = (g_object_unref (self->priv->namespaces), NULL)));
 	G_OBJECT_CLASS (vala_namespace_parent_class)->dispose (obj);
@@ -761,5 +842,16 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
