@@ -25,6 +25,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaNamespaceReferencePrivate {
 	char* _name;
 	ValaSymbol* _namespace_symbol;
@@ -40,6 +43,7 @@ static gpointer vala_namespace_reference_parent_class = NULL;
 static void vala_namespace_reference_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new namespace reference.
  *
@@ -49,10 +53,11 @@ static void vala_namespace_reference_dispose (GObject * obj);
  */
 ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSourceReference* source_reference) {
 	ValaNamespaceReference * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NAMESPACE_REFERENCE, 0, NULL);
-	vala_namespace_reference_set_name (self, name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_namespace_reference_set_name (self, name);
 	return self;
 }
 
@@ -60,7 +65,7 @@ ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSour
 static void vala_namespace_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamespaceReference * self;
 	self = VALA_NAMESPACE_REFERENCE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_namespace_reference (visitor, self);
 }
 
