@@ -35,7 +35,7 @@
 enum  {
 	VALA_NULL_TYPE_DUMMY_PROPERTY
 };
-static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static ValaDataType* vala_null_type_real_copy (ValaDataType* base);
 static gpointer vala_null_type_parent_class = NULL;
 
@@ -43,36 +43,35 @@ static gpointer vala_null_type_parent_class = NULL;
 
 ValaNullType* vala_null_type_new (ValaSourceReference* source_reference) {
 	ValaNullType * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NULL_TYPE, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
-static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaNullType * self;
 	ValaAttribute* _tmp1;
 	gboolean _tmp2;
 	self = VALA_NULL_TYPE (base);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	if (!(VALA_IS_POINTER_TYPE (target_type)) && (VALA_IS_NULL_TYPE (target_type) || (vala_data_type_get_data_type (target_type) == NULL && vala_data_type_get_type_parameter (target_type) == NULL))) {
 		return TRUE;
 	}
 	/* null can be cast to any reference or array type or pointer type */
 	_tmp1 = NULL;
-	if ((_tmp2 = vala_data_type_get_type_parameter (target_type) != NULL || VALA_IS_POINTER_TYPE (target_type) || vala_data_type_get_is_out (target_type) || vala_data_type_get_nullable (target_type) || (_tmp1 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2)) {
+	if ((_tmp2 = vala_data_type_get_type_parameter (target_type) != NULL || VALA_IS_POINTER_TYPE (target_type) || vala_data_type_get_nullable (target_type) || (_tmp1 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL, (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2)) {
 		return TRUE;
 	}
 	if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (target_type)) || VALA_IS_ARRAY_TYPE (target_type) || VALA_IS_DELEGATE_TYPE (target_type)) {
-		return !enable_non_null;
+		return TRUE;
 	}
+	/* null is not compatible with any other type (i.e. value types) */
 	return FALSE;
 }
 
 
-/* incompatibility between null and non-null types
- null is not compatible with any other type (i.e. value types) */
 static ValaDataType* vala_null_type_real_copy (ValaDataType* base) {
 	ValaNullType * self;
 	self = VALA_NULL_TYPE (base);
