@@ -31,9 +31,13 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaObjectCreationExpressionPrivate {
 	ValaMethod* _constructor;
 	ValaMemberAccess* _member_name;
+	gboolean _struct_creation;
 	GeeList* argument_list;
 	GeeList* object_initializer;
 	ValaDataType* _data_type;
@@ -43,7 +47,8 @@ enum  {
 	VALA_OBJECT_CREATION_EXPRESSION_DUMMY_PROPERTY,
 	VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE,
 	VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR,
-	VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME
+	VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME,
+	VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION
 };
 static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -54,6 +59,7 @@ static gpointer vala_object_creation_expression_parent_class = NULL;
 static void vala_object_creation_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new object creation expression.
  *
@@ -63,11 +69,11 @@ static void vala_object_creation_expression_dispose (GObject * obj);
  */
 ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference) {
 	ValaObjectCreationExpression * self;
-	g_return_val_if_fail (member_name == NULL || VALA_IS_MEMBER_ACCESS (member_name), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_MEMBER_ACCESS (member_name), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_OBJECT_CREATION_EXPRESSION, 0, NULL);
-	vala_object_creation_expression_set_member_name (self, member_name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_object_creation_expression_set_member_name (self, member_name);
 	return self;
 }
 
@@ -79,7 +85,7 @@ ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAcc
  */
 void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg) {
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	g_return_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg));
+	g_return_if_fail (VALA_IS_EXPRESSION (arg));
 	gee_collection_add (GEE_COLLECTION (self->priv->argument_list), arg);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (arg), VALA_CODE_NODE (self));
 }
@@ -103,7 +109,7 @@ GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCrea
  */
 void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init) {
 	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
-	g_return_if_fail (init == NULL || VALA_IS_MEMBER_INITIALIZER (init));
+	g_return_if_fail (VALA_IS_MEMBER_INITIALIZER (init));
 	gee_collection_add (GEE_COLLECTION (self->priv->object_initializer), init);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self));
 }
@@ -123,7 +129,7 @@ GeeCollection* vala_object_creation_expression_get_object_initializer (ValaObjec
 static void vala_object_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_object_creation_expression (visitor, self);
 }
 
@@ -131,12 +137,12 @@ static void vala_object_creation_expression_real_accept (ValaCodeNode* base, Val
 static void vala_object_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_object_creation_expression_get_type_reference (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_object_creation_expression_get_type_reference (self)), visitor);
 	}
-	if (vala_object_creation_expression_get_member_name (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_object_creation_expression_get_member_name (self)), visitor);
+	if (self->priv->_member_name != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_member_name), visitor);
 	}
 	{
 		GeeList* arg_collection;
@@ -175,8 +181,8 @@ static void vala_object_creation_expression_real_replace_expression (ValaCodeNod
 	ValaObjectCreationExpression * self;
 	gint index;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	index = gee_list_index_of (self->priv->argument_list, old_node);
 	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
 		gee_list_set (((GeeList*) self->priv->argument_list), index, new_node);
@@ -195,8 +201,8 @@ static gboolean vala_object_creation_expression_real_is_pure (ValaExpression* ba
 static void vala_object_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_object_creation_expression_get_type_reference (self) == old_type) {
 		vala_object_creation_expression_set_type_reference (self, new_type);
 	}
@@ -252,6 +258,18 @@ void vala_object_creation_expression_set_member_name (ValaObjectCreationExpressi
 }
 
 
+gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreationExpression* self) {
+	g_return_val_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self), FALSE);
+	return self->priv->_struct_creation;
+}
+
+
+void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value) {
+	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (self));
+	self->priv->_struct_creation = value;
+}
+
+
 static void vala_object_creation_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaObjectCreationExpression * self;
 	self = VALA_OBJECT_CREATION_EXPRESSION (object);
@@ -265,6 +283,9 @@ static void vala_object_creation_expression_get_property (GObject * object, guin
 		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
 		g_value_set_object (value, vala_object_creation_expression_get_member_name (self));
 		break;
+		case VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION:
+		g_value_set_boolean (value, vala_object_creation_expression_get_struct_creation (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -285,6 +306,9 @@ static void vala_object_creation_expression_set_property (GObject * object, guin
 		case VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME:
 		vala_object_creation_expression_set_member_name (self, g_value_get_object (value));
 		break;
+		case VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION:
+		vala_object_creation_expression_set_struct_creation (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -306,6 +330,7 @@ static void vala_object_creation_expression_class_init (ValaObjectCreationExpres
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_CONSTRUCTOR, g_param_spec_object ("constructor", "constructor", "constructor", VALA_TYPE_METHOD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_MEMBER_NAME, g_param_spec_object ("member-name", "member-name", "member-name", VALA_TYPE_MEMBER_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_OBJECT_CREATION_EXPRESSION_STRUCT_CREATION, g_param_spec_boolean ("struct-creation", "struct-creation", "struct-creation", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
