@@ -1,11 +1,11 @@
 /* valaparser.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,16 +20,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAPARSER_H__
-#define __VALAPARSER_H__
-typedef struct _ValaParser ValaParser;
-typedef struct _ValaParserClass ValaParserClass;
-typedef struct _ValaParserPrivate ValaParserPrivate;
+#ifndef __VALA_VALAPARSER_H__
+#define __VALA_VALAPARSER_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <stdlib.h>
-#include <string.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
@@ -44,23 +39,32 @@ G_BEGIN_DECLS
 #define VALA_IS_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_PARSER))
 #define VALA_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_PARSER, ValaParserClass))
 
+typedef struct _ValaParser ValaParser;
+typedef struct _ValaParserClass ValaParserClass;
+typedef struct _ValaParserPrivate ValaParserPrivate;
 
 /**
  * Code visitor parsing all Vala source files.
  */
 struct _ValaParser {
-	ValaCodeVisitor parent;
+	ValaCodeVisitor parent_instance;
 	ValaParserPrivate * priv;
 };
 struct _ValaParserClass {
-	ValaCodeVisitorClass parent;
+	ValaCodeVisitorClass parent_class;
 };
+typedef enum  {
+	VALA_PARSE_ERROR_FAILED,
+	VALA_PARSE_ERROR_SYNTAX
+} ValaParseError;
+#define VALA_PARSE_ERROR vala_parse_error_quark ()
 
 void vala_parser_parse (ValaParser* self, ValaCodeContext* context);
-void vala_parser_push_comment (ValaParser* self, const char* comment_item, gboolean file_comment);
-char* vala_parser_pop_comment (ValaParser* self);
 void vala_parser_parse_file (ValaParser* self, ValaSourceFile* source_file);
-GType vala_parser_get_type ();
+ValaParser* vala_parser_new (void);
+GType vala_parser_get_type (void);
+GQuark vala_parse_error_quark (void);
+
 
 G_END_DECLS
 
