@@ -1,11 +1,11 @@
 /* valapostfixexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,11 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valapostfixexpression.h"
-#include <vala/valasourcereference.h>
 #include <vala/valapostfixexpression.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaPostfixExpressionPrivate {
 	ValaExpression* _inner;
 	gboolean _increment;
@@ -36,10 +38,12 @@ enum  {
 	VALA_POSTFIX_EXPRESSION_INCREMENT
 };
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base);
 static gpointer vala_postfix_expression_parent_class = NULL;
 static void vala_postfix_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new postfix expression.
  *
@@ -48,16 +52,18 @@ static void vala_postfix_expression_dispose (GObject * obj);
  * @param source reference to source code
  * @return newly created postfix expression
  */
-ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source)
-{
+ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaPostfixExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, _inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_POSTFIX_EXPRESSION, __params_it - __params, __params);
 	vala_postfix_expression_set_increment (self, inc);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -70,48 +76,51 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 }
 
 
-static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPostfixExpression * self;
-	self = ((ValaPostfixExpression*) base);
+	self = VALA_POSTFIX_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_postfix_expression_get_inner (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_inner), visitor);
 	vala_code_visitor_visit_postfix_expression (visitor, self);
 }
 
 
-ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self)
-{
+static gboolean vala_postfix_expression_real_is_pure (ValaExpression* base) {
+	ValaPostfixExpression * self;
+	self = VALA_POSTFIX_EXPRESSION (base);
+	return FALSE;
+}
+
+
+ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self) {
 	g_return_val_if_fail (VALA_IS_POSTFIX_EXPRESSION (self), NULL);
 	return self->priv->_inner;
 }
 
 
-void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value)
-{
+void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value) {
+	ValaExpression* _tmp2;
 	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_inner = (_tmp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp1);
+	self->priv->_inner = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), _tmp2);
 }
 
 
-gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self)
-{
+gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self) {
 	g_return_val_if_fail (VALA_IS_POSTFIX_EXPRESSION (self), FALSE);
 	return self->priv->_increment;
 }
 
 
-void vala_postfix_expression_set_increment (ValaPostfixExpression* self, gboolean value)
-{
+void vala_postfix_expression_set_increment (ValaPostfixExpression* self, gboolean value) {
 	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (self));
 	self->priv->_increment = value;
 }
 
 
-static void vala_postfix_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_postfix_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (object);
 	switch (property_id) {
@@ -128,8 +137,7 @@ static void vala_postfix_expression_get_property (GObject * object, guint proper
 }
 
 
-static void vala_postfix_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_postfix_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (object);
 	switch (property_id) {
@@ -146,40 +154,33 @@ static void vala_postfix_expression_set_property (GObject * object, guint proper
 }
 
 
-static void vala_postfix_expression_class_init (ValaPostfixExpressionClass * klass)
-{
+static void vala_postfix_expression_class_init (ValaPostfixExpressionClass * klass) {
 	vala_postfix_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaPostfixExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_postfix_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_postfix_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_postfix_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_postfix_expression_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INNER, g_param_spec_object ("inner", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INCREMENT, g_param_spec_boolean ("increment", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_postfix_expression_real_is_pure;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POSTFIX_EXPRESSION_INCREMENT, g_param_spec_boolean ("increment", "increment", "increment", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_postfix_expression_init (ValaPostfixExpression * self)
-{
+static void vala_postfix_expression_init (ValaPostfixExpression * self) {
 	self->priv = VALA_POSTFIX_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_postfix_expression_dispose (GObject * obj)
-{
+static void vala_postfix_expression_dispose (GObject * obj) {
 	ValaPostfixExpression * self;
-	ValaPostfixExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_POSTFIX_EXPRESSION (obj);
 	(self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL)));
-	klass = VALA_POSTFIX_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_POSTFIX_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_postfix_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_postfix_expression_get_type (void)
-{
+GType vala_postfix_expression_get_type (void) {
 	static GType vala_postfix_expression_type_id = 0;
 	if (G_UNLIKELY (vala_postfix_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaPostfixExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_postfix_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPostfixExpression), 0, (GInstanceInitFunc) vala_postfix_expression_init };
