@@ -1,11 +1,11 @@
 /* valapostfixexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,9 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAPOSTFIXEXPRESSION_H__
-#define __VALAPOSTFIXEXPRESSION_H__
-typedef struct _ValaPostfixExpressionPrivate ValaPostfixExpressionPrivate;
+#ifndef __VALA_VALAPOSTFIXEXPRESSION_H__
+#define __VALA_VALAPOSTFIXEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,16 +38,17 @@ G_BEGIN_DECLS
 #define VALA_IS_POSTFIX_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_POSTFIX_EXPRESSION))
 #define VALA_POSTFIX_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_POSTFIX_EXPRESSION, ValaPostfixExpressionClass))
 
+typedef struct _ValaPostfixExpressionPrivate ValaPostfixExpressionPrivate;
 
 /**
  * Represents a postfix increment or decrement expression.
  */
 struct _ValaPostfixExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaPostfixExpressionPrivate * priv;
 };
 struct _ValaPostfixExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
 ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboolean inc, ValaSourceReference* source);
@@ -56,7 +56,8 @@ ValaExpression* vala_postfix_expression_get_inner (ValaPostfixExpression* self);
 void vala_postfix_expression_set_inner (ValaPostfixExpression* self, ValaExpression* value);
 gboolean vala_postfix_expression_get_increment (ValaPostfixExpression* self);
 void vala_postfix_expression_set_increment (ValaPostfixExpression* self, gboolean value);
-GType vala_postfix_expression_get_type ();
+GType vala_postfix_expression_get_type (void);
+
 
 G_END_DECLS
 
