@@ -23,6 +23,7 @@
 #include <vala/valaproperty.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valafield.h>
 #include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
@@ -30,6 +31,9 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaPropertyPrivate {
 	ValaPropertyAccessor* _get_accessor;
 	ValaPropertyAccessor* _set_accessor;
@@ -40,6 +44,7 @@ struct _ValaPropertyPrivate {
 	gboolean _is_abstract;
 	gboolean _is_virtual;
 	gboolean _overrides;
+	ValaField* _field;
 	ValaProperty* _base_property;
 	ValaProperty* _base_interface_property;
 	ValaExpression* _default_expression;
@@ -62,6 +67,7 @@ enum  {
 	VALA_PROPERTY_IS_ABSTRACT,
 	VALA_PROPERTY_IS_VIRTUAL,
 	VALA_PROPERTY_OVERRIDES,
+	VALA_PROPERTY_FIELD,
 	VALA_PROPERTY_INSTANCE,
 	VALA_PROPERTY_BASE_PROPERTY,
 	VALA_PROPERTY_BASE_INTERFACE_PROPERTY,
@@ -81,6 +87,7 @@ static void vala_property_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new property.
  *
@@ -93,10 +100,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaPropertyAccessor* _get_accessor, ValaPropertyAccessor* _set_accessor, ValaSourceReference* source) {
 	ValaProperty * self;
-	g_return_val_if_fail (type == NULL || VALA_IS_DATA_TYPE (type), NULL);
+	g_return_val_if_fail (_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
 	g_return_val_if_fail (_get_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_get_accessor), NULL);
 	g_return_val_if_fail (_set_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_set_accessor), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_PROPERTY, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), _name);
 	vala_property_set_type_reference (self, type);
@@ -110,7 +118,7 @@ ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaProp
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_property (visitor, self);
 }
@@ -119,16 +127,16 @@ static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_property_get_type_reference (self)), visitor);
-	if (vala_property_get_get_accessor (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_get_get_accessor (self)), visitor);
+	if (self->priv->_get_accessor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_get_accessor), visitor);
 	}
-	if (vala_property_get_set_accessor (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_get_set_accessor (self)), visitor);
+	if (self->priv->_set_accessor != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_set_accessor), visitor);
 	}
-	if (vala_property_get_default_expression (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_property_get_default_expression (self)), visitor);
+	if (self->priv->_default_expression != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 	}
 }
 
@@ -269,21 +277,21 @@ static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used)
  */
 gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
-	g_return_val_if_fail (prop2 == NULL || VALA_IS_PROPERTY (prop2), FALSE);
+	g_return_val_if_fail (VALA_IS_PROPERTY (prop2), FALSE);
 	if (!vala_data_type_equals (vala_property_get_type_reference (prop2), vala_property_get_type_reference (self))) {
 		return FALSE;
 	}
-	if ((vala_property_get_get_accessor (self) == NULL && vala_property_get_get_accessor (prop2) != NULL) || (vala_property_get_get_accessor (self) != NULL && vala_property_get_get_accessor (prop2) == NULL)) {
+	if ((self->priv->_get_accessor == NULL && prop2->priv->_get_accessor != NULL) || (self->priv->_get_accessor != NULL && prop2->priv->_get_accessor == NULL)) {
 		return FALSE;
 	}
-	if ((vala_property_get_set_accessor (self) == NULL && vala_property_get_set_accessor (prop2) != NULL) || (vala_property_get_set_accessor (self) != NULL && vala_property_get_set_accessor (prop2) == NULL)) {
+	if ((self->priv->_set_accessor == NULL && prop2->priv->_set_accessor != NULL) || (self->priv->_set_accessor != NULL && prop2->priv->_set_accessor == NULL)) {
 		return FALSE;
 	}
-	if (vala_property_get_set_accessor (self) != NULL) {
-		if (vala_property_accessor_get_writable (vala_property_get_set_accessor (self)) != vala_property_accessor_get_writable (vala_property_get_set_accessor (prop2))) {
+	if (self->priv->_set_accessor != NULL) {
+		if (vala_property_accessor_get_writable (self->priv->_set_accessor) != vala_property_accessor_get_writable (prop2->priv->_set_accessor)) {
 			return FALSE;
 		}
-		if (vala_property_accessor_get_construction (vala_property_get_set_accessor (self)) != vala_property_accessor_get_construction (vala_property_get_set_accessor (prop2))) {
+		if (vala_property_accessor_get_construction (self->priv->_set_accessor) != vala_property_accessor_get_construction (prop2->priv->_set_accessor)) {
 			return FALSE;
 		}
 	}
@@ -294,8 +302,8 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 static void vala_property_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_property_get_type_reference (self) == old_type) {
 		vala_property_set_type_reference (self, new_type);
 	}
@@ -439,6 +447,22 @@ void vala_property_set_overrides (ValaProperty* self, gboolean value) {
 }
 
 
+ValaField* vala_property_get_field (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	return self->priv->_field;
+}
+
+
+void vala_property_set_field (ValaProperty* self, ValaField* value) {
+	ValaField* _tmp2;
+	ValaField* _tmp1;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_field = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL))), _tmp2);
+}
+
+
 gboolean vala_property_get_instance (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
 	return self->priv->_instance;
@@ -571,6 +595,9 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_OVERRIDES:
 		g_value_set_boolean (value, vala_property_get_overrides (self));
 		break;
+		case VALA_PROPERTY_FIELD:
+		g_value_set_object (value, vala_property_get_field (self));
+		break;
 		case VALA_PROPERTY_INSTANCE:
 		g_value_set_boolean (value, vala_property_get_instance (self));
 		break;
@@ -630,6 +657,9 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_OVERRIDES:
 		vala_property_set_overrides (self, g_value_get_boolean (value));
 		break;
+		case VALA_PROPERTY_FIELD:
+		vala_property_set_field (self, g_value_get_object (value));
+		break;
 		case VALA_PROPERTY_INSTANCE:
 		vala_property_set_instance (self, g_value_get_boolean (value));
 		break;
@@ -674,6 +704,7 @@ static void vala_property_class_init (ValaPropertyClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_FIELD, g_param_spec_object ("field", "field", "field", VALA_TYPE_FIELD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -703,6 +734,7 @@ static void vala_property_dispose (GObject * obj) {
 	(self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL)));
 	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
+	(self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL)));
 	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL)));
 	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
