@@ -1,6 +1,6 @@
 /* valaproperty.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -80,12 +80,23 @@ gboolean vala_property_get_is_virtual (ValaProperty* self);
 void vala_property_set_is_virtual (ValaProperty* self, gboolean value);
 gboolean vala_property_get_overrides (ValaProperty* self);
 void vala_property_set_overrides (ValaProperty* self, gboolean value);
+ValaField* vala_property_get_field (ValaProperty* self);
+void vala_property_set_field (ValaProperty* self, ValaField* value);
+gboolean vala_property_get_instance (ValaProperty* self);
+void vala_property_set_instance (ValaProperty* self, gboolean value);
 ValaProperty* vala_property_get_base_property (ValaProperty* self);
 void vala_property_set_base_property (ValaProperty* self, ValaProperty* value);
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self);
 void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value);
+ValaExpression* vala_property_get_default_expression (ValaProperty* self);
+void vala_property_set_default_expression (ValaProperty* self, ValaExpression* value);
+char* vala_property_get_nick (ValaProperty* self);
+void vala_property_set_nick (ValaProperty* self, const char* value);
+char* vala_property_get_blurb (ValaProperty* self);
+void vala_property_set_blurb (ValaProperty* self, const char* value);
 GType vala_property_get_type (void);
 
+
 G_END_DECLS
 
 #endif
