@@ -1,6 +1,6 @@
 /* valareport.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,20 +31,14 @@
 
 G_BEGIN_DECLS
 
-typedef struct _ValaReport ValaReport;
 
-/**
- * Static class to centralize reporting warnings and errors.
- */
-struct _ValaReport {
-};
 
+void vala_report_set_verbose_errors (gboolean verbose);
 gint vala_report_get_warnings (void);
 gint vala_report_get_errors (void);
 void vala_report_warning (ValaSourceReference* source, const char* message);
 void vala_report_error (ValaSourceReference* source, const char* message);
-ValaReport* vala_report_new (void);
-void vala_report_free (ValaReport* self);
+
 
 G_END_DECLS
 
