@@ -1,11 +1,11 @@
 /* valareturnstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALARETURNSTATEMENT_H__
-#define __VALARETURNSTATEMENT_H__
+#ifndef __VALA_VALARETURNSTATEMENT_H__
+#define __VALA_VALARETURNSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -44,18 +44,19 @@ typedef struct _ValaReturnStatementPrivate ValaReturnStatementPrivate;
  * Represents a return statement in the source code.
  */
 struct _ValaReturnStatement {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaReturnStatementPrivate * priv;
 };
 struct _ValaReturnStatementClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
-ValaReturnStatement* vala_return_statement_new (ValaExpression* result, ValaSourceReference* source);
+ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expression, ValaSourceReference* source_reference);
 ValaExpression* vala_return_statement_get_return_expression (ValaReturnStatement* self);
 void vala_return_statement_set_return_expression (ValaReturnStatement* self, ValaExpression* value);
 GType vala_return_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
