@@ -77,12 +77,13 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaSignal * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_signal_set_return_type (self, return_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -94,7 +95,7 @@ ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSo
  */
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	/* default C parameter position*/
 	vala_formal_parameter_set_cparameter_position (param, ((double) gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1));
 	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
@@ -118,7 +119,8 @@ GeeList* vala_signal_get_parameters (ValaSignal* self) {
 ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
 	ValaDelegate* _tmp3;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	if (self->priv->generated_delegate == NULL) {
+	/* parent_symbol is null for D-Bus signals*/
+	if (self->priv->generated_delegate == NULL && vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) != NULL) {
 		ValaDelegate* _tmp0;
 		ValaReferenceType* sender_type;
 		ValaFormalParameter* sender_param;
@@ -184,6 +186,7 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -227,7 +230,7 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_signal (visitor, self);
 }
@@ -236,7 +239,7 @@ static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_signal_get_return_type (self)), visitor);
 	{
 		GeeList* param_collection;
@@ -298,8 +301,8 @@ static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used) {
 static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_signal_get_return_type (self) == old_type) {
 		vala_signal_set_return_type (self, new_type);
 	}
