@@ -21,12 +21,15 @@
  */
 
 #include <vala/valasizeofexpression.h>
-#include <vala/valatypereference.h>
+#include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaSizeofExpressionPrivate {
-	ValaTypeReference* _type_reference;
+	ValaDataType* _data_type;
 };
 #define VALA_SIZEOF_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIZEOF_EXPRESSION, ValaSizeofExpressionPrivate))
 enum  {
@@ -34,10 +37,13 @@ enum  {
 	VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE
 };
 static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_sizeof_expression_real_is_pure (ValaExpression* base);
+static void vala_sizeof_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_sizeof_expression_parent_class = NULL;
 static void vala_sizeof_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new sizeof expression.
  *
@@ -45,22 +51,13 @@ static void vala_sizeof_expression_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created sizeof expression
  */
-ValaSizeofExpression* vala_sizeof_expression_new (ValaTypeReference* type, ValaSourceReference* source) {
-	GParameter * __params;
-	GParameter * __params_it;
+ValaSizeofExpression* vala_sizeof_expression_new (ValaDataType* type, ValaSourceReference* source) {
 	ValaSizeofExpression * self;
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	self = g_object_newv (VALA_TYPE_SIZEOF_EXPRESSION, __params_it - __params, __params);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
+	self = g_object_newv (VALA_TYPE_SIZEOF_EXPRESSION, 0, NULL);
+	vala_sizeof_expression_set_type_reference (self, type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
@@ -74,17 +71,38 @@ static void vala_sizeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisi
 }
 
 
-ValaTypeReference* vala_sizeof_expression_get_type_reference (ValaSizeofExpression* self) {
-	g_return_val_if_fail (VALA_IS_SIZEOF_EXPRESSION (self), NULL);
-	return self->priv->_type_reference;
+static gboolean vala_sizeof_expression_real_is_pure (ValaExpression* base) {
+	ValaSizeofExpression * self;
+	self = VALA_SIZEOF_EXPRESSION (base);
+	return TRUE;
 }
 
 
-void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, ValaTypeReference* value) {
-	ValaTypeReference* _tmp1;
+static void vala_sizeof_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaSizeofExpression * self;
+	self = VALA_SIZEOF_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_sizeof_expression_get_type_reference (self) == old_type) {
+		vala_sizeof_expression_set_type_reference (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_sizeof_expression_get_type_reference (ValaSizeofExpression* self) {
+	g_return_val_if_fail (VALA_IS_SIZEOF_EXPRESSION (self), NULL);
+	return self->priv->_data_type;
+}
+
+
+void vala_sizeof_expression_set_type_reference (ValaSizeofExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
@@ -123,7 +141,9 @@ static void vala_sizeof_expression_class_init (ValaSizeofExpressionClass * klass
 	G_OBJECT_CLASS (klass)->set_property = vala_sizeof_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_sizeof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_sizeof_expression_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_sizeof_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_sizeof_expression_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIZEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -135,7 +155,7 @@ static void vala_sizeof_expression_init (ValaSizeofExpression * self) {
 static void vala_sizeof_expression_dispose (GObject * obj) {
 	ValaSizeofExpression * self;
 	self = VALA_SIZEOF_EXPRESSION (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_sizeof_expression_parent_class)->dispose (obj);
 }
 
