@@ -45,7 +45,7 @@
 struct _ValaSourceFilePrivate {
 	char* _filename;
 	char* _comment;
-	gboolean _pkg;
+	gboolean _external_package;
 	ValaSourceFileCycle* _cycle;
 	gboolean _is_cycle_head;
 	gint _mark;
@@ -62,13 +62,14 @@ struct _ValaSourceFilePrivate {
 	GeeList* header_internal_full_dependencies;
 	GeeList* header_internal_dependencies;
 	GeeArrayList* source_array;
+	GMappedFile* mapped_file;
 };
 #define VALA_SOURCE_FILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SOURCE_FILE, ValaSourceFilePrivate))
 enum  {
 	VALA_SOURCE_FILE_DUMMY_PROPERTY,
 	VALA_SOURCE_FILE_FILENAME,
 	VALA_SOURCE_FILE_COMMENT,
-	VALA_SOURCE_FILE_PKG,
+	VALA_SOURCE_FILE_EXTERNAL_PACKAGE,
 	VALA_SOURCE_FILE_CYCLE,
 	VALA_SOURCE_FILE_IS_CYCLE_HEAD,
 	VALA_SOURCE_FILE_MARK,
@@ -93,11 +94,12 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* filename, gboolean pkg) {
 	ValaSourceFile * self;
-	g_return_val_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (filename != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_SOURCE_FILE, 0, NULL);
-	vala_source_file_set_context (self, context);
 	vala_source_file_set_filename (self, filename);
-	vala_source_file_set_pkg (self, pkg);
+	vala_source_file_set_external_package (self, pkg);
+	vala_source_file_set_context (self, context);
 	return self;
 }
 
@@ -109,7 +111,7 @@ ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* file
  */
 void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE_REFERENCE (ns));
+	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
 	gee_collection_add (GEE_COLLECTION (self->priv->using_directives), ns);
 }
 
@@ -132,11 +134,18 @@ GeeCollection* vala_source_file_get_using_directives (ValaSourceFile* self) {
  */
 void vala_source_file_add_node (ValaSourceFile* self, ValaCodeNode* node) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (node == NULL || VALA_IS_CODE_NODE (node));
+	g_return_if_fail (VALA_IS_CODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->nodes), node);
 }
 
 
+void vala_source_file_remove_node (ValaSourceFile* self, ValaCodeNode* node) {
+	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
+	g_return_if_fail (VALA_IS_CODE_NODE (node));
+	gee_collection_remove (GEE_COLLECTION (self->priv->nodes), node);
+}
+
+
 /**
  * Returns a copy of the list of code nodes.
  *
@@ -150,14 +159,14 @@ GeeCollection* vala_source_file_get_nodes (ValaSourceFile* self) {
 
 void vala_source_file_accept (ValaSourceFile* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_source_file (visitor, self);
 }
 
 
 void vala_source_file_accept_children (ValaSourceFile* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* ns_ref_collection;
 		GeeIterator* ns_ref_it;
@@ -325,7 +334,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 	ValaSymbol* s;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (sym == NULL || VALA_IS_SYMBOL (sym));
-	if (self->priv->_pkg) {
+	if (self->priv->_external_package) {
 		return;
 	}
 	s = NULL;
@@ -347,6 +356,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 			_tmp3 = NULL;
 			s = (_tmp4 = VALA_SYMBOL ((_tmp3 = vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (fp)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), _tmp4);
 			if (s == NULL) {
+				/* generic type parameter */
 				(fp == NULL ? NULL : (fp = (g_object_unref (fp), NULL)));
 				(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 				return;
@@ -357,9 +367,8 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 			return;
 		}
 	}
-	/* generic type parameter */
 	if (dep_type == VALA_SOURCE_FILE_DEPENDENCY_TYPE_SOURCE) {
-		if (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s)))->priv->_pkg) {
+		if (vala_symbol_get_external_package (s)) {
 			{
 				GeeCollection* fn_collection;
 				GeeIterator* fn_it;
@@ -397,7 +406,8 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 		(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 		return;
 	}
-	if (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (s)))->priv->_pkg) {
+	if (vala_symbol_get_external_package (s)) {
+		/* external package */
 		{
 			GeeCollection* fn_collection;
 			GeeIterator* fn_it;
@@ -407,7 +417,6 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
 				char* fn;
 				fn = ((char*) gee_iterator_get (fn_it));
 				{
-					/* external package */
 					gee_collection_add (GEE_COLLECTION (self->priv->header_external_includes), fn);
 					fn = (g_free (fn), NULL);
 				}
@@ -451,7 +460,7 @@ void vala_source_file_add_symbol_dependency (ValaSourceFile* self, ValaSymbol* s
  */
 void vala_source_file_add_type_dependency (ValaSourceFile* self, ValaDataType* type, ValaSourceFileDependencyType dep_type) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	{
 		GeeCollection* type_symbol_collection;
 		GeeIterator* type_symbol_it;
@@ -493,6 +502,7 @@ void vala_source_file_add_header_internal_include (ValaSourceFile* self, const c
 	char* _tmp0;
 	gboolean _tmp1;
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
+	g_return_if_fail (include != NULL);
 	/* skip includes to self */
 	_tmp0 = NULL;
 	if ((_tmp1 = _vala_strcmp0 (include, (_tmp0 = vala_source_file_get_cinclude_filename (self))) != 0, (_tmp0 = (g_free (_tmp0), NULL)), _tmp1)) {
@@ -605,14 +615,14 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 		_tmp2;
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
-				goto __catch0_g_file_error;
+				goto __catch3_g_file_error;
 			}
 			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 			g_clear_error (&inner_error);
 		}
 	}
-	goto __finally0;
-	__catch0_g_file_error:
+	goto __finally3;
+	__catch3_g_file_error:
 	{
 		GError * fe;
 		fe = inner_error;
@@ -622,7 +632,7 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 			return;
 		}
 	}
-	__finally0:
+	__finally3:
 	;
 	_tmp3 = NULL;
 	lines = (_tmp3 = g_strsplit (cont, "\n", 0), lines_length1 = -1, _tmp3);
@@ -635,6 +645,25 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 }
 
 
+gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self) {
+	GError * inner_error;
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
+	inner_error = NULL;
+	if (self->priv->mapped_file == NULL) {
+		GMappedFile* _tmp0;
+		_tmp0 = NULL;
+		self->priv->mapped_file = (_tmp0 = g_mapped_file_new (self->priv->_filename, FALSE, &inner_error), (self->priv->mapped_file == NULL ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL))), _tmp0);
+	}
+	return g_mapped_file_get_contents (self->priv->mapped_file);
+}
+
+
+gsize vala_source_file_get_mapped_length (ValaSourceFile* self) {
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), 0UL);
+	return ((gsize) g_mapped_file_get_length (self->priv->mapped_file));
+}
+
+
 char* vala_source_file_get_filename (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), NULL);
 	return self->priv->_filename;
@@ -667,15 +696,15 @@ void vala_source_file_set_comment (ValaSourceFile* self, const char* value) {
 }
 
 
-gboolean vala_source_file_get_pkg (ValaSourceFile* self) {
+gboolean vala_source_file_get_external_package (ValaSourceFile* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_FILE (self), FALSE);
-	return self->priv->_pkg;
+	return self->priv->_external_package;
 }
 
 
-void vala_source_file_set_pkg (ValaSourceFile* self, gboolean value) {
+void vala_source_file_set_external_package (ValaSourceFile* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
-	self->priv->_pkg = value;
+	self->priv->_external_package = value;
 }
 
 
@@ -741,8 +770,8 @@ static void vala_source_file_get_property (GObject * object, guint property_id,
 		case VALA_SOURCE_FILE_COMMENT:
 		g_value_set_string (value, vala_source_file_get_comment (self));
 		break;
-		case VALA_SOURCE_FILE_PKG:
-		g_value_set_boolean (value, vala_source_file_get_pkg (self));
+		case VALA_SOURCE_FILE_EXTERNAL_PACKAGE:
+		g_value_set_boolean (value, vala_source_file_get_external_package (self));
 		break;
 		case VALA_SOURCE_FILE_CYCLE:
 		g_value_set_object (value, vala_source_file_get_cycle (self));
@@ -773,8 +802,8 @@ static void vala_source_file_set_property (GObject * object, guint property_id,
 		case VALA_SOURCE_FILE_COMMENT:
 		vala_source_file_set_comment (self, g_value_get_string (value));
 		break;
-		case VALA_SOURCE_FILE_PKG:
-		vala_source_file_set_pkg (self, g_value_get_boolean (value));
+		case VALA_SOURCE_FILE_EXTERNAL_PACKAGE:
+		vala_source_file_set_external_package (self, g_value_get_boolean (value));
 		break;
 		case VALA_SOURCE_FILE_CYCLE:
 		vala_source_file_set_cycle (self, g_value_get_object (value));
@@ -803,7 +832,7 @@ static void vala_source_file_class_init (ValaSourceFileClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_source_file_dispose;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_FILENAME, g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_COMMENT, g_param_spec_string ("comment", "comment", "comment", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_PKG, g_param_spec_boolean ("pkg", "pkg", "pkg", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_EXTERNAL_PACKAGE, g_param_spec_boolean ("external-package", "external-package", "external-package", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_CYCLE, g_param_spec_object ("cycle", "cycle", "cycle", VALA_TYPE_SOURCE_FILE_CYCLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_IS_CYCLE_HEAD, g_param_spec_boolean ("is-cycle-head", "is-cycle-head", "is-cycle-head", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SOURCE_FILE_MARK, g_param_spec_int ("mark", "mark", "mark", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -825,6 +854,7 @@ static void vala_source_file_init (ValaSourceFile * self) {
 	self->priv->header_internal_full_dependencies = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, NULL, NULL, g_direct_equal));
 	self->priv->header_internal_dependencies = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, NULL, NULL, g_direct_equal));
 	self->priv->source_array = NULL;
+	self->priv->mapped_file = NULL;
 }
 
 
@@ -846,6 +876,7 @@ static void vala_source_file_dispose (GObject * obj) {
 	(self->priv->header_internal_full_dependencies == NULL ? NULL : (self->priv->header_internal_full_dependencies = (g_object_unref (self->priv->header_internal_full_dependencies), NULL)));
 	(self->priv->header_internal_dependencies == NULL ? NULL : (self->priv->header_internal_dependencies = (g_object_unref (self->priv->header_internal_dependencies), NULL)));
 	(self->priv->source_array == NULL ? NULL : (self->priv->source_array = (g_object_unref (self->priv->source_array), NULL)));
+	(self->priv->mapped_file == NULL ? NULL : (self->priv->mapped_file = (g_mapped_file_free (self->priv->mapped_file), NULL)));
 	G_OBJECT_CLASS (vala_source_file_parent_class)->dispose (obj);
 }
 
