@@ -1,6 +1,6 @@
 /* valasourcereference.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasourcefile.h>
 
+
+
+
 struct _ValaSourceReferencePrivate {
 	ValaSourceFile* _file;
 	gint _first_line;
@@ -45,6 +48,7 @@ static gpointer vala_source_reference_parent_class = NULL;
 static void vala_source_reference_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new source reference.
  *
@@ -57,7 +61,7 @@ static void vala_source_reference_dispose (GObject * obj);
  */
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column) {
 	ValaSourceReference * self;
-	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
 	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
@@ -81,7 +85,7 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
  */
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment) {
 	ValaSourceReference * self;
-	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
 	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
@@ -100,7 +104,7 @@ ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _fi
  */
 char* vala_source_reference_to_string (ValaSourceReference* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
-	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (vala_source_reference_get_file (self)), vala_source_reference_get_first_line (self), vala_source_reference_get_first_column (self), vala_source_reference_get_last_line (self), vala_source_reference_get_last_column (self)));
+	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column));
 }
 
 
