@@ -1,6 +1,6 @@
 /* valastringliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaStringLiteralPrivate {
 	char* _value;
 };
@@ -33,10 +36,12 @@ enum  {
 	VALA_STRING_LITERAL_VALUE
 };
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_string_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_string_literal_parent_class = NULL;
 static void vala_string_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new string literal.
  *
@@ -46,7 +51,8 @@ static void vala_string_literal_dispose (GObject * obj);
  */
 ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source) {
 	ValaStringLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (s != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_STRING_LITERAL, 0, NULL);
 	vala_string_literal_set_value (self, s);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -63,25 +69,32 @@ char* vala_string_literal_eval (ValaStringLiteral* self) {
 	char* noquotes;
 	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
-	if (vala_string_literal_get_value (self) == NULL) {
+	if (self->priv->_value == NULL) {
 		return NULL;
 	}
 	/* remove quotes */
-	noquotes = g_strndup (g_utf8_offset_to_pointer (vala_string_literal_get_value (self), ((glong) 1)), ((gulong) ((guint) (g_utf8_strlen (vala_string_literal_get_value (self), -1) - 2))));
+	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) 1)), ((gulong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2))));
+	/* unescape string */
 	_tmp1 = NULL;
 	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
 }
 
 
-/* unescape string */
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_string_literal (visitor, self);
 }
 
 
+static gboolean vala_string_literal_real_is_pure (ValaExpression* base) {
+	ValaStringLiteral * self;
+	self = VALA_STRING_LITERAL (base);
+	return TRUE;
+}
+
+
 char* vala_string_literal_get_value (ValaStringLiteral* self) {
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -133,6 +146,7 @@ static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_string_literal_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_string_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_string_literal_real_accept;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_string_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
