@@ -1,6 +1,6 @@
 /* valastringliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -46,11 +46,11 @@ typedef struct _ValaStringLiteralPrivate ValaStringLiteralPrivate;
  * Represents a string literal in the source code.
  */
 struct _ValaStringLiteral {
-	ValaLiteral parent;
+	ValaLiteral parent_instance;
 	ValaStringLiteralPrivate * priv;
 };
 struct _ValaStringLiteralClass {
-	ValaLiteralClass parent;
+	ValaLiteralClass parent_class;
 };
 
 ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source);
@@ -59,6 +59,7 @@ char* vala_string_literal_get_value (ValaStringLiteral* self);
 void vala_string_literal_set_value (ValaStringLiteral* self, const char* value);
 GType vala_string_literal_get_type (void);
 
+
 G_END_DECLS
 
 #endif
