@@ -35,13 +35,16 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valavaluetype.h>
 #include <vala/valavoidtype.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaStructPrivate {
 	GeeList* type_parameters;
 	GeeList* constants;
@@ -63,6 +66,7 @@ struct _ValaStructPrivate {
 	char* set_value_function;
 	char* default_value;
 	gboolean simple_type;
+	char* type_signature;
 	ValaMethod* _default_construction_method;
 };
 #define VALA_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT, ValaStructPrivate))
@@ -79,6 +83,7 @@ static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_struct_get_lower_case_csuffix (ValaStruct* self);
 static char* vala_struct_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static char* vala_struct_real_get_upper_case_cname (ValaTypesymbol* base, const char* infix);
+static char* vala_struct_real_get_type_signature (ValaTypesymbol* base);
 static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute* a);
 static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAttribute* a);
 static void vala_struct_process_floating_type_attribute (ValaStruct* self, ValaAttribute* a);
@@ -99,6 +104,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new struct.
  *
@@ -108,10 +114,11 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference) {
 	ValaStruct * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_STRUCT, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -123,7 +130,7 @@ ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_refer
  */
 void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_TYPESYMBOL (self);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
@@ -137,7 +144,7 @@ void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p) {
  */
 void vala_struct_add_constant (ValaStruct* self, ValaConstant* c) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	g_return_if_fail (VALA_IS_CONSTANT (c));
 	gee_collection_add (GEE_COLLECTION (self->priv->constants), c);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (c)), VALA_SYMBOL (c));
 }
@@ -150,7 +157,7 @@ void vala_struct_add_constant (ValaStruct* self, ValaConstant* c) {
  */
 void vala_struct_add_field (ValaStruct* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (f)), VALA_SYMBOL (f));
 }
@@ -176,7 +183,7 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
 	GeeCollection* _tmp2;
 	gboolean _tmp3;
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	g_return_if_fail (m != NULL);
 	if (vala_method_get_instance (m)) {
 		ValaFormalParameter* _tmp1;
@@ -190,14 +197,13 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
 	}
 	_tmp2 = NULL;
 	if ((_tmp3 = !(VALA_IS_VOID_TYPE (vala_method_get_return_type (m))) && gee_collection_get_size ((_tmp2 = vala_method_get_postconditions (m))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
-		ValaVariableDeclarator* _tmp4;
-		ValaDataType* _tmp5;
-		_tmp4 = NULL;
-		vala_method_set_result_var (m, (_tmp4 = vala_variable_declarator_new ("result", NULL, NULL)));
-		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+		ValaLocalVariable* _tmp5;
+		ValaDataType* _tmp4;
 		_tmp5 = NULL;
-		vala_variable_declarator_set_type_reference (vala_method_get_result_var (m), (_tmp5 = vala_data_type_copy (vala_method_get_return_type (m))));
+		_tmp4 = NULL;
+		vala_method_set_result_var (m, (_tmp5 = vala_local_variable_new ((_tmp4 = vala_data_type_copy (vala_method_get_return_type (m))), "result", NULL, NULL)));
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+		(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_result_var (m))), VALA_SYMBOL (vala_method_get_result_var (m)));
 	}
 	if (VALA_IS_CREATION_METHOD (m)) {
@@ -248,7 +254,7 @@ GeeCollection* vala_struct_get_methods (ValaStruct* self) {
 static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStruct * self;
 	self = VALA_STRUCT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_struct (visitor, self);
 }
 
@@ -256,7 +262,7 @@ static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStruct * self;
 	self = VALA_STRUCT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* type_collection;
 		GeeIterator* type_it;
@@ -361,6 +367,7 @@ static void vala_struct_set_cname (ValaStruct* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -371,6 +378,7 @@ static void vala_struct_set_const_cname (ValaStruct* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_STRUCT (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->const_cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->const_cname = (g_free (self->priv->const_cname), NULL)), _tmp1);
@@ -434,6 +442,15 @@ static char* vala_struct_real_get_upper_case_cname (ValaTypesymbol* base, const
 }
 
 
+static char* vala_struct_real_get_type_signature (ValaTypesymbol* base) {
+	ValaStruct * self;
+	const char* _tmp0;
+	self = VALA_STRUCT (base);
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->type_signature, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+}
+
+
 /**
  * Returns whether this is an integer type.
  *
@@ -469,7 +486,7 @@ gint vala_struct_get_rank (ValaStruct* self) {
 
 static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -540,12 +557,17 @@ static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute
 		vala_struct_set_default_value (self, (_tmp8 = vala_attribute_get_string (a, "default_value")));
 		_tmp8 = (g_free (_tmp8), NULL);
 	}
+	if (vala_attribute_has_argument (a, "type_signature")) {
+		char* _tmp9;
+		_tmp9 = NULL;
+		self->priv->type_signature = (_tmp9 = vala_attribute_get_string (a, "type_signature"), (self->priv->type_signature = (g_free (self->priv->type_signature), NULL)), _tmp9);
+	}
 }
 
 
 static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->integer_type = TRUE;
 	if (vala_attribute_has_argument (a, "rank")) {
 		self->priv->rank = vala_attribute_get_integer (a, "rank");
@@ -555,7 +577,7 @@ static void vala_struct_process_integer_type_attribute (ValaStruct* self, ValaAt
 
 static void vala_struct_process_floating_type_attribute (ValaStruct* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->floating_type = TRUE;
 	if (vala_attribute_has_argument (a, "rank")) {
 		self->priv->rank = vala_attribute_get_integer (a, "rank");
@@ -734,10 +756,40 @@ static void vala_struct_set_set_value_function (ValaStruct* self, const char* fu
 
 static char* vala_struct_real_get_default_value (ValaTypesymbol* base) {
 	ValaStruct * self;
-	const char* _tmp0;
 	self = VALA_STRUCT (base);
-	_tmp0 = NULL;
-	return (_tmp0 = self->priv->default_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	if (self->priv->default_value != NULL) {
+		const char* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = self->priv->default_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	}
+	/* inherit default value from base type*/
+	{
+		GeeList* type_collection;
+		GeeIterator* type_it;
+		type_collection = self->priv->base_types;
+		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+		while (gee_iterator_next (type_it)) {
+			ValaDataType* type;
+			type = ((ValaDataType*) gee_iterator_get (type_it));
+			{
+				ValaStruct* _tmp3;
+				ValaTypesymbol* _tmp2;
+				ValaStruct* st;
+				_tmp3 = NULL;
+				_tmp2 = NULL;
+				st = (_tmp3 = (_tmp2 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp2) ? ((ValaStruct*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+				if (st != NULL) {
+					char* _tmp4;
+					_tmp4 = NULL;
+					return (_tmp4 = vala_typesymbol_get_default_value (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp4);
+				}
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+			}
+		}
+		(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+	}
+	return NULL;
 }
 
 
@@ -758,7 +810,7 @@ static void vala_struct_set_default_value (ValaStruct* self, const char* value)
  */
 void vala_struct_add_base_type (ValaStruct* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	gee_collection_add (GEE_COLLECTION (self->priv->base_types), type);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (type), VALA_CODE_NODE (self));
 }
@@ -779,6 +831,7 @@ static gint vala_struct_real_get_type_parameter_index (ValaTypesymbol* base, con
 	ValaStruct * self;
 	gint i;
 	self = VALA_STRUCT (base);
+	g_return_val_if_fail (name != NULL, 0);
 	i = 0;
 	{
 		GeeList* p_collection;
@@ -851,12 +904,12 @@ void vala_struct_set_simple_type (ValaStruct* self, gboolean simple_type) {
 static void vala_struct_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaStruct * self;
 	self = VALA_STRUCT (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->base_types)); i++) {
+		for (; i < gee_collection_get_size (GEE_COLLECTION (self->priv->base_types)); i++) {
 			ValaDataType* _tmp0;
 			gboolean _tmp1;
 			_tmp0 = NULL;
@@ -925,6 +978,7 @@ static void vala_struct_class_init (ValaStructClass * klass) {
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_struct_real_get_lower_case_cprefix;
 	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_struct_real_get_lower_case_cname;
 	VALA_TYPESYMBOL_CLASS (klass)->get_upper_case_cname = vala_struct_real_get_upper_case_cname;
+	VALA_TYPESYMBOL_CLASS (klass)->get_type_signature = vala_struct_real_get_type_signature;
 	VALA_TYPESYMBOL_CLASS (klass)->get_type_id = vala_struct_real_get_type_id;
 	VALA_TYPESYMBOL_CLASS (klass)->get_marshaller_type_name = vala_struct_real_get_marshaller_type_name;
 	VALA_TYPESYMBOL_CLASS (klass)->get_get_value_function = vala_struct_real_get_get_value_function;
@@ -966,6 +1020,7 @@ static void vala_struct_dispose (GObject * obj) {
 	self->priv->get_value_function = (g_free (self->priv->get_value_function), NULL);
 	self->priv->set_value_function = (g_free (self->priv->set_value_function), NULL);
 	self->priv->default_value = (g_free (self->priv->default_value), NULL);
+	self->priv->type_signature = (g_free (self->priv->type_signature), NULL);
 	(self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL)));
 	G_OBJECT_CLASS (vala_struct_parent_class)->dispose (obj);
 }
