@@ -43,11 +43,11 @@ typedef struct _ValaSwitchLabelPrivate ValaSwitchLabelPrivate;
  * Represents a switch label in the source code.
  */
 struct _ValaSwitchLabel {
-	ValaCodeNode parent;
+	ValaCodeNode parent_instance;
 	ValaSwitchLabelPrivate * priv;
 };
 struct _ValaSwitchLabelClass {
-	ValaCodeNodeClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
 ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReference* source);
@@ -56,6 +56,7 @@ ValaExpression* vala_switch_label_get_expression (ValaSwitchLabel* self);
 void vala_switch_label_set_expression (ValaSwitchLabel* self, ValaExpression* value);
 GType vala_switch_label_get_type (void);
 
+
 G_END_DECLS
 
 #endif
