@@ -1,6 +1,6 @@
 /* valaswitchsection.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,13 +25,15 @@
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valaswitchlabel.h>
-#include <vala/valastatement.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valastatement.h>
+
+
+
 
 struct _ValaSwitchSectionPrivate {
 	GeeList* labels;
-	GeeList* statement_list;
 };
 #define VALA_SWITCH_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionPrivate))
 enum  {
@@ -43,6 +45,7 @@ static gpointer vala_switch_section_parent_class = NULL;
 static void vala_switch_section_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new switch section.
  *
@@ -51,7 +54,7 @@ static void vala_switch_section_dispose (GObject * obj);
  */
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference) {
 	ValaSwitchSection * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SWITCH_SECTION, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -90,7 +93,7 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
 		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = gee_iterator_get (label_it);
+			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
 			{
 				if (vala_switch_label_get_expression (label) == NULL) {
 					gboolean _tmp0;
@@ -105,29 +108,6 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 }
 
 
-/**
- * Appends the specified statement to this switch section.
- *
- * @param stmt a statement
- */
-void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt) {
-	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
-	g_return_if_fail (VALA_IS_STATEMENT (stmt));
-	gee_collection_add (GEE_COLLECTION (self->priv->statement_list), stmt);
-}
-
-
-/**
- * Returns a copy of the list of statements.
- *
- * @return statement list
- */
-GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self) {
-	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->statement_list)));
-}
-
-
 static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (base);
@@ -147,7 +127,7 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
 		while (gee_iterator_next (label_it)) {
 			ValaSwitchLabel* label;
-			label = gee_iterator_get (label_it);
+			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (label), visitor);
 				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
@@ -156,18 +136,19 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
 	{
-		GeeList* st_collection;
+		GeeCollection* st_collection;
 		GeeIterator* st_it;
-		st_collection = self->priv->statement_list;
+		st_collection = vala_block_get_statements (VALA_BLOCK (self));
 		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
 		while (gee_iterator_next (st_it)) {
 			ValaStatement* st;
-			st = gee_iterator_get (st_it);
+			st = ((ValaStatement*) gee_iterator_get (st_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
 				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 			}
 		}
+		(st_collection == NULL ? NULL : (st_collection = (g_object_unref (st_collection), NULL)));
 		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
 	}
 }
@@ -185,7 +166,6 @@ static void vala_switch_section_class_init (ValaSwitchSectionClass * klass) {
 static void vala_switch_section_init (ValaSwitchSection * self) {
 	self->priv = VALA_SWITCH_SECTION_GET_PRIVATE (self);
 	self->priv->labels = GEE_LIST (gee_array_list_new (VALA_TYPE_SWITCH_LABEL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
@@ -193,7 +173,6 @@ static void vala_switch_section_dispose (GObject * obj) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (obj);
 	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_object_unref (self->priv->labels), NULL)));
-	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
 	G_OBJECT_CLASS (vala_switch_section_parent_class)->dispose (obj);
 }
 
