@@ -24,6 +24,8 @@
 #include <gee/readonlycollection.h>
 #include <vala/valascope.h>
 #include <vala/valanamespace.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasourcefile.h>
 
 
 
@@ -32,9 +34,9 @@ struct _ValaSymbolPrivate {
 	char* _name;
 	gboolean _active;
 	ValaSymbolAccessibility _access;
-	gboolean _is_imported;
 	ValaScope* _owner;
 	ValaScope* _scope;
+	gboolean _external;
 };
 #define VALA_SYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SYMBOL, ValaSymbolPrivate))
 enum  {
@@ -45,7 +47,8 @@ enum  {
 	VALA_SYMBOL_ACTIVE,
 	VALA_SYMBOL_ACCESS,
 	VALA_SYMBOL_SCOPE,
-	VALA_SYMBOL_IS_IMPORTED
+	VALA_SYMBOL_EXTERNAL,
+	VALA_SYMBOL_EXTERNAL_PACKAGE
 };
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self);
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix);
@@ -65,20 +68,18 @@ static void vala_symbol_dispose (GObject * obj);
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	{
+		ValaSymbol* _tmp0;
 		ValaSymbol* sym;
-		ValaSymbol* _tmp3;
 		ValaSymbol* _tmp2;
 		ValaSymbol* _tmp1;
-		ValaSymbol* _tmp0;
-		sym = NULL;
-		_tmp3 = NULL;
+		_tmp0 = NULL;
+		sym = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		_tmp0 = NULL;
-		for (sym = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp1); NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3)) {
+		for (; NULL != sym; sym = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (sym), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp2)) {
 			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == sym->priv->_access) {
-				gboolean _tmp4;
-				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
+				gboolean _tmp3;
+				return (_tmp3 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3);
 			}
 		}
 		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
@@ -208,6 +209,7 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 	gboolean first;
 	const char* _tmp0;
 	char* _tmp1;
+	g_return_val_if_fail (camel_case != NULL, NULL);
 	result = g_string_new ("");
 	i = camel_case;
 	first = TRUE;
@@ -257,7 +259,6 @@ ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self) {
 		while (scope != NULL && VALA_IS_NAMESPACE (vala_scope_get_owner (scope)) && vala_scope_get_owner (scope)->priv->_name != NULL) {
 			ValaScope* _tmp2;
 			ValaScope* _tmp1;
-			/* skip scopes of normal namespaces, they don't influence accessibility*/
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			scope = (_tmp2 = (_tmp1 = vala_scope_get_parent_scope (scope), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp2);
@@ -267,10 +268,21 @@ ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self) {
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
 		return NULL;
 	}
+	/* if this is a public symbol, it's equally accessible as the parent symbol*/
 	return vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self));
 }
 
 
+/**
+ * Represents a node in the symbol tree.
+ */
+ValaSymbol* vala_symbol_new (void) {
+	ValaSymbol * self;
+	self = g_object_newv (VALA_TYPE_SYMBOL, 0, NULL);
+	return self;
+}
+
+
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_owner (self) == NULL) {
@@ -340,15 +352,21 @@ ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
 }
 
 
-gboolean vala_symbol_get_is_imported (ValaSymbol* self) {
+gboolean vala_symbol_get_external (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
-	return self->priv->_is_imported;
+	return self->priv->_external || (vala_symbol_get_parent_symbol (self) != NULL && vala_symbol_get_external (vala_symbol_get_parent_symbol (self))) || vala_symbol_get_external_package (self);
 }
 
 
-void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value) {
+void vala_symbol_set_external (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
-	self->priv->_is_imported = value;
+	self->priv->_external = value;
+}
+
+
+gboolean vala_symbol_get_external_package (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
+	return (vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && vala_source_file_get_external_package (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self)))));
 }
 
 
@@ -393,8 +411,11 @@ static void vala_symbol_get_property (GObject * object, guint property_id, GValu
 		case VALA_SYMBOL_SCOPE:
 		g_value_set_object (value, vala_symbol_get_scope (self));
 		break;
-		case VALA_SYMBOL_IS_IMPORTED:
-		g_value_set_boolean (value, vala_symbol_get_is_imported (self));
+		case VALA_SYMBOL_EXTERNAL:
+		g_value_set_boolean (value, vala_symbol_get_external (self));
+		break;
+		case VALA_SYMBOL_EXTERNAL_PACKAGE:
+		g_value_set_boolean (value, vala_symbol_get_external_package (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -419,8 +440,8 @@ static void vala_symbol_set_property (GObject * object, guint property_id, const
 		case VALA_SYMBOL_ACCESS:
 		vala_symbol_set_access (self, g_value_get_enum (value));
 		break;
-		case VALA_SYMBOL_IS_IMPORTED:
-		vala_symbol_set_is_imported (self, g_value_get_boolean (value));
+		case VALA_SYMBOL_EXTERNAL:
+		vala_symbol_set_external (self, g_value_get_boolean (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -446,7 +467,8 @@ static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_enum ("access", "access", "access", VALA_TYPE_SYMBOL_ACCESSIBILITY, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "scope", "scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_IS_IMPORTED, g_param_spec_boolean ("is-imported", "is-imported", "is-imported", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL, g_param_spec_boolean ("external", "external", "external", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL_PACKAGE, g_param_spec_boolean ("external-package", "external-package", "external-package", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
