@@ -36,11 +36,19 @@
 #include <vala/valavoidtype.h>
 #include <vala/valainvalidtype.h>
 #include <vala/valatypeparameter.h>
+#include <vala/valatypeparametertype.h>
 #include <vala/valadelegatetype.h>
-#include <vala/valapointertype.h>
-#include <vala/valaarraytype.h>
 #include <vala/valaerrortype.h>
 #include <vala/valaerrordomain.h>
+#include <vala/valaclasstype.h>
+#include <vala/valainterfacetype.h>
+#include <vala/valavaluetype.h>
+#include <vala/valapointertype.h>
+#include <vala/valaarraytype.h>
+#include <vala/valareferencetype.h>
+
+
+
 
 struct _ValaSymbolResolverPrivate {
 	ValaSymbol* root_symbol;
@@ -72,7 +80,7 @@ static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor
 static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self, ValaUnresolvedSymbol* unresolved_symbol);
 static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type);
 static void vala_symbol_resolver_real_visit_data_type (ValaCodeVisitor* base, ValaDataType* data_type);
-static void vala_symbol_resolver_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl);
+static void vala_symbol_resolver_real_visit_local_variable (ValaCodeVisitor* base, ValaLocalVariable* local);
 static void vala_symbol_resolver_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list);
 static void vala_symbol_resolver_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt);
 static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section);
@@ -95,6 +103,7 @@ static void vala_symbol_resolver_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Resolve symbol names in the specified code context.
  *
@@ -106,7 +115,7 @@ void vala_symbol_resolver_resolve (ValaSymbolResolver* self, ValaCodeContext* co
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	g_return_if_fail (VALA_IS_SYMBOL_RESOLVER (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->root_symbol = (_tmp1 = VALA_SYMBOL ((_tmp0 = vala_code_context_get_root (context), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)))), (self->priv->root_symbol == NULL ? NULL : (self->priv->root_symbol = (g_object_unref (self->priv->root_symbol), NULL))), _tmp1);
@@ -124,7 +133,7 @@ static void vala_symbol_resolver_real_visit_source_file (ValaCodeVisitor* base,
 	ValaScope* _tmp1;
 	GeeCollection* _tmp3;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (file == NULL || VALA_IS_SOURCE_FILE (file));
+	g_return_if_fail (VALA_IS_SOURCE_FILE (file));
 	_tmp0 = NULL;
 	self->priv->current_using_directives = (_tmp0 = vala_source_file_get_using_directives (file), (self->priv->current_using_directives == NULL ? NULL : (self->priv->current_using_directives = (g_object_unref (self->priv->current_using_directives), NULL))), _tmp0);
 	_tmp2 = NULL;
@@ -143,7 +152,7 @@ static void vala_symbol_resolver_real_visit_class (ValaCodeVisitor* base, ValaCl
 	ValaScope* _tmp10;
 	ValaScope* _tmp9;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (cl)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -216,7 +225,7 @@ static void vala_symbol_resolver_real_visit_struct (ValaCodeVisitor* base, ValaS
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (st)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -234,7 +243,7 @@ static void vala_symbol_resolver_real_visit_interface (ValaCodeVisitor* base, Va
 	ValaScope* _tmp6;
 	ValaScope* _tmp5;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (iface)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -284,7 +293,7 @@ static void vala_symbol_resolver_real_visit_enum (ValaCodeVisitor* base, ValaEnu
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	g_return_if_fail (VALA_IS_ENUM (en));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (en)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -302,7 +311,7 @@ static void vala_symbol_resolver_real_visit_delegate (ValaCodeVisitor* base, Val
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (cb == NULL || VALA_IS_DELEGATE (cb));
+	g_return_if_fail (VALA_IS_DELEGATE (cb));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (cb)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -318,7 +327,7 @@ static void vala_symbol_resolver_real_visit_constant (ValaCodeVisitor* base, Val
 	ValaScope* _tmp1;
 	ValaScope* _tmp0;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	g_return_if_fail (VALA_IS_CONSTANT (c));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (c)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -333,7 +342,7 @@ static void vala_symbol_resolver_real_visit_field (ValaCodeVisitor* base, ValaFi
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (f)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -351,7 +360,7 @@ static void vala_symbol_resolver_real_visit_method (ValaCodeVisitor* base, ValaM
 	ValaScope* _tmp3;
 	ValaScope* _tmp2;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (m)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
@@ -365,7 +374,7 @@ static void vala_symbol_resolver_real_visit_method (ValaCodeVisitor* base, ValaM
 static void vala_symbol_resolver_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 }
 
@@ -373,7 +382,7 @@ static void vala_symbol_resolver_real_visit_creation_method (ValaCodeVisitor* ba
 static void vala_symbol_resolver_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (p == NULL || VALA_IS_FORMAL_PARAMETER (p));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (p));
 	vala_code_node_accept_children (VALA_CODE_NODE (p), VALA_CODE_VISITOR (self));
 }
 
@@ -381,7 +390,7 @@ static void vala_symbol_resolver_real_visit_formal_parameter (ValaCodeVisitor* b
 static void vala_symbol_resolver_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	vala_code_node_accept_children (VALA_CODE_NODE (prop), VALA_CODE_VISITOR (self));
 }
 
@@ -389,7 +398,7 @@ static void vala_symbol_resolver_real_visit_property (ValaCodeVisitor* base, Val
 static void vala_symbol_resolver_real_visit_property_accessor (ValaCodeVisitor* base, ValaPropertyAccessor* acc) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (acc == NULL || VALA_IS_PROPERTY_ACCESSOR (acc));
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
 	vala_code_node_accept_children (VALA_CODE_NODE (acc), VALA_CODE_VISITOR (self));
 }
 
@@ -397,7 +406,7 @@ static void vala_symbol_resolver_real_visit_property_accessor (ValaCodeVisitor*
 static void vala_symbol_resolver_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	vala_code_node_accept_children (VALA_CODE_NODE (sig), VALA_CODE_VISITOR (self));
 }
 
@@ -405,7 +414,7 @@ static void vala_symbol_resolver_real_visit_signal (ValaCodeVisitor* base, ValaS
 static void vala_symbol_resolver_real_visit_constructor (ValaCodeVisitor* base, ValaConstructor* c) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTRUCTOR (c));
+	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
 	vala_code_node_accept_children (VALA_CODE_NODE (c), VALA_CODE_VISITOR (self));
 }
 
@@ -413,7 +422,7 @@ static void vala_symbol_resolver_real_visit_constructor (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_destructor (ValaCodeVisitor* base, ValaDestructor* d) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (d == NULL || VALA_IS_DESTRUCTOR (d));
+	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
 	vala_code_node_accept_children (VALA_CODE_NODE (d), VALA_CODE_VISITOR (self));
 }
 
@@ -421,7 +430,7 @@ static void vala_symbol_resolver_real_visit_destructor (ValaCodeVisitor* base, V
 static void vala_symbol_resolver_real_visit_block (ValaCodeVisitor* base, ValaBlock* b) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (b == NULL || VALA_IS_BLOCK (b));
+	g_return_if_fail (VALA_IS_BLOCK (b));
 	vala_code_node_accept_children (VALA_CODE_NODE (b), VALA_CODE_VISITOR (self));
 }
 
@@ -430,7 +439,7 @@ static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor
 	ValaSymbolResolver * self;
 	ValaSymbol* _tmp0;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE_REFERENCE (ns));
+	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
 	_tmp0 = NULL;
 	vala_namespace_reference_set_namespace_symbol (ns, (_tmp0 = vala_scope_lookup (self->priv->current_scope, vala_namespace_reference_get_name (ns))));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
@@ -447,7 +456,7 @@ static void vala_symbol_resolver_real_visit_namespace_reference (ValaCodeVisitor
 
 static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self, ValaUnresolvedSymbol* unresolved_symbol) {
 	g_return_val_if_fail (VALA_IS_SYMBOL_RESOLVER (self), NULL);
-	g_return_val_if_fail (unresolved_symbol == NULL || VALA_IS_UNRESOLVED_SYMBOL (unresolved_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_UNRESOLVED_SYMBOL (unresolved_symbol), NULL);
 	if (vala_unresolved_symbol_get_inner (unresolved_symbol) == NULL) {
 		ValaSymbol* sym;
 		ValaScope* _tmp0;
@@ -535,17 +544,113 @@ static ValaSymbol* vala_symbol_resolver_resolve_symbol (ValaSymbolResolver* self
 static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self, ValaUnresolvedType* unresolved_type) {
 	ValaDataType* type;
 	ValaSymbol* sym;
-	ValaDataType* _tmp11;
+	ValaDataType* _tmp23;
 	g_return_val_if_fail (VALA_IS_SYMBOL_RESOLVER (self), NULL);
-	g_return_val_if_fail (unresolved_type == NULL || VALA_IS_UNRESOLVED_TYPE (unresolved_type), NULL);
-	type = vala_data_type_new ();
+	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (unresolved_type), NULL);
+	type = NULL;
+	/* still required for vapigen*/
+	if (_vala_strcmp0 (vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (unresolved_type)), "void") == 0) {
+		ValaVoidType* _tmp0;
+		_tmp0 = NULL;
+		return VALA_DATA_TYPE ((_tmp0 = vala_void_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp0));
+	}
+	sym = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_type_get_unresolved_symbol (unresolved_type));
+	if (sym == NULL) {
+		ValaInvalidType* _tmp3;
+		/* don't report same error twice*/
+		if (!vala_code_node_get_error (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))) {
+			char* _tmp2;
+			char* _tmp1;
+			_tmp2 = NULL;
+			_tmp1 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp2 = g_strdup_printf ("The type name `%s' could not be found", (_tmp1 = vala_code_node_to_string (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))))));
+			_tmp2 = (g_free (_tmp2), NULL);
+			_tmp1 = (g_free (_tmp1), NULL);
+		}
+		_tmp3 = NULL;
+		return VALA_DATA_TYPE ((_tmp3 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3));
+	}
+	if (VALA_IS_TYPEPARAMETER (sym)) {
+		ValaDataType* _tmp4;
+		_tmp4 = NULL;
+		type = (_tmp4 = VALA_DATA_TYPE (vala_typeparameter_type_new (VALA_TYPEPARAMETER (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp4);
+	} else {
+		if (VALA_IS_TYPESYMBOL (sym)) {
+			if (VALA_IS_DELEGATE (sym)) {
+				ValaDataType* _tmp5;
+				_tmp5 = NULL;
+				type = (_tmp5 = VALA_DATA_TYPE (vala_delegate_type_new (VALA_DELEGATE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp5);
+			} else {
+				if (VALA_IS_CLASS (sym)) {
+					ValaClass* _tmp6;
+					ValaClass* cl;
+					_tmp6 = NULL;
+					cl = (_tmp6 = VALA_CLASS (sym), (_tmp6 == NULL ? NULL : g_object_ref (_tmp6)));
+					if (vala_class_get_is_error_base (cl)) {
+						ValaDataType* _tmp7;
+						_tmp7 = NULL;
+						type = (_tmp7 = VALA_DATA_TYPE (vala_error_type_new (NULL, vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp7);
+					} else {
+						ValaDataType* _tmp8;
+						_tmp8 = NULL;
+						type = (_tmp8 = VALA_DATA_TYPE (vala_class_type_new (cl)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp8);
+					}
+					(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+				} else {
+					if (VALA_IS_INTERFACE (sym)) {
+						ValaDataType* _tmp9;
+						_tmp9 = NULL;
+						type = (_tmp9 = VALA_DATA_TYPE (vala_interface_type_new (VALA_INTERFACE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9);
+					} else {
+						if (VALA_IS_STRUCT (sym)) {
+							ValaDataType* _tmp10;
+							_tmp10 = NULL;
+							type = (_tmp10 = VALA_DATA_TYPE (vala_value_type_new (VALA_TYPESYMBOL (VALA_STRUCT (sym)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp10);
+						} else {
+							if (VALA_IS_ENUM (sym)) {
+								ValaDataType* _tmp11;
+								_tmp11 = NULL;
+								type = (_tmp11 = VALA_DATA_TYPE (vala_value_type_new (VALA_TYPESYMBOL (VALA_ENUM (sym)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp11);
+							} else {
+								if (VALA_IS_ERROR_DOMAIN (sym)) {
+									ValaDataType* _tmp12;
+									_tmp12 = NULL;
+									type = (_tmp12 = VALA_DATA_TYPE (vala_error_type_new (VALA_ERROR_DOMAIN (sym), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp12);
+								} else {
+									char* _tmp14;
+									char* _tmp13;
+									ValaInvalidType* _tmp15;
+									_tmp14 = NULL;
+									_tmp13 = NULL;
+									vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp14 = g_strdup_printf ("internal error: `%s' is not a supported type", (_tmp13 = vala_symbol_get_full_name (sym)))));
+									_tmp14 = (g_free (_tmp14), NULL);
+									_tmp13 = (g_free (_tmp13), NULL);
+									_tmp15 = NULL;
+									return VALA_DATA_TYPE ((_tmp15 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp15));
+								}
+							}
+						}
+					}
+				}
+			}
+		} else {
+			char* _tmp17;
+			char* _tmp16;
+			ValaInvalidType* _tmp18;
+			_tmp17 = NULL;
+			_tmp16 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)), (_tmp17 = g_strdup_printf ("`%s' is not a type", (_tmp16 = vala_symbol_get_full_name (sym)))));
+			_tmp17 = (g_free (_tmp17), NULL);
+			_tmp16 = (g_free (_tmp16), NULL);
+			_tmp18 = NULL;
+			return VALA_DATA_TYPE ((_tmp18 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp18));
+		}
+	}
 	vala_code_node_set_source_reference (VALA_CODE_NODE (type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)));
 	vala_data_type_set_takes_ownership (type, vala_data_type_get_takes_ownership (VALA_DATA_TYPE (unresolved_type)));
 	vala_data_type_set_transfers_ownership (type, vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (unresolved_type)));
-	vala_data_type_set_is_ref (type, vala_data_type_get_is_ref (VALA_DATA_TYPE (unresolved_type)));
-	vala_data_type_set_is_out (type, vala_data_type_get_is_out (VALA_DATA_TYPE (unresolved_type)));
 	vala_data_type_set_nullable (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
-	vala_data_type_set_requires_null_check (type, vala_data_type_get_requires_null_check (VALA_DATA_TYPE (unresolved_type)));
+	vala_data_type_set_is_dynamic (type, vala_data_type_get_is_dynamic (VALA_DATA_TYPE (unresolved_type)));
 	{
 		GeeList* type_arg_collection;
 		GeeIterator* type_arg_it;
@@ -562,123 +667,51 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 		(type_arg_collection == NULL ? NULL : (type_arg_collection = (g_object_unref (type_arg_collection), NULL)));
 		(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
 	}
-	/* still required for vapigen*/
-	if (_vala_strcmp0 (vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (unresolved_type)), "void") == 0) {
-		ValaVoidType* _tmp0;
-		_tmp0 = NULL;
-		return VALA_DATA_TYPE ((_tmp0 = vala_void_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp0));
-	}
-	sym = vala_symbol_resolver_resolve_symbol (self, vala_unresolved_type_get_unresolved_symbol (unresolved_type));
-	if (sym == NULL) {
-		ValaInvalidType* _tmp3;
-		/* don't report same error twice*/
-		if (!vala_code_node_get_error (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))) {
-			char* _tmp2;
-			char* _tmp1;
-			_tmp2 = NULL;
-			_tmp1 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp2 = g_strdup_printf ("The type name `%s' could not be found", (_tmp1 = vala_code_node_to_string (VALA_CODE_NODE (vala_unresolved_type_get_unresolved_symbol (unresolved_type)))))));
-			_tmp2 = (g_free (_tmp2), NULL);
-			_tmp1 = (g_free (_tmp1), NULL);
-		}
-		_tmp3 = NULL;
-		return VALA_DATA_TYPE ((_tmp3 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3));
-	}
-	if (VALA_IS_TYPEPARAMETER (sym)) {
-		vala_data_type_set_type_parameter (type, VALA_TYPEPARAMETER (sym));
-	} else {
-		if (VALA_IS_TYPESYMBOL (sym)) {
-			if (VALA_IS_DELEGATE (sym)) {
-				ValaDataType* _tmp4;
-				_tmp4 = NULL;
-				type = (_tmp4 = VALA_DATA_TYPE (vala_delegate_type_new (VALA_DELEGATE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp4);
-			} else {
-				vala_data_type_set_data_type (type, VALA_TYPESYMBOL (sym));
-			}
-		} else {
-			char* _tmp6;
-			char* _tmp5;
-			ValaInvalidType* _tmp7;
-			_tmp6 = NULL;
-			_tmp5 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (type)), (_tmp6 = g_strdup_printf ("`%s' is not a type", (_tmp5 = vala_symbol_get_full_name (sym)))));
-			_tmp6 = (g_free (_tmp6), NULL);
-			_tmp5 = (g_free (_tmp5), NULL);
-			_tmp7 = NULL;
-			return VALA_DATA_TYPE ((_tmp7 = vala_invalid_type_new (), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp7));
-		}
-	}
 	{
 		gint pointer_level;
-		pointer_level = 0;
-		for (pointer_level = vala_unresolved_type_get_pointer_level (unresolved_type); pointer_level > 0; pointer_level--) {
-			ValaDataType* _tmp8;
-			_tmp8 = NULL;
-			type = (_tmp8 = VALA_DATA_TYPE (vala_pointer_type_new (type)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp8);
+		pointer_level = vala_unresolved_type_get_pointer_level (unresolved_type);
+		for (; pointer_level > 0; pointer_level--) {
+			ValaDataType* _tmp19;
+			ValaDataType* base_type;
+			ValaDataType* _tmp20;
+			_tmp19 = NULL;
+			base_type = (_tmp19 = type, (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
+			vala_data_type_set_takes_ownership (base_type, FALSE);
+			vala_data_type_set_transfers_ownership (base_type, FALSE);
+			vala_data_type_set_nullable (base_type, FALSE);
+			vala_data_type_set_is_dynamic (base_type, FALSE);
+			_tmp20 = NULL;
+			type = (_tmp20 = VALA_DATA_TYPE (vala_pointer_type_new (base_type)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp20);
+			(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
 		}
 	}
-	/* check for array */
-	if (vala_unresolved_type_get_array_rank (unresolved_type) > 0) {
-		ValaDataType* element_type;
-		ValaDataType* _tmp9;
-		element_type = vala_data_type_new ();
-		vala_data_type_set_data_type (element_type, vala_data_type_get_data_type (type));
-		vala_data_type_set_type_parameter (element_type, vala_data_type_get_type_parameter (type));
-		{
-			GeeList* type_arg_collection;
-			GeeIterator* type_arg_it;
-			type_arg_collection = vala_data_type_get_type_arguments (type);
-			type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
-			while (gee_iterator_next (type_arg_it)) {
-				ValaDataType* type_arg;
-				type_arg = ((ValaDataType*) gee_iterator_get (type_arg_it));
-				{
-					vala_data_type_add_type_argument (element_type, type_arg);
-					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
-				}
-			}
-			(type_arg_collection == NULL ? NULL : (type_arg_collection = (g_object_unref (type_arg_collection), NULL)));
-			(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
-		}
-		if (vala_data_type_get_data_type (type) != NULL) {
-			if (vala_typesymbol_is_reference_type (vala_data_type_get_data_type (type))) {
-				vala_data_type_set_takes_ownership (element_type, vala_data_type_get_takes_ownership (type));
-			}
-		} else {
-			vala_data_type_set_takes_ownership (element_type, vala_data_type_get_takes_ownership (type));
-		}
-		_tmp9 = NULL;
-		type = (_tmp9 = VALA_DATA_TYPE (vala_array_type_new (element_type, vala_unresolved_type_get_array_rank (unresolved_type))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9);
-		vala_data_type_add_type_argument (type, element_type);
-		vala_code_node_set_source_reference (VALA_CODE_NODE (type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)));
-		vala_data_type_set_takes_ownership (type, vala_data_type_get_takes_ownership (VALA_DATA_TYPE (unresolved_type)));
-		vala_data_type_set_transfers_ownership (type, vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (unresolved_type)));
-		vala_data_type_set_is_ref (type, vala_data_type_get_is_ref (VALA_DATA_TYPE (unresolved_type)));
-		vala_data_type_set_is_out (type, vala_data_type_get_is_out (VALA_DATA_TYPE (unresolved_type)));
-		vala_data_type_set_nullable (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
-		vala_data_type_set_requires_null_check (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
-		(element_type == NULL ? NULL : (element_type = (g_object_unref (element_type), NULL)));
-	}
-	if (vala_data_type_get_data_type (type) != NULL && !vala_typesymbol_is_reference_type (vala_data_type_get_data_type (type))) {
+	if (!vala_data_type_is_reference_type_or_type_parameter (type)) {
 		/* reset takes_ownership and transfers_ownership of
 		 * value-types for contexts where types are ref by
 		 * default (field declarations and method return types)
 		 */
 		vala_data_type_set_takes_ownership (type, FALSE);
 		vala_data_type_set_transfers_ownership (type, FALSE);
-		/* reset nullable of value-types for local variables */
-		if (vala_data_type_get_nullable (type) && !vala_data_type_get_requires_null_check (type)) {
-			vala_data_type_set_nullable (type, FALSE);
-		}
 	}
-	/* check whether this type resolved to a ErrorBase class */
-	if (VALA_IS_CLASS (vala_data_type_get_data_type (type)) && vala_class_get_is_error_base ((VALA_CLASS (vala_data_type_get_data_type (type))))) {
-		ValaDataType* _tmp10;
-		_tmp10 = NULL;
-		type = (_tmp10 = VALA_DATA_TYPE (vala_error_type_new (NULL)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp10);
+	/* check for array */
+	if (vala_unresolved_type_get_array_rank (unresolved_type) > 0) {
+		ValaDataType* _tmp21;
+		ValaDataType* element_type;
+		ValaDataType* _tmp22;
+		_tmp21 = NULL;
+		element_type = (_tmp21 = type, (_tmp21 == NULL ? NULL : g_object_ref (_tmp21)));
+		vala_data_type_set_transfers_ownership (element_type, FALSE);
+		vala_data_type_set_nullable (element_type, FALSE);
+		_tmp22 = NULL;
+		type = (_tmp22 = VALA_DATA_TYPE (vala_array_type_new (element_type, vala_unresolved_type_get_array_rank (unresolved_type), vala_code_node_get_source_reference (VALA_CODE_NODE (unresolved_type)))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp22);
+		vala_data_type_add_type_argument (type, element_type);
+		vala_data_type_set_takes_ownership (type, vala_data_type_get_takes_ownership (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_transfers_ownership (type, vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (unresolved_type)));
+		vala_data_type_set_nullable (type, vala_data_type_get_nullable (VALA_DATA_TYPE (unresolved_type)));
+		(element_type == NULL ? NULL : (element_type = (g_object_unref (element_type), NULL)));
 	}
-	_tmp11 = NULL;
-	return (_tmp11 = type, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp11);
+	_tmp23 = NULL;
+	return (_tmp23 = type, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp23);
 }
 
 
@@ -688,7 +721,7 @@ static void vala_symbol_resolver_real_visit_data_type (ValaCodeVisitor* base, Va
 	ValaUnresolvedType* unresolved_type;
 	ValaDataType* _tmp1;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (data_type == NULL || VALA_IS_DATA_TYPE (data_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (data_type));
 	if (!(VALA_IS_UNRESOLVED_TYPE (data_type))) {
 		return;
 	}
@@ -701,18 +734,21 @@ static void vala_symbol_resolver_real_visit_data_type (ValaCodeVisitor* base, Va
 }
 
 
-static void vala_symbol_resolver_real_visit_variable_declarator (ValaCodeVisitor* base, ValaVariableDeclarator* decl) {
+static void vala_symbol_resolver_real_visit_local_variable (ValaCodeVisitor* base, ValaLocalVariable* local) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (decl == NULL || VALA_IS_VARIABLE_DECLARATOR (decl));
-	vala_code_node_accept_children (VALA_CODE_NODE (decl), VALA_CODE_VISITOR (self));
+	g_return_if_fail (VALA_IS_LOCAL_VARIABLE (local));
+	vala_code_node_accept_children (VALA_CODE_NODE (local), VALA_CODE_VISITOR (self));
+	if (VALA_IS_REFERENCE_TYPE (vala_local_variable_get_variable_type (local))) {
+		vala_data_type_set_nullable (vala_local_variable_get_variable_type (local), TRUE);
+	}
 }
 
 
 static void vala_symbol_resolver_real_visit_initializer_list (ValaCodeVisitor* base, ValaInitializerList* list) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (list == NULL || VALA_IS_INITIALIZER_LIST (list));
+	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
 	vala_code_node_accept_children (VALA_CODE_NODE (list), VALA_CODE_VISITOR (self));
 }
 
@@ -720,7 +756,7 @@ static void vala_symbol_resolver_real_visit_initializer_list (ValaCodeVisitor* b
 static void vala_symbol_resolver_real_visit_if_statement (ValaCodeVisitor* base, ValaIfStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_IF_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_IF_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -728,7 +764,7 @@ static void vala_symbol_resolver_real_visit_if_statement (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* base, ValaSwitchSection* section) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (section == NULL || VALA_IS_SWITCH_SECTION (section));
+	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
 	vala_code_node_accept_children (VALA_CODE_NODE (section), VALA_CODE_VISITOR (self));
 }
 
@@ -736,7 +772,7 @@ static void vala_symbol_resolver_real_visit_switch_section (ValaCodeVisitor* bas
 static void vala_symbol_resolver_real_visit_while_statement (ValaCodeVisitor* base, ValaWhileStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_WHILE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_WHILE_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -744,7 +780,7 @@ static void vala_symbol_resolver_real_visit_while_statement (ValaCodeVisitor* ba
 static void vala_symbol_resolver_real_visit_do_statement (ValaCodeVisitor* base, ValaDoStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_DO_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_DO_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -752,7 +788,7 @@ static void vala_symbol_resolver_real_visit_do_statement (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_for_statement (ValaCodeVisitor* base, ValaForStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_FOR_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOR_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -760,7 +796,7 @@ static void vala_symbol_resolver_real_visit_for_statement (ValaCodeVisitor* base
 static void vala_symbol_resolver_real_visit_foreach_statement (ValaCodeVisitor* base, ValaForeachStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_FOREACH_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -768,7 +804,7 @@ static void vala_symbol_resolver_real_visit_foreach_statement (ValaCodeVisitor*
 static void vala_symbol_resolver_real_visit_return_statement (ValaCodeVisitor* base, ValaReturnStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_RETURN_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_RETURN_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -776,7 +812,7 @@ static void vala_symbol_resolver_real_visit_return_statement (ValaCodeVisitor* b
 static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* base, ValaThrowStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_THROW_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -784,7 +820,7 @@ static void vala_symbol_resolver_real_visit_throw_statement (ValaCodeVisitor* ba
 static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base, ValaTryStatement* stmt) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (stmt == NULL || VALA_IS_TRY_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
 	vala_code_node_accept_children (VALA_CODE_NODE (stmt), VALA_CODE_VISITOR (self));
 }
 
@@ -792,7 +828,7 @@ static void vala_symbol_resolver_real_visit_try_statement (ValaCodeVisitor* base
 static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base, ValaCatchClause* clause) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (clause == NULL || VALA_IS_CATCH_CLAUSE (clause));
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
 	vala_code_node_accept_children (VALA_CODE_NODE (clause), VALA_CODE_VISITOR (self));
 }
 
@@ -800,7 +836,7 @@ static void vala_symbol_resolver_real_visit_catch_clause (ValaCodeVisitor* base,
 static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeVisitor* base, ValaArrayCreationExpression* e) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (e == NULL || VALA_IS_ARRAY_CREATION_EXPRESSION (e));
+	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (e));
 	vala_code_node_accept_children (VALA_CODE_NODE (e), VALA_CODE_VISITOR (self));
 }
 
@@ -808,7 +844,7 @@ static void vala_symbol_resolver_real_visit_array_creation_expression (ValaCodeV
 static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVisitor* base, ValaParenthesizedExpression* expr) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_PARENTHESIZED_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 }
 
@@ -816,7 +852,7 @@ static void vala_symbol_resolver_real_visit_parenthesized_expression (ValaCodeVi
 static void vala_symbol_resolver_real_visit_invocation_expression (ValaCodeVisitor* base, ValaInvocationExpression* expr) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_INVOCATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 }
 
@@ -824,7 +860,7 @@ static void vala_symbol_resolver_real_visit_invocation_expression (ValaCodeVisit
 static void vala_symbol_resolver_real_visit_object_creation_expression (ValaCodeVisitor* base, ValaObjectCreationExpression* expr) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (expr == NULL || VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
 	vala_code_node_accept_children (VALA_CODE_NODE (expr), VALA_CODE_VISITOR (self));
 }
 
@@ -832,7 +868,7 @@ static void vala_symbol_resolver_real_visit_object_creation_expression (ValaCode
 static void vala_symbol_resolver_real_visit_lambda_expression (ValaCodeVisitor* base, ValaLambdaExpression* l) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (l == NULL || VALA_IS_LAMBDA_EXPRESSION (l));
+	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (l));
 	vala_code_node_accept_children (VALA_CODE_NODE (l), VALA_CODE_VISITOR (self));
 }
 
@@ -840,7 +876,7 @@ static void vala_symbol_resolver_real_visit_lambda_expression (ValaCodeVisitor*
 static void vala_symbol_resolver_real_visit_assignment (ValaCodeVisitor* base, ValaAssignment* a) {
 	ValaSymbolResolver * self;
 	self = VALA_SYMBOL_RESOLVER (base);
-	g_return_if_fail (a == NULL || VALA_IS_ASSIGNMENT (a));
+	g_return_if_fail (VALA_IS_ASSIGNMENT (a));
 	vala_code_node_accept_children (VALA_CODE_NODE (a), VALA_CODE_VISITOR (self));
 }
 
@@ -878,7 +914,7 @@ static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_block = vala_symbol_resolver_real_visit_block;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_namespace_reference = vala_symbol_resolver_real_visit_namespace_reference;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_data_type = vala_symbol_resolver_real_visit_data_type;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_symbol_resolver_real_visit_variable_declarator;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_local_variable = vala_symbol_resolver_real_visit_local_variable;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_symbol_resolver_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_symbol_resolver_real_visit_if_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_switch_section = vala_symbol_resolver_real_visit_switch_section;
