@@ -1,6 +1,6 @@
 /* valasymbolresolver.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,7 +33,7 @@
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
-#include <vala/valacallback.h>
+#include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
 #include <vala/valamethod.h>
@@ -46,16 +46,21 @@
 #include <vala/valadestructor.h>
 #include <vala/valablock.h>
 #include <vala/valanamespacereference.h>
-#include <vala/valatypereference.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valadatatype.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
+#include <vala/valaifstatement.h>
 #include <vala/valaswitchsection.h>
+#include <vala/valawhilestatement.h>
+#include <vala/valadostatement.h>
+#include <vala/valaforstatement.h>
 #include <vala/valaforeachstatement.h>
 #include <vala/valareturnstatement.h>
 #include <vala/valathrowstatement.h>
 #include <vala/valatrystatement.h>
 #include <vala/valacatchclause.h>
 #include <vala/valaarraycreationexpression.h>
+#include <vala/valaparenthesizedexpression.h>
 #include <vala/valainvocationexpression.h>
 #include <vala/valaobjectcreationexpression.h>
 #include <vala/valalambdaexpression.h>
@@ -79,17 +84,18 @@ typedef struct _ValaSymbolResolverPrivate ValaSymbolResolverPrivate;
  * Code visitor resolving symbol names.
  */
 struct _ValaSymbolResolver {
-	ValaCodeVisitor parent;
+	ValaCodeVisitor parent_instance;
 	ValaSymbolResolverPrivate * priv;
 };
 struct _ValaSymbolResolverClass {
-	ValaCodeVisitorClass parent;
+	ValaCodeVisitorClass parent_class;
 };
 
 void vala_symbol_resolver_resolve (ValaSymbolResolver* self, ValaCodeContext* context);
 ValaSymbolResolver* vala_symbol_resolver_new (void);
 GType vala_symbol_resolver_get_type (void);
 
+
 G_END_DECLS
 
 #endif
