@@ -54,11 +54,11 @@ static void vala_throw_statement_dispose (GObject * obj);
  */
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference) {
 	ValaThrowStatement * self;
-	g_return_val_if_fail (error_expression == NULL || VALA_IS_EXPRESSION (error_expression), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (error_expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_THROW_STATEMENT, 0, NULL);
-	vala_throw_statement_set_error_expression (self, error_expression);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_throw_statement_set_error_expression (self, error_expression);
 	return self;
 }
 
@@ -66,7 +66,7 @@ ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression,
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_throw_statement (visitor, self);
 }
 
@@ -74,7 +74,7 @@ static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_throw_statement_get_error_expression (self)), visitor);
 	}
@@ -84,8 +84,8 @@ static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaC
 static void vala_throw_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_throw_statement_get_error_expression (self) == old_node) {
 		vala_throw_statement_set_error_expression (self, new_node);
 	}
