@@ -61,7 +61,7 @@ static void vala_try_statement_dispose (GObject * obj);
  */
 ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference) {
 	ValaTryStatement * self;
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (finally_body == NULL || VALA_IS_BLOCK (finally_body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_TRY_STATEMENT, 0, NULL);
@@ -79,7 +79,7 @@ ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_bo
  */
 void vala_try_statement_add_catch_clause (ValaTryStatement* self, ValaCatchClause* clause) {
 	g_return_if_fail (VALA_IS_TRY_STATEMENT (self));
-	g_return_if_fail (clause == NULL || VALA_IS_CATCH_CLAUSE (clause));
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
 	gee_collection_add (GEE_COLLECTION (self->priv->catch_clauses), clause);
 }
 
@@ -98,7 +98,7 @@ GeeList* vala_try_statement_get_catch_clauses (ValaTryStatement* self) {
 static void vala_try_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTryStatement * self;
 	self = VALA_TRY_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_try_statement (visitor, self);
 }
 
@@ -106,7 +106,7 @@ static void vala_try_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_try_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTryStatement * self;
 	self = VALA_TRY_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 	{
 		GeeList* clause_collection;
