@@ -1,11 +1,11 @@
 /* valatypeofexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,16 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valatypeofexpression.h"
-#include <vala/valatypereference.h>
-#include <vala/valasourcereference.h>
 #include <vala/valatypeofexpression.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaTypeofExpressionPrivate {
-	ValaTypeReference* _type_reference;
+	ValaDataType* _data_type;
 };
 #define VALA_TYPEOF_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPEOF_EXPRESSION, ValaTypeofExpressionPrivate))
 enum  {
@@ -35,10 +37,13 @@ enum  {
 	VALA_TYPEOF_EXPRESSION_TYPE_REFERENCE
 };
 static void vala_typeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static gboolean vala_typeof_expression_real_is_pure (ValaExpression* base);
+static void vala_typeof_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
 static gpointer vala_typeof_expression_parent_class = NULL;
 static void vala_typeof_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new typeof expression.
  *
@@ -46,55 +51,62 @@ static void vala_typeof_expression_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created typeof expression
  */
-ValaTypeofExpression* vala_typeof_expression_new (ValaTypeReference* type, ValaSourceReference* source)
-{
-	GParameter * __params;
-	GParameter * __params_it;
+ValaTypeofExpression* vala_typeof_expression_new (ValaDataType* type, ValaSourceReference* source) {
 	ValaTypeofExpression * self;
-	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	self = g_object_newv (VALA_TYPE_TYPEOF_EXPRESSION, __params_it - __params, __params);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
+	self = g_object_newv (VALA_TYPE_TYPEOF_EXPRESSION, 0, NULL);
+	vala_typeof_expression_set_type_reference (self, type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
-	while (__params_it > __params) {
-		--__params_it;
-		g_value_unset (&__params_it->value);
-	}
-	g_free (__params);
 	return self;
 }
 
 
-static void vala_typeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_typeof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeofExpression * self;
-	self = ((ValaTypeofExpression*) base);
+	self = VALA_TYPEOF_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_typeof_expression_get_type_reference (self)), visitor);
 	vala_code_visitor_visit_typeof_expression (visitor, self);
 }
 
 
-ValaTypeReference* vala_typeof_expression_get_type_reference (ValaTypeofExpression* self)
-{
+static gboolean vala_typeof_expression_real_is_pure (ValaExpression* base) {
+	ValaTypeofExpression * self;
+	self = VALA_TYPEOF_EXPRESSION (base);
+	return TRUE;
+}
+
+
+static void vala_typeof_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaTypeofExpression * self;
+	self = VALA_TYPEOF_EXPRESSION (base);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_typeof_expression_get_type_reference (self) == old_type) {
+		vala_typeof_expression_set_type_reference (self, new_type);
+	}
+}
+
+
+ValaDataType* vala_typeof_expression_get_type_reference (ValaTypeofExpression* self) {
 	g_return_val_if_fail (VALA_IS_TYPEOF_EXPRESSION (self), NULL);
-	return self->priv->_type_reference;
+	return self->priv->_data_type;
 }
 
 
-void vala_typeof_expression_set_type_reference (ValaTypeofExpression* self, ValaTypeReference* value)
-{
-	ValaTypeReference* _tmp1;
+void vala_typeof_expression_set_type_reference (ValaTypeofExpression* self, ValaDataType* value) {
+	ValaDataType* _tmp2;
+	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_TYPEOF_EXPRESSION (self));
+	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_type_reference = (_tmp1 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), _tmp1);
+	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
 }
 
 
-static void vala_typeof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_typeof_expression_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaTypeofExpression * self;
 	self = VALA_TYPEOF_EXPRESSION (object);
 	switch (property_id) {
@@ -108,8 +120,7 @@ static void vala_typeof_expression_get_property (GObject * object, guint propert
 }
 
 
-static void vala_typeof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_typeof_expression_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaTypeofExpression * self;
 	self = VALA_TYPEOF_EXPRESSION (object);
 	switch (property_id) {
@@ -123,39 +134,33 @@ static void vala_typeof_expression_set_property (GObject * object, guint propert
 }
 
 
-static void vala_typeof_expression_class_init (ValaTypeofExpressionClass * klass)
-{
+static void vala_typeof_expression_class_init (ValaTypeofExpressionClass * klass) {
 	vala_typeof_expression_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaTypeofExpressionPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_typeof_expression_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_typeof_expression_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_typeof_expression_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_typeof_expression_real_accept;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_typeof_expression_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_typeof_expression_real_replace_type;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_TYPEOF_EXPRESSION_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_typeof_expression_init (ValaTypeofExpression * self)
-{
+static void vala_typeof_expression_init (ValaTypeofExpression * self) {
 	self->priv = VALA_TYPEOF_EXPRESSION_GET_PRIVATE (self);
 }
 
 
-static void vala_typeof_expression_dispose (GObject * obj)
-{
+static void vala_typeof_expression_dispose (GObject * obj) {
 	ValaTypeofExpression * self;
-	ValaTypeofExpressionClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_TYPEOF_EXPRESSION (obj);
-	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
-	klass = VALA_TYPEOF_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_TYPEOF_EXPRESSION));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	G_OBJECT_CLASS (vala_typeof_expression_parent_class)->dispose (obj);
 }
 
 
-GType vala_typeof_expression_get_type (void)
-{
+GType vala_typeof_expression_get_type (void) {
 	static GType vala_typeof_expression_type_id = 0;
 	if (G_UNLIKELY (vala_typeof_expression_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeofExpression), 0, (GInstanceInitFunc) vala_typeof_expression_init };
