@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaUnaryExpressionPrivate {
 	ValaUnaryOperator _operator;
 	ValaExpression* _inner;
@@ -43,6 +46,7 @@ static gpointer vala_unary_expression_parent_class = NULL;
 static void vala_unary_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new unary expression.
  *
@@ -55,8 +59,8 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaUnaryExpression * self;
-	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -78,7 +82,7 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_unary_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_unary_expression (visitor, self);
 }
@@ -87,8 +91,8 @@ static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_unary_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_unary_expression_get_inner (self) == old_node) {
 		vala_unary_expression_set_inner (self, new_node);
 	}
@@ -144,7 +148,7 @@ static char* vala_unary_expression_real_to_string (ValaCodeNode* base) {
 static gboolean vala_unary_expression_real_is_pure (ValaExpression* base) {
 	ValaUnaryExpression * self;
 	self = VALA_UNARY_EXPRESSION (base);
-	if (vala_unary_expression_get_operator (self) == VALA_UNARY_OPERATOR_INCREMENT || vala_unary_expression_get_operator (self) == VALA_UNARY_OPERATOR_DECREMENT) {
+	if (self->priv->_operator == VALA_UNARY_OPERATOR_INCREMENT || self->priv->_operator == VALA_UNARY_OPERATOR_DECREMENT) {
 		return FALSE;
 	}
 	return vala_expression_is_pure (vala_unary_expression_get_inner (self));
@@ -185,7 +189,7 @@ static void vala_unary_expression_get_property (GObject * object, guint property
 	self = VALA_UNARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_UNARY_EXPRESSION_OPERATOR:
-		g_value_set_int (value, vala_unary_expression_get_operator (self));
+		g_value_set_enum (value, vala_unary_expression_get_operator (self));
 		break;
 		case VALA_UNARY_EXPRESSION_INNER:
 		g_value_set_object (value, vala_unary_expression_get_inner (self));
@@ -202,7 +206,7 @@ static void vala_unary_expression_set_property (GObject * object, guint property
 	self = VALA_UNARY_EXPRESSION (object);
 	switch (property_id) {
 		case VALA_UNARY_EXPRESSION_OPERATOR:
-		vala_unary_expression_set_operator (self, g_value_get_int (value));
+		vala_unary_expression_set_operator (self, g_value_get_enum (value));
 		break;
 		case VALA_UNARY_EXPRESSION_INNER:
 		vala_unary_expression_set_inner (self, g_value_get_object (value));
@@ -224,7 +228,7 @@ static void vala_unary_expression_class_init (ValaUnaryExpressionClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_unary_expression_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_unary_expression_real_to_string;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_unary_expression_real_is_pure;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNARY_EXPRESSION_OPERATOR, g_param_spec_int ("operator", "operator", "operator", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNARY_EXPRESSION_OPERATOR, g_param_spec_enum ("operator", "operator", "operator", VALA_TYPE_UNARY_OPERATOR, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNARY_EXPRESSION_INNER, g_param_spec_object ("inner", "inner", "inner", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
@@ -253,4 +257,15 @@ GType vala_unary_expression_get_type (void) {
 
 
 
+GType vala_unary_operator_get_type (void) {
+	static GType vala_unary_operator_type_id = 0;
+	if (G_UNLIKELY (vala_unary_operator_type_id == 0)) {
+		static const GEnumValue values[] = {{VALA_UNARY_OPERATOR_NONE, "VALA_UNARY_OPERATOR_NONE", "none"}, {VALA_UNARY_OPERATOR_PLUS, "VALA_UNARY_OPERATOR_PLUS", "plus"}, {VALA_UNARY_OPERATOR_MINUS, "VALA_UNARY_OPERATOR_MINUS", "minus"}, {VALA_UNARY_OPERATOR_LOGICAL_NEGATION, "VALA_UNARY_OPERATOR_LOGICAL_NEGATION", "logical-negation"}, {VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT, "VALA_UNARY_OPERATOR_BITWISE_COMPLEMENT", "bitwise-complement"}, {VALA_UNARY_OPERATOR_INCREMENT, "VALA_UNARY_OPERATOR_INCREMENT", "increment"}, {VALA_UNARY_OPERATOR_DECREMENT, "VALA_UNARY_OPERATOR_DECREMENT", "decrement"}, {VALA_UNARY_OPERATOR_REF, "VALA_UNARY_OPERATOR_REF", "ref"}, {VALA_UNARY_OPERATOR_OUT, "VALA_UNARY_OPERATOR_OUT", "out"}, {0, NULL, NULL}};
+		vala_unary_operator_type_id = g_enum_register_static ("ValaUnaryOperator", values);
+	}
+	return vala_unary_operator_type_id;
+}
+
+
+
 
