@@ -22,6 +22,9 @@
 
 #include <vala/valaunresolvedsymbol.h>
 
+
+
+
 struct _ValaUnresolvedSymbolPrivate {
 	ValaUnresolvedSymbol* _inner;
 	char* _name;
@@ -37,9 +40,11 @@ static gpointer vala_unresolved_symbol_parent_class = NULL;
 static void vala_unresolved_symbol_dispose (GObject * obj);
 
 
+
 ValaUnresolvedSymbol* vala_unresolved_symbol_new (ValaUnresolvedSymbol* inner, const char* name, ValaSourceReference* source_reference) {
 	ValaUnresolvedSymbol * self;
 	g_return_val_if_fail (inner == NULL || VALA_IS_UNRESOLVED_SYMBOL (inner), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_UNRESOLVED_SYMBOL, 0, NULL);
 	vala_unresolved_symbol_set_inner (self, inner);
@@ -52,23 +57,23 @@ ValaUnresolvedSymbol* vala_unresolved_symbol_new (ValaUnresolvedSymbol* inner, c
 static char* vala_unresolved_symbol_real_to_string (ValaCodeNode* base) {
 	ValaUnresolvedSymbol * self;
 	self = VALA_UNRESOLVED_SYMBOL (base);
-	if (vala_unresolved_symbol_get_inner (self) == NULL) {
+	if (self->priv->_inner == NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = vala_unresolved_symbol_get_name (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+		return (_tmp0 = self->priv->_name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	} else {
 		char* _tmp2;
 		char* _tmp3;
 		_tmp2 = NULL;
 		_tmp3 = NULL;
-		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (vala_unresolved_symbol_get_inner (self)))), vala_unresolved_symbol_get_name (self)), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
+		return (_tmp3 = g_strdup_printf ("%s.%s", (_tmp2 = vala_code_node_to_string (VALA_CODE_NODE (self->priv->_inner))), self->priv->_name), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
 	}
 }
 
 
 ValaUnresolvedSymbol* vala_unresolved_symbol_copy (ValaUnresolvedSymbol* self) {
 	g_return_val_if_fail (VALA_IS_UNRESOLVED_SYMBOL (self), NULL);
-	return vala_unresolved_symbol_new (vala_unresolved_symbol_get_inner (self), vala_unresolved_symbol_get_name (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+	return vala_unresolved_symbol_new (self->priv->_inner, self->priv->_name, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 }
 
 
