@@ -26,6 +26,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaWhileStatementPrivate {
 	ValaExpression* _condition;
 	ValaBlock* _body;
@@ -44,6 +47,7 @@ static ValaStatementIface* vala_while_statement_vala_statement_parent_iface = NU
 static void vala_while_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new while statement.
  *
@@ -56,8 +60,8 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaWhileStatement * self;
-	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -80,7 +84,7 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_while_statement (visitor, self);
 }
 
@@ -88,7 +92,7 @@ static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_while_statement_get_condition (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_body (self)), visitor);
@@ -98,8 +102,8 @@ static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaC
 static void vala_while_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_while_statement_get_condition (self) == old_node) {
 		vala_while_statement_set_condition (self, new_node);
 	}
