@@ -38,9 +38,6 @@
 #include <vala/valareport.h>
 #include <glib/gstdio.h>
 
-typedef struct _ValaVAPICheck ValaVAPICheck;
-typedef struct _ValaVAPICheckClass ValaVAPICheckClass;
-typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
 
 #define VALA_TYPE_VAPI_CHECK (vala_vapi_check_get_type ())
 #define VALA_VAPI_CHECK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheck))
@@ -49,6 +46,10 @@ typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
 #define VALA_IS_VAPI_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VAPI_CHECK))
 #define VALA_VAPI_CHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_CHECK, ValaVAPICheckClass))
 
+typedef struct _ValaVAPICheck ValaVAPICheck;
+typedef struct _ValaVAPICheckClass ValaVAPICheckClass;
+typedef struct _ValaVAPICheckPrivate ValaVAPICheckPrivate;
+
 struct _ValaVAPICheck {
 	GObject parent_instance;
 	ValaVAPICheckPrivate * priv;
@@ -56,6 +57,8 @@ struct _ValaVAPICheck {
 struct _ValaVAPICheckClass {
 	GObjectClass parent_class;
 };
+
+
 struct _ValaVAPICheckPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _gidl;
@@ -92,6 +95,7 @@ static GType vala_vapi_check_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
 
+
 static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
@@ -101,7 +105,8 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 	char* _tmp2;
 	char* _tmp1;
 	ValaVAPICheck * self;
-	g_return_val_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (gidlname != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	_tmp0 = NULL;
@@ -149,7 +154,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		{
 			GList* module_collection;
 			GList* module_it;
-			module_collection = g_idl_parse_file (vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), &inner_error);
+			module_collection = g_idl_parse_file (vala_source_file_get_filename (self->priv->_gidl), &inner_error);
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_MARKUP_ERROR) {
 					goto __catch0_g_markup_error;
@@ -174,7 +179,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 		e = inner_error;
 		inner_error = NULL;
 		{
-			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), e->message);
+			fprintf (stderr, "%s: %s\n", vala_source_file_get_filename (self->priv->_gidl), e->message);
 		}
 	}
 	__finally0:
@@ -184,6 +189,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 
 static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
 	if (NULL != separator) {
 		char* _tmp1;
 		char* _tmp0;
@@ -209,6 +215,7 @@ static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 
 static void vala_vapi_check_enter_scope (ValaVAPICheck* self, const char* name) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
 	gee_collection_add (GEE_COLLECTION (self->priv->_scope), name);
 	vala_vapi_check_add_symbol (self, name, NULL);
 }
@@ -222,6 +229,8 @@ static void vala_vapi_check_leave_scope (ValaVAPICheck* self) {
 
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (members != NULL);
 	vala_vapi_check_enter_scope (self, name);
 	{
 		GList* node_collection;
@@ -266,7 +275,7 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 					break;
 				} while (0); else
 				do {
-					g_warning ("valavapicheck.vala:120: TODO: %s: Implement support for type %d nodes", node->name, node->type);
+					g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, node->type);
 					break;
 				} while (0);
 			}
@@ -287,7 +296,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		GIOStatus _tmp1;
 		char* _tmp0;
 		gint _tmp5;
-		metafile = g_io_channel_new_file (vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), "r", &inner_error);
+		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch1_g_file_error;
@@ -311,7 +320,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 			if (strlen (symbol) > 0 && !gee_collection_contains (GEE_COLLECTION (self->priv->_symbols), symbol)) {
 				ValaSourceReference* src;
 				char* _tmp4;
-				src = vala_source_reference_new (vala_vapi_check_get_metadata (self), lineno, 1, lineno, ((gint) g_utf8_strlen (symbol, -1)));
+				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, ((gint) g_utf8_strlen (symbol, -1)));
 				_tmp4 = NULL;
 				vala_report_error (src, (_tmp4 = g_strdup_printf ("Symbol `%s' not found", symbol)));
 				_tmp4 = (g_free (_tmp4), NULL);
@@ -332,7 +341,7 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		{
 			char* _tmp6;
 			_tmp6 = NULL;
-			vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), error->message)));
+			vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
 			_tmp6 = (g_free (_tmp6), NULL);
 			return 1;
 		}
@@ -344,17 +353,17 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 
 static gint vala_vapi_check_run (ValaVAPICheck* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), 0);
-	if (!g_file_test (vala_source_file_get_filename (vala_vapi_check_get_gidl (self)), G_FILE_TEST_IS_REGULAR)) {
+	if (!g_file_test (vala_source_file_get_filename (self->priv->_gidl), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp0;
 		_tmp0 = NULL;
-		vala_report_error (NULL, (_tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (vala_vapi_check_get_gidl (self)))));
+		vala_report_error (NULL, (_tmp0 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_gidl))));
 		_tmp0 = (g_free (_tmp0), NULL);
 		return 2;
 	}
-	if (!g_file_test (vala_source_file_get_filename (vala_vapi_check_get_metadata (self)), G_FILE_TEST_IS_REGULAR)) {
+	if (!g_file_test (vala_source_file_get_filename (self->priv->_metadata), G_FILE_TEST_IS_REGULAR)) {
 		char* _tmp2;
 		_tmp2 = NULL;
-		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (vala_vapi_check_get_metadata (self)))));
+		vala_report_error (NULL, (_tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (self->priv->_metadata))));
 		_tmp2 = (g_free (_tmp2), NULL);
 		return 2;
 	}
