@@ -36,9 +36,6 @@
 #include <config.h>
 #include "vapigen/valagidlparser.h"
 
-typedef struct _ValaVAPIGen ValaVAPIGen;
-typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
-typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 
 #define VALA_TYPE_VAPI_GEN (vala_vapi_gen_get_type ())
 #define VALA_VAPI_GEN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VAPI_GEN, ValaVAPIGen))
@@ -47,6 +44,10 @@ typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
 #define VALA_IS_VAPI_GEN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VAPI_GEN))
 #define VALA_VAPI_GEN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VAPI_GEN, ValaVAPIGenClass))
 
+typedef struct _ValaVAPIGen ValaVAPIGen;
+typedef struct _ValaVAPIGenClass ValaVAPIGenClass;
+typedef struct _ValaVAPIGenPrivate ValaVAPIGenPrivate;
+
 struct _ValaVAPIGen {
 	GObject parent_instance;
 	ValaVAPIGenPrivate * priv;
@@ -54,6 +55,8 @@ struct _ValaVAPIGen {
 struct _ValaVAPIGenClass {
 	GObjectClass parent_class;
 };
+
+
 struct _ValaVAPIGenPrivate {
 	ValaCodeContext* context;
 };
@@ -68,7 +71,6 @@ static char** vala_vapi_gen_sources;
 static char** vala_vapi_gen_vapi_directories;
 static char* vala_vapi_gen_library;
 static char** vala_vapi_gen_packages;
-static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", 0, 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", 0, 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", 0, 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 static gint vala_vapi_gen_quit (ValaVAPIGen* self);
 static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg);
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1);
@@ -80,6 +82,8 @@ static void vala_vapi_gen_dispose (GObject * obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
+static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) 0), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) 0), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) 0), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
+
 
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), 0);
@@ -102,10 +106,11 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	ValaSourceFile* _tmp2;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), FALSE);
+	g_return_val_if_fail (pkg != NULL, FALSE);
 	if (vala_code_context_has_package (self->priv->context, pkg)) {
+		/* ignore multiple occurences of the same package*/
 		return TRUE;
 	}
-	/* ignore multiple occurences of the same package*/
 	package_path = vala_code_context_get_package_path (self->priv->context, pkg, -1, vala_vapi_gen_vapi_directories);
 	if (package_path == NULL) {
 		gboolean _tmp1;
@@ -126,6 +131,7 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 	char* _tmp0;
 	gpointer _tmp4;
 	gpointer _tmp5;
+	g_return_val_if_fail (depsfile != NULL, NULL);
 	inner_error = NULL;
 	contents = NULL;
 	_tmp0 = NULL;
@@ -155,6 +161,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
 	}
+	/* load packages from .deps file */
 	{
 		char** source_collection;
 		char** source_it;
@@ -175,7 +182,6 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				gint deps_length1;
 				gint _tmp4;
 				char** deps;
-				/* load packages from .deps file */
 				if (!g_str_has_suffix (source, ".gi")) {
 					source = (g_free (source), NULL);
 					continue;
